<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core
 */

/**
 * Find whether there is anti-leech protection using session IDs.
 *
 * @return boolean Whether there is
 */
function has_regular_anti_leech_protection() : bool
{
    if (get_option('anti_leech') == '1') {
        global $SITE_INFO;
        if ((!is_guest()) || (empty($SITE_INFO['any_guest_cached_too']))) {
            return true;
        }
    }
    return false;
}

/**
 * Apply anti-leech protection to a URL.
 *
 * @param  Tempcode $url The URL
 */
function apply_anti_leech_to_tempcode_url(object $url)
{
    if (has_regular_anti_leech_protection()) {
        $url->attach('&for_session=');
        $url->attach(symbol_tempcode('SESSION_HASHED'));
    }
}

/**
 * Check anti-leech protection.
 */
function check_anti_leech()
{
    if (get_option('anti_leech') == '1') {
        if (has_regular_anti_leech_protection()) {
            // Safe to apply anti-leech protection using sessions
            if ((get_param_string('for_session', '') != md5(get_session_id())) && ($_SERVER['HTTP_REFERER'] != ''/*not a download manager*/)) {
                warn_exit(do_lang_tempcode('LEECH_BLOCK'));
            }
        } else {
            // We need to do anti-leech protection using referrers - as we cannot rely on ANYTHING dynamic when static-cache is enabled
            if ($_SERVER['HTTP_REFERER'] != '') {
                $domain = @cms_parse_url_safe($_SERVER['HTTP_REFERER'], PHP_URL_HOST);
                if (($domain !== false) && (!is_our_server($domain))) {
                    warn_exit(do_lang_tempcode('LEECH_BLOCK'));
                }
            }
        }
    }
}
