<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core
 */

/**
 * AJAX script to store an autosave.
 *
 * @ignore
 */
function store_autosave_script()
{
    require_code('input_filter_2');
    if (get_value('disable_modsecurity_workaround') !== '1') {
        modsecurity_workaround_enable();
    }

    prepare_backend_response('text/plain');

    $member_id = get_member();
    $time = time();

    foreach (array_keys($_POST) as $key) {
        $value = post_param_string($key);

        $GLOBALS['SITE_DB']->query_insert('autosave', [
            // Will duplicate against a_member_id/a_key, but DB space is not an issue - better to have the back-archive of it
            'a_member_id' => $member_id,
            'a_key' => $key,
            'a_value' => $value,
            'a_time' => $time,
        ]);
    }

    cms_safe_exit_flow();
}

/**
 * AJAX script to retrieve an autosave.
 *
 * @ignore
 */
function retrieve_autosave_script()
{
    prepare_backend_response();

    $member_id = get_member();
    $stem = either_param_string('stem');

    require_code('xml');

    cms_ini_set('ocproducts.xss_detect', '0');

    echo '<?xml version="1.0" encoding="' . escape_html(get_charset()) . '"?' . '>';
    echo '<request><result>' . "\n";

    $rows = $GLOBALS['SITE_DB']->query_select(
        'autosave',
        ['a_key', 'a_value', 'a_time'],
        ['a_member_id' => $member_id],
        'AND a_key LIKE \'' . db_encode_like($stem) . '%\' ORDER BY a_time DESC'
    );

    $done = [];
    foreach ($rows as $row) {
        if (isset($done[$row['a_key']])) {
            continue;
        }
        echo '<field key="' . xmlentities($row['a_key']) . '" value="' . xmlentities($row['a_value']) . '" />' . "\n";
        $done[$row['a_key']] = true;
    }

    echo '</result></request>';

    cms_safe_exit_flow();
}

/**
 * Declare that an action succeeded - delete safety autosave cookies.
 */
function clear_cms_autosave()
{
    static $done_once = false;
    if ($done_once) {
        return;
    }

    if (!function_exists('get_member')) {
        return;
    }

    foreach (array_keys($_COOKIE) as $key) {
        if (!is_string($key)) {
            continue;
        }

        if (substr($key, 0, 13) == 'cms_autosave_') {
            if (strpos($key, get_page_name()) !== false || strpos($key, str_replace('_', '-', get_page_name())) !== false) {
                // Has to do both, due to inconsistencies with how PHP reads and sets cookies -- reading de-urlencodes (although not strictly needed), while setting does not urlencode; may differ between versions
                require_code('users_active_actions');
                cms_eatcookie(urlencode($key));
                cms_eatcookie($key);
            }
        }
    }

    $sql = 'DELETE FROM ' . $GLOBALS['SITE_DB']->get_table_prefix() . 'autosave WHERE a_time<' . strval(time() - 60 * 60 * 24) . ' OR (a_member_id=' . strval(get_member()) . ' AND (a_key LIKE \'' . db_encode_like('%' . get_page_name() . '%') . '\'))';
    $GLOBALS['SITE_DB']->query($sql);

    $done_once = true;
}
