<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    custom_comcode
 */

/**
 * Block class.
 */
class Block_main_custom_comcode_tags
{
    /**
     * Find details of the block.
     *
     * @return ?array Map of block info (null: block is disabled)
     */
    public function info() : ?array
    {
        $info = [];
        $info['author'] = 'Chris Graham';
        $info['organisation'] = 'Composr';
        $info['hacked_by'] = null;
        $info['hack_version'] = null;
        $info['version'] = 2;
        $info['locked'] = false;
        $info['min_cms_version'] = 11.0;
        $info['addon'] = 'custom_comcode';
        $info['parameters'] = [];
        return $info;
    }

    /**
     * Execute the block.
     *
     * @param  array $map A map of parameters
     * @return Tempcode The result of execution
     */
    public function run(array $map) : object
    {
        $error_msg = new Tempcode();
        if (!addon_installed__messaged('custom_comcode', $error_msg)) {
            return $error_msg;
        }

        require_lang('custom_comcode');

        $block_id = get_block_id($map);

        $tags = [];
        $wmap = ['tag_enabled' => 1];
        if (!has_privilege(get_member(), 'comcode_dangerous')) {
            $wmap['tag_dangerous_tag'] = 0;
        }
        $tags = array_merge($tags, $GLOBALS['SITE_DB']->query_select('custom_comcode', ['tag_title', 'tag_description', 'tag_example', 'tag_parameters', 'tag_replace', 'tag_tag', 'tag_dangerous_tag', 'tag_block_tag', 'tag_textual_tag'], $wmap));
        if ((is_on_multi_site_network()) && (get_forum_type() == 'cns')) {
            $tags = array_merge($tags, $GLOBALS['FORUM_DB']->query_select('custom_comcode', ['tag_title', 'tag_description', 'tag_example', 'tag_parameters', 'tag_replace', 'tag_tag', 'tag_dangerous_tag', 'tag_block_tag', 'tag_textual_tag'], $wmap));
        }

        // From Comcode hooks
        $hooks = find_all_hook_obs('systems', 'comcode', 'Hook_comcode_');
        foreach ($hooks as $object) {
            $_tag = $object->get_tag();
            if ($_tag !== null) {
                $tags[] = $_tag;
            }
        }

        if (!array_key_exists(0, $tags)) {
            return paragraph(do_lang_tempcode('NONE_EM'), 'wa7toclrdmr6di83mmc2te5kgb34qslc', 'nothing-here');
        }

        $_tags = [];
        foreach ($tags as $tag) {
            $_tags[] = [
                '_GUID' => '28c257f5d0c596aa828fd9556b0df4a9',
                'TITLE' => is_string($tag['tag_title']) ? $tag['tag_title'] : get_translated_text($tag['tag_title']),
                'DESCRIPTION' => is_string($tag['tag_description']) ? $tag['tag_description'] : get_translated_text($tag['tag_description']),
                'EXAMPLE' => $tag['tag_example'],
            ];
        }

        return do_template('BLOCK_MAIN_CUSTOM_COMCODE_TAGS', [
            '_GUID' => 'b8d3436e6e5fe679ae9b0a368e607610',
            'BLOCK_ID' => $block_id,
            'TAGS' => $_tags,
        ]);
    }
}
