<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core_feedback_features
 */

/**
 * Block class.
 */
class Block_main_rating
{
    /**
     * Find details of the block.
     *
     * @return ?array Map of block info (null: block is disabled)
     */
    public function info() : ?array
    {
        $info = [];
        $info['author'] = 'Chris Graham';
        $info['organisation'] = 'Composr';
        $info['hacked_by'] = null;
        $info['hack_version'] = null;
        $info['version'] = 2;
        $info['locked'] = false;
        $info['min_cms_version'] = 11.0;
        $info['addon'] = 'core_feedback_features';
        $info['parameters'] = ['param', 'page', 'title', 'display_tpl'];
        return $info;
    }

    /**
     * Find caching details for the block.
     *
     * @return ?array Map of cache details (cache_on and ttl) (null: block is disabled)
     */
    /*
    public function caching_environment() // We can't cache this block, because it needs to execute in order to allow commenting
    {
        $info['cache_on'] = <<<'PHP'
        [
            has_privilege(get_member(), 'rate'),
            array_key_exists('param', $map) ? $map['param'] : 'main',
            array_key_exists('page', $map) ? $map['page'] : get_page_name(),
            array_key_exists('title', $map) ? $map['title'] : '',
            empty($map['display_tpl']) ? 'RATING_BOX' : $map['display_tpl'],
        ]
PHP;
        $info['ttl'] = 60 * 5;
        return $info;
    }*/

    /**
     * Execute the block.
     *
     * @param  array $map A map of parameters
     * @return Tempcode The result of execution
     */
    public function run(array $map) : object
    {
        $content_type = 'block_main_rating';
        $param = array_key_exists('param', $map) ? $map['param'] : 'main';
        $page = array_key_exists('page', $map) ? $map['page'] : get_page_name();
        $id = $page . '_' . $param;

        require_code('feedback');

        $self_url = get_self_url();
        $self_title = @cms_empty_safe($map['title']) ? $page : $map['title'];

        $test_changed = post_param_string('rating_' . $id, '');
        if ($test_changed != '') {
            delete_cache_entry('main_rating');
        }

        $display_tpl = empty($map['display_tpl']) ? 'RATING_BOX' : $map['display_tpl'];

        actualise_rating(true, $content_type, $id, $self_url, $self_title);

        return display_rating($self_url, $self_title, $content_type, $id, $display_tpl);
    }
}
