<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core
 */

/**
 * Block class.
 */
class Block_top_login
{
    /**
     * Find details of the block.
     *
     * @return ?array Map of block info (null: block is disabled)
     */
    public function info() : ?array
    {
        $info = [];
        $info['author'] = 'Chris Graham';
        $info['organisation'] = 'Composr';
        $info['hacked_by'] = null;
        $info['hack_version'] = null;
        $info['version'] = 2;
        $info['locked'] = false;
        $info['min_cms_version'] = 11.0;
        $info['addon'] = 'core';
        $info['parameters'] = [];
        return $info;
    }

    /**
     * Find caching details for the block.
     *
     * @return ?array Map of cache details (cache_on and ttl) (null: block is disabled)
     */
    public function caching_environment() : ?array
    {
        $info = [];
        // No caching for guests due to self URL redirect
        $info['cache_on'] = <<<'PHP'
        is_guest()
        ?
        null
        :
        [
        ]
PHP;
        $info['ttl'] = 60 * 24;
        return $info;
    }

    /**
     * Execute the block.
     *
     * @param  array $map A map of parameters
     * @return Tempcode The result of execution
     */
    public function run(array $map) : object
    {
        if (!is_guest()) {
            return new Tempcode();
        }

        if (get_forum_type() == 'none') {
            return do_template('RED_ALERT', ['_GUID' => '8wj7a899zxqp7vnxaio4hamm6p3j651d', 'TEXT' => do_lang_tempcode('NO_FORUM_INSTALLED')]);
        }

        require_css('personal_stats');

        $block_id = get_block_id($map);

        $title = do_lang_tempcode('NOT_LOGGED_IN');

        list($full_url, $login_url, $join_url) = get_login_url();
        return do_template('BLOCK_TOP_LOGIN', [
            '_GUID' => '9d1547632875ecd466ced4f90a866df9',
            'BLOCK_ID' => $block_id,
            'TITLE' => $title,
            'FULL_LOGIN_URL' => $full_url,
            'JOIN_URL' => $join_url,
            'LOGIN_URL' => $login_url,
        ]);
    }
}
