<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core
 */

/**
 * Block class.
 */
class Block_top_personal_stats
{
    /**
     * Find details of the block.
     *
     * @return ?array Map of block info (null: block is disabled)
     */
    public function info() : ?array
    {
        $info = [];
        $info['author'] = 'Chris Graham';
        $info['organisation'] = 'Composr';
        $info['hacked_by'] = null;
        $info['hack_version'] = null;
        $info['version'] = 2;
        $info['locked'] = false;
        $info['min_cms_version'] = 11.0;
        $info['addon'] = 'core';
        $info['parameters'] = [];
        return $info;
    }

    /**
     * Execute the block.
     *
     * @param  array $map A map of parameters
     * @return Tempcode The result of execution
     */
    public function run(array $map) : object
    {
        if (is_guest()) {
            return new Tempcode();
        }

        require_css('personal_stats');

        $block_id = get_block_id($map);

        require_javascript('sound');

        $member_id = get_member();

        $avatar_url = '';
        if (!has_no_forum()) {
            $avatar_url = $GLOBALS['FORUM_DRIVER']->get_member_avatar_url($member_id);
        }

        $username = $GLOBALS['FORUM_DRIVER']->get_username($member_id);

        require_code('global4');
        list($links, $links_ecommerce, $details, $num_unread_pps) = member_personal_links_and_details($member_id);

        return do_template('BLOCK_TOP_PERSONAL_STATS', [
            '_GUID' => '6460943f1f0944fb6e8fe252dfa1b853',
            'BLOCK_ID' => $block_id,
            'NUM_UNREAD_PTS' => strval($num_unread_pps),
            'AVATAR_URL' => $avatar_url,
            'MEMBER_ID' => strval($member_id),
            'USERNAME' => $username,
            'LINKS' => $links,
            'LINKS_ECOMMERCE' => $links_ecommerce,
            'DETAILS' => $details,
        ]);
    }
}
