<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    cns_warnings
 */

/**
 * Find a member's content.
 *
 * @param  MEMBER $member_id Member ID
 * @param  ?integer $days Only consider content posted in the last specified days (null: do not consider)
 * @param  ?integer $max Maximum results (null: no maximum; you should specify $days in this case)
 * @return array List of content rows
 */
function find_member_content(int $member_id, ?int $days = null, ?int $max = 30) : array
{
    if (!has_privilege(get_member(), 'delete_highrange_content')) {
        return [];
    }

    require_code('content');

    $content = [];

    if (is_guest($member_id)) {
        return $content;
    }

    // All content using hooks...

    $content_types = [];
    $hooks = find_all_hook_obs('systems', 'content_meta_aware', 'Hook_content_meta_aware_');
    foreach ($hooks as $hook => $ob) {
        $cma_info = $ob->info();
        if (
            (!in_array($hook, ['member', 'topic', 'post'/*topics and posts handled with special support elsewhere*/])) &&
            ($cma_info['table'] !== null) &&
            ($cma_info['submitter_field'] !== null) &&
            ($cma_info['id_field'] !== null) &&
            ($cma_info['add_time_field'] !== null) &&
            ($cma_info['commandr_filesystem_hook'] !== null)
        ) {
            $content_types[] = $hook;
        }
    }

    require_code('content');
    list($rows) = content_rows_for_multi_type($content_types, $days, '', '', 'recent DESC', 0, $max * 10);

    foreach ($rows as $row) {
        $ob = get_content_object($row['content_type']);

        $submitter = $ob->get_submitter($row);
        if (($submitter === null) || ($submitter != $member_id)) {
            continue;
        }

        $content_id = $ob->get_id($row);
        $content_title = $ob->get_title($row);
        $content_url = $ob->get_view_url($row);
        $content_add_time = $ob->get_add_time($row);

        $content[] = [
            $ob->get_content_type_label($row),
            $row['content_type'],
            $content_id,
            $content_title,
            $content_url,
            $content_add_time,
            false
        ];

        if (count($content) >= $max) {
            break;
        }
    }

    return $content;
}
