<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    content_reviews
 */

/**
 * Show content review details.
 *
 * @param  ID_TEXT $content_type The content type
 * @param  ID_TEXT $content_id The content ID
 * @param  integer $display_mode The display mode (0=show full box of review information, 1=show last reviewed time, 2=show next reviewed time)
 * @set 0 1 2
 * @return string Content review details to show
 */
function show_content_reviews(string $content_type, string $content_id, int $display_mode = 0) : string
{
    $content_reviews = $GLOBALS['SITE_DB']->query_select('content_reviews', ['display_review_status', 'last_reviewed_time', 'next_review_time'], [
        'content_type' => $content_type,
        'content_id' => $content_id,
    ], '', 1);
    if (isset($content_reviews[0])) {
        if ($display_mode == 1) {
            $value = strval($content_reviews[0]['last_reviewed_time']);
        } elseif ($display_mode == 2) {
            $value = strval($content_reviews[0]['next_review_time']);
        } else { // display mode 0
            require_lang('content_reviews');
            $value = static_evaluate_tempcode(do_template('REVIEW_STATUS', [
                '_GUID' => '89fa418ac54d63c3d53c32b9314b8889',
                'LAST_REVIEWED_DATE' => get_timezoned_date($content_reviews[0]['last_reviewed_time'], false),
                'NEXT_REVIEW_DATE' => get_timezoned_date($content_reviews[0]['next_review_time'], false),
                '_LAST_REVIEWED_TIME' => strval($content_reviews[0]['last_reviewed_time']),
                '_NEXT_REVIEW_TIME' => strval($content_reviews[0]['next_review_time']),
                'CONTENT_TYPE' => $content_type,
                'CONTENT_ID' => $content_id,
                'DISPLAY' => $content_reviews[0]['display_review_status'] == 1,
            ]));
        }
    } else {
        $value = '';
        if ($GLOBALS['XSS_DETECT']) {
            ocp_mark_as_escaped($value);
        }
    }

    return $value;
}
