<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    backup
 */

/**
 * Hook class.
 */
class Hook_checklist_backup
{
    /**
     * Find items to include on the staff checklist.
     *
     * @return array An array of tuples: The task row to show, the number of seconds until it is due (or null if not on a timer), the number of things to sort out (or null if not on a queue), The name of the config option that controls the schedule (or null if no option)
     */
    public function run() : array
    {
        if (!addon_installed('backup')) {
            return [];
        }

        if (get_option('backup_time') == '' || get_option('backup_time') == '0') {
            return [];
        }
        $limit_hours = intval(get_option('backup_time'));

        require_lang('backups');

        $_date = get_value('last_backup');
        $date = ($_date === null) ? null : intval($_date);
        $seconds_ago = null;
        if ($date === null) {
            require_code('global4');
            $date = get_site_start_time();
        }
        $seconds_ago = time() - $date;
        $status = ($seconds_ago > $limit_hours * 60 * 60) ? 0 : 1;

        $_status = ($status == 0) ? do_template('BLOCK_MAIN_STAFF_CHECKLIST_ITEM_STATUS_0') : do_template('BLOCK_MAIN_STAFF_CHECKLIST_ITEM_STATUS_1');

        require_code('config2');
        $config_url = config_option_url('backup_time');

        $url = build_url(['page' => 'admin_backup', 'type' => 'browse'], get_module_zone('admin_backup'));
        list($info, $seconds_due_in) = staff_checklist_time_ago_and_due($seconds_ago, $limit_hours);
        $tpl = do_template('BLOCK_MAIN_STAFF_CHECKLIST_ITEM', [
            '_GUID' => '432685ec6c9f7548ce8b488b6ce00030',
            'CONFIG_URL' => $config_url,
            'URL' => $url,
            'STATUS' => $_status,
            'TASK' => do_lang_tempcode('BACKUP'),
            'INFO' => $info,
        ]);
        return [[$tpl, $seconds_due_in, null, 'backup_time']];
    }
}
