<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    wiki
 */

/**
 * Hook class.
 */
class Hook_stats_wiki
{
    /**
     * Show a stats section.
     *
     * @return Tempcode The result of execution
     */
    public function run() : object
    {
        if (!addon_installed('wiki')) {
            return new Tempcode();
        }

        require_code('wiki_stats');
        require_lang('wiki');

        $bits = new Tempcode();
        if (get_option('wiki_show_stats_count_pages') == '1') {
            $num_pages = get_num_wiki_pages();

            $bits->attach(do_template('BLOCK_SIDE_STATS_SUBLINE', [
                '_GUID' => '8bbd18d5169c4e5449b252880ecda716',
                'KEY' => do_lang_tempcode('COUNT_PAGES'),
                'RAW_VALUE' => strval($num_pages),
                'VALUE' => integer_format($num_pages, 0),
            ]));
        }
        if (get_option('wiki_show_stats_count_posts') == '1') {
            $num_posts = get_num_wiki_posts();

            $bits->attach(do_template('BLOCK_SIDE_STATS_SUBLINE', [
                '_GUID' => 'd8cf3d5aabc18777f609760010303ace',
                'KEY' => do_lang_tempcode('COUNT_POSTS'),
                'RAW_VALUE' => strval($num_posts),
                'VALUE' => integer_format($num_posts, 0),
            ]));
        }
        if ($bits->is_empty_shell()) {
            return new Tempcode();
        }
        $wiki = do_template('BLOCK_SIDE_STATS_SECTION', ['_GUID' => 'ea19e51db4e62958843ace808016af1e', 'SECTION' => do_lang_tempcode('WIKI'), 'CONTENT' => $bits]);

        return $wiki;
    }
}
