<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    catalogues
 */

/**
 * Hook class.
 */
class Hook_sw_catalogues
{
    /**
     * Run function for features in the setup wizard.
     *
     * @return array Current settings
     */
    public function get_current_settings() : array
    {
        $settings = [];
        $settings['have_default_catalogues_projects'] = has_predefined_content('catalogues', 'have_default_catalogues_projects') ? '1' : '0';
        $settings['have_default_catalogues_faqs'] = has_predefined_content('catalogues', 'have_default_catalogues_faqs') ? '1' : '0';
        $settings['have_default_catalogues_links'] = has_predefined_content('catalogues', 'have_default_catalogues_links') ? '1' : '0';
        $settings['have_default_catalogues_contacts'] = has_predefined_content('catalogues', 'have_default_catalogues_contacts') ? '1' : '0';
        return $settings;
    }

    /**
     * Run function for features in the setup wizard.
     *
     * @param  array $field_defaults Default values for the fields, from the install-profile
     * @return array A pair: Input fields, Hidden fields
     */
    public function get_fields(array $field_defaults) : array
    {
        if (!addon_installed('catalogues') || post_param_integer('addon_catalogues', null) === 0) {
            return [new Tempcode(), new Tempcode()];
        }

        $current_settings = $this->get_current_settings();
        $field_defaults += $current_settings; // $field_defaults will take precedence, due to how "+" operator works in PHP

        require_lang('catalogues');

        $fields = new Tempcode();
        $fields->attach(form_input_tick(do_lang_tempcode('HAVE_DEFAULT_CATALOGUES_PROJECTS'), do_lang_tempcode('DESCRIPTION_HAVE_DEFAULT_CATALOGUES_PROJECTS'), 'have_default_catalogues_projects', $field_defaults['have_default_catalogues_projects'] == '1'));
        $fields->attach(form_input_tick(do_lang_tempcode('HAVE_DEFAULT_CATALOGUES_FAQS'), do_lang_tempcode('DESCRIPTION_HAVE_DEFAULT_CATALOGUES_FAQS'), 'have_default_catalogues_faqs', $field_defaults['have_default_catalogues_faqs'] == '1'));
        $fields->attach(form_input_tick(do_lang_tempcode('HAVE_DEFAULT_CATALOGUES_LINKS'), do_lang_tempcode('DESCRIPTION_HAVE_DEFAULT_CATALOGUES_LINKS'), 'have_default_catalogues_links', $field_defaults['have_default_catalogues_links'] == '1'));
        $fields->attach(form_input_tick(do_lang_tempcode('HAVE_DEFAULT_CATALOGUES_CONTACTS'), do_lang_tempcode('DESCRIPTION_HAVE_DEFAULT_CATALOGUES_CONTACTS'), 'have_default_catalogues_contacts', $field_defaults['have_default_catalogues_contacts'] == '1'));

        return [$fields, new Tempcode()];
    }

    /**
     * Run function for setting features from the setup wizard.
     */
    public function set_fields()
    {
        if (!addon_installed('catalogues') || post_param_integer('addon_catalogues', null) === 0) {
            return;
        }

        install_predefined_content('catalogues', [
           'have_default_catalogues_projects' => (post_param_integer('have_default_catalogues_projects', 0) == 1),
           'have_default_catalogues_faqs' => (post_param_integer('have_default_catalogues_faqs', 0) == 1),
           'have_default_catalogues_links' => (post_param_integer('have_default_catalogues_links', 0) == 1),
           'have_default_catalogues_contacts' => (post_param_integer('have_default_catalogues_contacts', 0) == 1),
        ]);
    }
}
