<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    news
 */

/**
 * Hook class.
 */
class Hook_sw_news
{
    /**
     * Run function for features in the setup wizard.
     *
     * @return array Current settings
     */
    public function get_current_settings() : array
    {
        $settings = [];

        $test = $GLOBALS['SITE_DB']->query_select_value('group_privileges', 'COUNT(*)', ['privilege' => 'have_personal_category', 'the_page' => 'cms_news']);
        $settings['keep_blogs'] = ($test == 0) ? '0' : '1';

        $keep_news_categories = false;
        if (has_predefined_content('news', 'technology')) {
            $keep_news_categories = true;
        }
        if (has_predefined_content('news', 'difficulties')) {
            $keep_news_categories = true;
        }
        if (has_predefined_content('news', 'community')) {
            $keep_news_categories = true;
        }
        if (has_predefined_content('news', 'entertainment')) {
            $keep_news_categories = true;
        }
        if (has_predefined_content('news', 'business')) {
            $keep_news_categories = true;
        }
        if (has_predefined_content('news', 'art')) {
            $keep_news_categories = true;
        }
        $settings['keep_news_categories'] = $keep_news_categories ? '1' : '0';

        return $settings;
    }

    /**
     * Run function for features in the setup wizard.
     *
     * @param  array $field_defaults Default values for the fields, from the install-profile
     * @return array A pair: Input fields, Hidden fields
     */
    public function get_fields(array $field_defaults) : array
    {
        if (!addon_installed('news') || post_param_integer('addon_news', null) === 0) {
            return [new Tempcode(), new Tempcode()];
        }

        $current_settings = $this->get_current_settings();
        $field_defaults += $current_settings; // $field_defaults will take precedence, due to how "+" operator works in PHP

        require_lang('news');
        $fields = new Tempcode();

        $fields->attach(form_input_tick(do_lang_tempcode('KEEP_BLOGS'), do_lang_tempcode('DESCRIPTION_KEEP_BLOGS'), 'keep_blogs', $field_defaults['keep_blogs'] == '1'));

        $fields->attach(form_input_tick(do_lang_tempcode('EXTENDED_NEWS_CATEGORIES_SET'), do_lang_tempcode('DESCRIPTION_KEEP_DEFAULT_NEWS_CATEGORIES'), 'keep_news_categories', $field_defaults['keep_news_categories'] == '1'));

        return [$fields, new Tempcode()];
    }

    /**
     * Run function for setting features from the setup wizard.
     */
    public function set_fields()
    {
        if (!addon_installed('news') || post_param_integer('addon_news', null) === 0) {
            return;
        }

        $admin_groups = $GLOBALS['FORUM_DRIVER']->get_super_admin_groups();
        $groups = $GLOBALS['FORUM_DRIVER']->get_usergroup_list(false, true);
        $GLOBALS['SITE_DB']->query_delete('group_privileges', ['privilege' => 'have_personal_category', 'the_page' => 'cms_news']);
        if (post_param_integer('keep_blogs', 0) == 1) {
            foreach (array_keys($groups) as $group_id) {
                if (!in_array($group_id, $admin_groups)) {
                    $GLOBALS['SITE_DB']->query_insert('group_privileges', ['privilege' => 'have_personal_category', 'group_id' => $group_id, 'module_the_name' => '', 'category_name' => '', 'the_page' => 'cms_news', 'the_value' => 1]);
                }
            }
        }

        install_predefined_content('news', [
           'technology' => (post_param_integer('keep_news_categories', 0) == 1),
           'difficulties' => (post_param_integer('keep_news_categories', 0) == 1),
           'community' => (post_param_integer('keep_news_categories', 0) == 1),
           'entertainment' => (post_param_integer('keep_news_categories', 0) == 1),
           'business' => (post_param_integer('keep_news_categories', 0) == 1),
           'art' => (post_param_integer('keep_news_categories', 0) == 1),
        ]);
    }

    /**
     * Run function for blocks in the setup wizard.
     *
     * @return array A map between block names and pairs (BLOCK_POSITION_* constants for what is supported, then a BLOCK_POSITION_* constant for what is the default)
     */
    public function get_blocks() : array
    {
        return [
            'main_news' => [BLOCK_POSITION_MAIN, null],
            'side_news_archive' => [BLOCK_POSITION_PANEL, null],
            'side_news_categories' => [BLOCK_POSITION_PANEL, null],
            'side_news' => [BLOCK_POSITION_PANEL, null],
        ];
    }
}
