<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    setupwizard
 */

/**
 * Hook class.
 */
class Hook_admin_setupwizard_installprofiles_infosite
{
    /**
     * Get info about the installprofile.
     *
     * @return ?array Map of installprofile details (null: profile is unavailable)
     */
    public function info() : ?array
    {
        return [
            'title' => do_lang('INFOSITE'),
        ];
    }

    /**
     * Get a list of addons that are kept with this installation profile (added to the list of addons always kept).
     *
     * @return array Pair: List of addons in the profile, Separated list of ones to show under advanced
     */
    public function get_addon_list() : array
    {
        return [
            ['news', 'newsletter', 'syndication_blocks', 'quizzes', 'recommend', 'polls'],
            []
        ];
    }

    /**
     * Get a map of default settings associated with this installation profile.
     *
     * @return array Map of default settings
     */
    public function field_defaults() : array
    {
        return [
            'have_default_banners_hosting' => '0',
            'have_default_banners_donation' => '0',
            'have_default_banners_advertising' => '0',
            'have_default_catalogues_projects' => '0',
            'have_default_catalogues_faqs' => '1',
            'have_default_catalogues_links' => '0',
            'have_default_catalogues_contacts' => '0',
            'keep_personal_galleries' => '0',
            'keep_news_categories' => '1',
            'rank_set' => 'none',
            'show_content_tagging' => '1',
            'show_content_tagging_inline' => '1',
            'show_screen_actions' => '1',
            'rules' => 'balanced',
        ];
    }

    /**
     * Find details of desired blocks.
     *
     * @return array Details of what blocks are wanted
     */
    public function default_blocks() : array
    {
        return [
            BLOCK_POSITION_MAIN => [
                'main_multi_content',
                'main_rss',
                'main_quotes',
            ],
            BLOCK_POSITION_CELL => [],
            BLOCK_POSITION_PANEL => [
                'main_newsletter_signup',
                'side_calendar',
                'main_poll',
            ],
        ];
    }

    /**
     * Get options for blocks in this profile.
     *
     * @return array Details of what block options are wanted
     */
    public function block_options() : array
    {
        return [
            'side_calendar' => [
                'type' => 'listing',
            ],
            'main_rss' => [
                'param' => 'http://feeds.reuters.com/reuters/topNews',
            ],
        ];
    }

    /**
     * Execute any special code needed to put this install profile into play.
     */
    public function install_code()
    {
    }
}
