<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    banners
 */

/**
 * Hook class.
 */
class Hook_actionlog_banners extends Hook_actionlog
{
    /**
     * Get details of action log entry types handled by this hook.
     *
     * @return array Map of handler data in standard format
     */
    public function get_handlers() : array
    {
        if (!addon_installed('banners')) {
            return [];
        }

        require_lang('banners');

        return [
            'ADD_BANNER_TYPE' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'banner_type',
                'identifier_index' => 0,
                'written_context_index' => 0,
                'followup_page_links' => [
                    'EDIT_THIS_BANNER_TYPE' => '_SEARCH:cms_banners:_edit_category:{ID}',
                    'ADD_BANNER' => '_SEARCH:cms_banners:add:b_type={ID}',
                ],
            ],
            'EDIT_BANNER_TYPE' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'banner_type',
                'identifier_index' => 1,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'EDIT_THIS_BANNER_TYPE' => '_SEARCH:cms_banners:_edit_category:{ID}',
                    'ADD_BANNER' => '_SEARCH:cms_banners:add:b_type={ID}',
                ],
            ],
            'DELETE_BANNER_TYPE' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'banner_type',
                'identifier_index' => 0,
                'written_context_index' => 0,
                'followup_page_links' => [
                    'ADD_BANNER_TYPE' => '_SEARCH:cms_banners:add_category',
                ],
            ],
            'ADD_BANNER' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'banner',
                'identifier_index' => 0,
                'written_context_index' => 0,
                'followup_page_links' => [
                    'VIEW' => '_SEARCH:banners:view:source={ID}',
                    'EDIT_THIS_BANNER_TYPE' => '_SEARCH:cms_banners:_edit_category:{ID}',
                    'ADD_BANNER' => '_SEARCH:cms_banners:add:b_type={CAT,OPTIONAL}',
                ],
            ],
            'VALIDATE_BANNER' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'banner',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'VIEW' => '_SEARCH:banners:view:source={ID}',
                    'EDIT_THIS_BANNER' => '_SEARCH:cms_banners:_edit:{ID}',
                    'ADD_BANNER' => '_SEARCH:cms_banners:add:b_type={CAT,OPTIONAL}',
                ],
            ],
            'EDIT_BANNER' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'banner',
                'identifier_index' => 0,
                'written_context_index' => 0,
                'followup_page_links' => [
                    'VIEW' => '_SEARCH:banners:view:source={ID}',
                    'EDIT_THIS_BANNER' => '_SEARCH:cms_banners:_edit:{ID}',
                    'ADD_BANNER' => '_SEARCH:cms_banners:add:b_type={CAT,OPTIONAL}',
                ],
            ],
            'DELETE_BANNER' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'banner',
                'identifier_index' => 0,
                'written_context_index' => 0,
                'followup_page_links' => [
                    'ADD_BANNER' => '_SEARCH:cms_banners:add',
                ],
            ],
        ];
    }

    /**
     * Get details of action log entry types handled by this hook.
     *
     * @param  array $actionlog_row Action log row
     * @param  ?string $identifier The identifier associated with this action log entry (null: unknown / none)
     * @param  ?string $written_context The written context associated with this action log entry (null: unknown / none)
     * @param  array $bindings Default bindings
     */
    protected function get_extended_actionlog_bindings(array $actionlog_row, ?string $identifier, ?string $written_context, array &$bindings)
    {
        switch ($actionlog_row['the_type']) {
            case 'ADD_BANNER':
            case 'EDIT_BANNER':
                if ($identifier !== null) {
                    $b_type = $GLOBALS['SITE_DB']->query_select_value_if_there('banners', 'b_type', ['name' => $identifier]);
                    if ($b_type !== null) {
                        $bindings += [
                            'CAT' => $b_type,
                        ];
                    }
                }
                break;
        }
    }
}
