<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    calendar
 */

/**
 * Hook class.
 */
class Hook_actionlog_calendar extends Hook_actionlog
{
    /**
     * Get details of action log entry types handled by this hook.
     *
     * @return array Map of handler data in standard format
     */
    public function get_handlers() : array
    {
        if (!addon_installed('calendar')) {
            return [];
        }

        require_lang('calendar');

        return [
            'ADD_EVENT_TYPE' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'calendar_type',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'CALENDAR' => '_SEARCH:calendar',
                    'EDIT_THIS_EVENT_TYPE' => '_SEARCH:cms_calendar:_edit_category:{ID}',
                    'ADD_EVENT_TYPE' => '_SEARCH:cms_calendar:add_category',
                    'ADD_CALENDAR_EVENT' => '_SEARCH:cms_calendar:add:e_type={ID}',
                ],
            ],
            'EDIT_EVENT_TYPE' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'calendar_type',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'CALENDAR' => '_SEARCH:calendar',
                    'EDIT_THIS_EVENT_TYPE' => '_SEARCH:cms_calendar:_edit_category:{ID}',
                    'ADD_EVENT_TYPE' => '_SEARCH:cms_calendar:add_category',
                    'ADD_CALENDAR_EVENT' => '_SEARCH:cms_calendar:add:e_type={ID}',
                ],
            ],
            'DELETE_EVENT_TYPE' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'calendar_type',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'ADD_EVENT_TYPE' => '_SEARCH:cms_calendar:add_category',
                ],
            ],
            'ADD_CALENDAR_EVENT' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'event',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'VIEW' => '_SEARCH:calendar:view:{ID}',
                    'EDIT_THIS_CALENDAR_EVENT' => '_SEARCH:cms_calendar:_edit:{ID}',
                    'ADD_CALENDAR_EVENT' => '_SEARCH:cms_calendar:add:e_type={TYPE,OPTIONAL}',
                ],
            ],
            'EDIT_CALENDAR_EVENT' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'event',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'VIEW' => '_SEARCH:calendar:view:{ID}',
                    'EDIT_THIS_CALENDAR_EVENT' => '_SEARCH:cms_calendar:_edit:{ID}',
                    'ADD_CALENDAR_EVENT' => '_SEARCH:cms_calendar:add:e_type={TYPE,OPTIONAL}',
                ],
            ],
            'VALIDATE_CALENDAR_EVENT' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'event',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'VIEW' => '_SEARCH:calendar:view:{ID}',
                    'EDIT_THIS_CALENDAR_EVENT' => '_SEARCH:cms_calendar:_edit:{ID}',
                    'ADD_CALENDAR_EVENT' => '_SEARCH:cms_calendar:add:e_type={TYPE,OPTIONAL}',
                ],
            ],
            'DELETE_CALENDAR_EVENT' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'event',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'ADD_CALENDAR_EVENT' => '_SEARCH:cms_calendar:add',
                ],
            ],
        ];
    }

    /**
     * Get details of action log entry types handled by this hook.
     *
     * @param  array $actionlog_row Action log row
     * @param  ?string $identifier The identifier associated with this action log entry (null: unknown / none)
     * @param  ?string $written_context The written context associated with this action log entry (null: unknown / none)
     * @param  array $bindings Default bindings
     */
    protected function get_extended_actionlog_bindings(array $actionlog_row, ?string $identifier, ?string $written_context, array &$bindings)
    {
        switch ($actionlog_row['the_type']) {
            case 'ADD_CALENDAR_EVENT':
            case 'EDIT_CALENDAR_EVENT':
                if ($identifier !== null) {
                    $type_id = $GLOBALS['SITE_DB']->query_select_value_if_there('calendar_events', 'e_type', ['id' => intval($identifier)]);
                    if ($type_id !== null) {
                        $bindings += [
                            'TYPE' => strval($type_id),
                        ];
                    }
                }
                break;
        }
    }
}
