<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    cns_forum
 */

/**
 * Hook class.
 */
class Hook_actionlog_cns_forum extends Hook_actionlog
{
    /**
     * Get details of action log entry types handled by this hook.
     *
     * @return array Map of handler data in standard format
     */
    public function get_handlers() : array
    {
        if (get_forum_type() != 'cns') {
            return [];
        }

        if (!addon_installed('cns_forum')) {
            return [];
        }

        require_lang('cns');
        require_lang('cns_polls');

        return [
            'ADD_FORUM_GROUPING' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'forum_grouping',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'EDIT_THIS_FORUM_GROUPING' => '_SEARCH:admin_cns_forum_groupings:_edit:{ID}',
                    'ADD_FORUM_GROUPING' => '_SEARCH:admin_cns_forum_groupings:add',
                    'ADD_FORUM' => '_SEARCH:admin_cns_forums:add:forum_grouping_id={ID}',
                ],
            ],
            'EDIT_FORUM_GROUPING' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'forum_grouping',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'EDIT_THIS_FORUM_GROUPING' => '_SEARCH:admin_cns_forum_groupings:_edit:{ID}',
                    'ADD_FORUM_GROUPING' => '_SEARCH:admin_cns_forum_groupings:add',
                    'ADD_FORUM' => '_SEARCH:admin_cns_forums:add:forum_grouping_id={ID}',
                ],
            ],
            'DELETE_FORUM_GROUPING' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'forum_grouping',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'ADD_FORUM_GROUPING' => '_SEARCH:admin_cns_forum_groupings:add',
                    'ADD_FORUM' => '_SEARCH:admin_cns_forums:add',
                ],
            ],
            'ADD_FORUM' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'forum',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'FORUM' => '_SEARCH:forumview:browse:{ID}',
                    'EDIT_THIS_FORUM' => '_SEARCH:admin_cns_forums:_edit:{ID}',
                    'ADD_FORUM' => '_SEARCH:admin_cns_forums:add',
                ],
            ],
            'EDIT_FORUM' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'forum',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'FORUM' => '_SEARCH:forumview:browse:{ID}',
                    'EDIT_THIS_FORUM' => '_SEARCH:admin_cns_forums:_edit:{ID}',
                    'ADD_FORUM' => '_SEARCH:admin_cns_forums:add',
                ],
            ],
            'DELETE_FORUM' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'forum',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'ADD_FORUM' => '_SEARCH:admin_cns_forums:add',
                ],
            ],
            'EDIT_TOPIC' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'topic',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'VIEW_TOPIC' => '_SEARCH:topicview:browse:{ID}',
                ],
            ],
            'EDIT_TOPIC_POLL' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'topic',
                'identifier_index' => null,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'VIEW_TOPIC' => '_SEARCH:topicview:browse:{ID}',
                ],
            ],
            'DELETE_TOPIC' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'topic',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'FORUM' => '_SEARCH:forumview',
                ],
            ],
            'DELETE_TOPIC_POLL' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => null,
                'identifier_index' => null,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'VIEW_TOPIC' => '_SEARCH:topicview:browse:{TOPIC}',
                ],
            ],
            'VOTE_REVOCATION' => [
                'flags' => ACTIONLOG_FLAGS_NONE | ACTIONLOG_FLAG__USER_ACTION,
                'cma_hook' => 'topic',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'VIEW_TOPIC' => '_SEARCH:topicview:browse:{ID}',
                ],
            ],
            'MOVE_TOPICS' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'forum',
                'identifier_index' => 1,
                'written_context_index' => null,
                'followup_page_links' => [
                    'FORUM' => '_SEARCH:forumview:browse:{ID}',
                ],
            ],
            'EDIT_POST' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'post',
                'identifier_index' => 0,
                'written_context_index' => null,
                'followup_page_links' => [
                    'VIEW_TOPIC' => '_SEARCH:topicview:browse:{TOPIC}',
                    'EDIT_POST' => '_SEARCH:topics:edit_post:{ID}',
                ],
            ],
            'DELETE_POST' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'topic',
                'identifier_index' => 0,
                'written_context_index' => null,
                'followup_page_links' => [
                    'VIEW_TOPIC' => '_SEARCH:topicview:browse:{ID}',
                ],
            ],
            'DELETE_POSTS' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'topic',
                'identifier_index' => 0,
                'written_context_index' => null,
                'followup_page_links' => [
                    'VIEW_TOPIC' => '_SEARCH:topicview:browse:{ID}',
                ],
            ],
            'VALIDATE_POST' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'post',
                'identifier_index' => 0,
                'written_context_index' => null,
                'followup_page_links' => [
                    'VIEW_TOPIC' => '_SEARCH:topicview:browse:{TOPIC}',
                    'EDIT_POST' => '_SEARCH:topics:edit_post:{ID}',
                ],
            ],
            'INVALIDATE_POST' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'post',
                'identifier_index' => 0,
                'written_context_index' => null,
                'followup_page_links' => [
                    'VIEW_TOPIC' => '_SEARCH:topicview:browse:{TOPIC}',
                    'EDIT_POST' => '_SEARCH:topics:edit_post:{ID}',
                ],
            ],
            'MOVE_POSTS' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'topic',
                'identifier_index' => 0,
                'written_context_index' => null,
                'followup_page_links' => [
                    'VIEW_TOPIC' => '_SEARCH:topicview:browse:{ID}',
                ],
            ],
            'MAKE_ANONYMOUS_POST' => [
                'flags' => ACTIONLOG_FLAGS_NONE | ACTIONLOG_FLAG__USER_ACTION,
                'cma_hook' => 'post',
                'identifier_index' => 0,
                'written_context_index' => null,
                'followup_page_links' => [
                    'VIEW_TOPIC' => '_SEARCH:topicview:browse:{TOPIC}',
                    'EDIT_POST' => '_SEARCH:topics:edit_post:{ID}',
                ],
            ],
            'ADD_TOPIC' => [
                'flags' => ACTIONLOG_FLAGS_NONE | ACTIONLOG_FLAG__USER_ACTION,
                'cma_hook' => 'topic',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'VIEW_TOPIC' => '_SEARCH:topicview:browse:{ID}',
                ],
            ],
            'NEW_INLINE_PERSONAL_POST' => [
                'flags' => ACTIONLOG_FLAGS_NONE | ACTIONLOG_FLAG__USER_ACTION,
                'cma_hook' => 'post',
                'identifier_index' => 0,
                'written_context_index' => null,
                'followup_page_links' => [
                    'VIEW_TOPIC' => '_SEARCH:topicview:browse:{TOPIC}',
                    'EDIT_POST' => '_SEARCH:topics:edit_post:{ID}',
                ],
            ],
            'REPLY' => [
                'flags' => ACTIONLOG_FLAGS_NONE | ACTIONLOG_FLAG__USER_ACTION,
                'cma_hook' => 'post',
                'identifier_index' => 0,
                'written_context_index' => null,
                'followup_page_links' => [
                    'VIEW_TOPIC' => '_SEARCH:topicview:browse:{TOPIC}',
                    'EDIT_POST' => '_SEARCH:topics:edit_post:{ID}',
                ],
            ],
        ];
    }

    /**
     * Get written context for an action log entry handled by this hook.
     *
     * @param  array $actionlog_row Action log row
     * @param  array $handler_data Handler data
     * @param  ?string $identifier Identifier (null: none)
     * @return ?string Written context (null: none)
     */
    protected function get_written_context(array $actionlog_row, array $handler_data, ?string $identifier) : ?string
    {
        switch ($actionlog_row['the_type']) {
            case 'EDIT_POST':
            case 'VALIDATE_POST':
            case 'INVALIDATE_POST':
            case 'MAKE_ANONYMOUS_POST':
                $member_id = $GLOBALS['FORUM_DB']->query_select_value_if_there('f_posts', 'p_poster', ['id' => intval($actionlog_row['param_a'])]);
                if ($member_id !== null) {
                    $username = $GLOBALS['FORUM_DRIVER']->get_username($member_id);
                    if ($username === null) {
                        $username = '#' . strval($member_id);
                    }
                } else {
                    $username = do_lang('UNKNOWN');
                }

                $topic_id = $GLOBALS['FORUM_DB']->query_select_value_if_there('f_posts', 'p_topic_id', ['id' => intval($actionlog_row['param_a'])]);
                if ($topic_id !== null) {
                    $topic_title = $GLOBALS['FORUM_DB']->query_select_value_if_there('f_topics', 't_cache_first_title', ['id' => $topic_id]);
                    if ($topic_title === null) {
                        $topic_title = '#' . strval($topic_id);
                    }
                } else {
                    $topic_title = do_lang('UNKNOWN');
                }

                $written_context = do_lang('POST_BY_X_IN_Y', $username, $topic_title);
                return $written_context;

            case 'DELETE_POST':
                $topic_id = $GLOBALS['FORUM_DB']->query_select_value_if_there('f_posts', 'p_topic_id', ['id' => intval($actionlog_row['param_a'])]);
                if ($topic_id !== null) {
                    $topic_title = $GLOBALS['FORUM_DB']->query_select_value_if_there('f_topics', 't_cache_first_title', ['id' => $topic_id]);
                    if ($topic_title === null) {
                        $topic_title = '#' . strval($topic_id);
                    }
                } else {
                    $topic_title = do_lang('UNKNOWN');
                }

                $written_context = do_lang('SOMETHING_IN', '#' . $actionlog_row['param_b'], $topic_title);
                return $written_context;

            case 'DELETE_POSTS':
                $topic_id = $GLOBALS['FORUM_DB']->query_select_value_if_there('f_posts', 'p_topic_id', ['id' => intval($actionlog_row['param_a'])]);
                if ($topic_id !== null) {
                    $topic_title = $GLOBALS['FORUM_DB']->query_select_value_if_there('f_topics', 't_cache_first_title', ['id' => $topic_id]);
                    if ($topic_title === null) {
                        $topic_title = '#' . strval($topic_id);
                    }
                } else {
                    $topic_title = do_lang('UNKNOWN');
                }

                $written_context = do_lang('SOMETHING_IN', integer_format(intval($actionlog_row['param_b']), 0), $topic_title);
                return $written_context;

            case 'MOVE_POSTS':
                $topic_id = $GLOBALS['FORUM_DB']->query_select_value_if_there('f_posts', 'p_topic_id', ['id' => intval($actionlog_row['param_a'])]);
                if ($topic_id !== null) {
                    $topic_title = $GLOBALS['FORUM_DB']->query_select_value_if_there('f_topics', 't_cache_first_title', ['id' => $topic_id]);
                    if ($topic_title === null) {
                        $topic_title = '#' . strval($topic_id);
                    }
                } else {
                    $topic_title = do_lang('UNKNOWN');
                }

                $written_context = do_lang('SOMETHING_TO', integer_format(intval($actionlog_row['param_b']), 0), $topic_title);
                return $written_context;
        }

        return parent::get_written_context($actionlog_row, $handler_data, $identifier);
    }

    /**
     * Get details of action log entry types handled by this hook.
     *
     * @param  array $actionlog_row Action log row
     * @param  ?string $identifier The identifier associated with this action log entry (null: unknown / none)
     * @param  ?string $written_context The written context associated with this action log entry (null: unknown / none)
     * @param  array $bindings Default bindings
     */
    protected function get_extended_actionlog_bindings(array $actionlog_row, ?string $identifier, ?string $written_context, array &$bindings)
    {
        switch ($actionlog_row['the_type']) {
            case 'DELETE_TOPIC_POLL':
                if ($identifier !== null) {
                    $parts = explode(':', $identifier, 2);
                    if (array_key_exists(1, $parts)) {
                        $bindings += [
                            'TOPIC' => $parts[0],
                        ];
                    }
                }
                break;

            case 'EDIT_POST':
            case 'VALIDATE_POST':
            case 'INVALIDATE_POST':
            case 'MAKE_ANONYMOUS_POST':
                if ($identifier !== null) {
                    $topic_id = $GLOBALS['FORUM_DB']->query_select_value_if_there('f_posts', 'p_topic_id', ['id' => intval($identifier)]);
                    if ($topic_id !== null) {
                        $bindings += [
                            'TOPIC' => strval($topic_id),
                        ];
                    }
                }
                break;
        }
    }
}
