<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    cns_post_templates
 */

/**
 * Hook class.
 */
class Hook_actionlog_cns_post_templates extends Hook_actionlog
{
    /**
     * Get details of action log entry types handled by this hook.
     *
     * @return array Map of handler data in standard format
     */
    public function get_handlers() : array
    {
        if (get_forum_type() != 'cns') {
            return [];
        }

        if (!addon_installed('cns_post_templates')) {
            return [];
        }

        require_lang('cns_post_templates');

        return [
            'ADD_POST_TEMPLATE' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'post_template',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'EDIT_THIS_POST_TEMPLATE' => '_SEARCH:admin_cns_post_templates:_edit:{ID}',
                    'ADD_POST_TEMPLATE' => '_SEARCH:admin_cns_post_templates:add',
                ],
            ],
            'EDIT_POST_TEMPLATE' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'post_template',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'EDIT_THIS_POST_TEMPLATE' => '_SEARCH:admin_cns_post_templates:_edit:{ID}',
                    'ADD_POST_TEMPLATE' => '_SEARCH:admin_cns_post_templates:add',
                ],
            ],
            'DELETE_POST_TEMPLATE' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'post_template',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'ADD_POST_TEMPLATE' => '_SEARCH:admin_cns_post_templates:add',
                ],
            ],
            'IMPORT_STOCK_RESPONSES_PT' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => null,
                'identifier_index' => null,
                'written_context_index' => null,
                'followup_page_links' => [
                    'POST_TEMPLATES' => '_SEARCH:admin_cns_post_templates',
                ],
            ],
        ];
    }
}
