<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    cns_warnings
 */

/**
 * Hook class.
 */
class Hook_actionlog_cns_warnings extends Hook_actionlog
{
    /**
     * Get details of action log entry types handled by this hook.
     *
     * @return array Map of handler data in standard format
     */
    public function get_handlers() : array
    {
        if (get_forum_type() != 'cns') {
            return [];
        }

        if (!addon_installed('cns_warnings')) {
            return [];
        }

        require_lang('cns_warnings');

        return [
            'ADD_WARNING' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => null,
                'identifier_index' => 0,
                'written_context_index' => null,
                'followup_page_links' => [
                    'VIEW_PROFILE' => '_SEARCH:members:view:{1}',
                    'VIEW_WARNING' => '_SEARCH:warnings:view:{ID}'
                ],
            ],
            'EDIT_WARNING' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => null,
                'identifier_index' => 0,
                'written_context_index' => null,
                'followup_page_links' => [
                    'VIEW_PROFILE' => '_SEARCH:members:view:{1}',
                    'VIEW_WARNING' => '_SEARCH:warnings:view:{ID}'
                ],
            ],
            'DELETE_WARNING' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => null,
                'identifier_index' => 0,
                'written_context_index' => null,
                'followup_page_links' => [
                    'VIEW_PROFILE' => '_SEARCH:members:view:{1}',
                    'VIEW_WARNING' => '_SEARCH:warnings:view:{ID}'
                ],
            ],
            'MARK_AS_SPAMMER' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'VIEW_PROFILE' => '_SEARCH:members:view:{ID}',
                ],
            ],
            'START_PROBATION' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'VIEW_PROFILE' => '_SEARCH:members:view:{ID}',
                ],
            ],
            'STOP_PROBATION' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'VIEW_PROFILE' => '_SEARCH:members:view:{ID}',
                ],
            ],
            'EXTEND_PROBATION' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'VIEW_PROFILE' => '_SEARCH:members:view:{ID}',
                ],
            ],
            'REDUCE_PROBATION' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'VIEW_PROFILE' => '_SEARCH:members:view:{ID}',
                ],
            ],
            'SILENCE_FROM_FORUM' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => null,
                'followup_page_links' => [
                    'VIEW_PROFILE' => '_SEARCH:members:view:{ID}',
                    'FORUM' => '_SEARCH:forumview:browse:{1}',
                ],
            ],
            'UNSILENCE_FORUM' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => null,
                'followup_page_links' => [
                    'VIEW_PROFILE' => '_SEARCH:members:view:{ID}',
                    'FORUM' => '_SEARCH:forumview:browse:{1}',
                ],
            ],
            'SILENCE_FROM_TOPIC' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => null,
                'followup_page_links' => [
                    'VIEW_PROFILE' => '_SEARCH:members:view:{ID}',
                    'VIEW_TOPIC' => '_SEARCH:topicview:browse:{1}',
                ],
            ],
            'UNSILENCE_TOPIC' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => null,
                'followup_page_links' => [
                    'VIEW_PROFILE' => '_SEARCH:members:view:{ID}',
                    'VIEW_TOPIC' => '_SEARCH:topicview:browse:{1}',
                ],
            ],
            'GROUP_CHANGE' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => null,
                'followup_page_links' => [
                    'VIEW_PROFILE' => '_SEARCH:members:view:{ID}',
                    'USERGROUP' => '_SEARCH:groups:view:{1}',
                ],
            ],
            'UNDO_GROUP_CHANGE' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'VIEW_PROFILE' => '_SEARCH:members:view:{ID}',
                ],
            ],
            'REVIEW_WARNING_HISTORY' => [
                'flags' => ACTIONLOG_FLAG__GDPR,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'VIEW_PROFILE' => '_SEARCH:members:view:{ID}',
                    'MEMBERS' => '_SEARCH:admin_cns_members',
                ],
            ],
        ];
    }

    /**
     * Get written context for an action log entry handled by this hook.
     *
     * @param  array $actionlog_row Action log row
     * @param  array $handler_data Handler data
     * @param  ?string $identifier Identifier (null: none)
     * @return ?string Written context (null: none)
     */
    protected function get_written_context(array $actionlog_row, array $handler_data, ?string $identifier) : ?string
    {
        switch ($actionlog_row['the_type']) {
            case 'ADD_WARNING':
            case 'EDIT_WARNING':
            case 'DELETE_WARNING':
                require_lang('cns_warnings');

                $written_context = $GLOBALS['FORUM_DRIVER']->get_username(intval($actionlog_row['param_b']));
                if ($written_context === null) {
                    return do_lang('WARNING_NUMBER', $actionlog_row['param_a']);
                } else {
                    $written_context .= ' ' . do_lang('WARNING_NUMBER', $actionlog_row['param_a']);
                }
                return $written_context;

            case 'SILENCE_FROM_FORUM':
            case 'UNSILENCE_FORUM':
                require_lang('cns_warnings');

                $username = $GLOBALS['FORUM_DRIVER']->get_username(intval($actionlog_row['param_a']));
                if ($username === null) {
                    $username = '#' . $actionlog_row['param_b'];
                }

                $forum_name = $GLOBALS['FORUM_DB']->query_select_value_if_there('f_forums', 'f_name', ['id' => intval($actionlog_row['param_b'])]);
                if ($forum_name === null) {
                    $forum_name = '#' . $actionlog_row['param_b'];
                }

                $silence_until = $GLOBALS['FORUM_DB']->query_select_value_if_there('member_privileges', 'active_until', [
                    'member_id' => intval($actionlog_row['param_a']),
                    'privilege' => 'submit_midrange_content',
                    'the_page' => '',
                    'module_the_name' => 'forums',
                    'category_name' => strval($actionlog_row['param_b']),
                    'the_value' => '0'
                ], 'ORDER BY active_until DESC');
                if ($silence_until !== null) {
                    $silence_until = do_lang('PUNITIVE_SILENCED_UNTIL', get_timezoned_date_time($silence_until, false, false, get_member()));
                } else {
                    $silence_until = do_lang('PUNITIVE_SILENCE_EXPIRED');
                }

                $written_context = do_lang('SOMETHING_TO', $username, $forum_name) . ' ' . $silence_until;
                return $written_context;

            case 'SILENCE_FROM_TOPIC':
            case 'UNSILENCE_TOPIC':
                require_lang('cns_warnings');

                $username = $GLOBALS['FORUM_DRIVER']->get_username(intval($actionlog_row['param_a']));
                if ($username === null) {
                    $username = '#' . $actionlog_row['param_b'];
                }

                $topic_title = $GLOBALS['FORUM_DB']->query_select_value_if_there('f_topics', 't_cache_first_title', ['id' => intval($actionlog_row['param_b'])]);
                if ($topic_title === null) {
                    $topic_title = '#' . $actionlog_row['param_b'];
                }

                $silence_until = $GLOBALS['FORUM_DB']->query_select_value_if_there('member_privileges', 'active_until', [
                    'member_id' => intval($actionlog_row['param_a']),
                    'privilege' => 'submit_lowrange_content',
                    'the_page' => '',
                    'module_the_name' => 'topics',
                    'category_name' => strval($actionlog_row['param_b']),
                ], 'ORDER BY active_until DESC');
                if ($silence_until !== null) {
                    $silence_until = do_lang('PUNITIVE_SILENCED_UNTIL', get_timezoned_date_time($silence_until, false, false, get_member()));
                } else {
                    $silence_until = do_lang('PUNITIVE_SILENCE_EXPIRED');
                }

                $written_context = do_lang('SOMETHING_TO', $username, $topic_title) . ' ' . $silence_until;
                return $written_context;
        }

        return parent::get_written_context($actionlog_row, $handler_data, $identifier);
    }
}
