<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    points
 */

/**
 * Hook class.
 */
class Hook_actionlog_points extends Hook_actionlog
{
    /**
     * Get details of action log entry types handled by this hook.
     *
     * @return array Map of handler data in standard format
     */
    public function get_handlers() : array
    {
        if (!addon_installed('points')) {
            return [];
        }

        require_lang('points');

        return [
            'UNDO_CHARGE' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'VIEW_PROFILE' => ['FORUM_DRIVER__PROFILE_URL', '{ID}'],
                    'POINTS_LEDGER' => '_SEARCH:admin_points',
                ],
            ],
            'REVERSE_TRANSACTION' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    '_VIEW_POINT_TRANSACTION' => '_SEARCH:admin_points:view:{ID}',
                    'POINTS_LEDGER' => '_SEARCH:admin_points',
                ],
            ],
            'AMEND_POINT_TRANSACTION' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    '_VIEW_POINT_TRANSACTION' => '_SEARCH:admin_points:view:{ID}',
                    'POINTS_LEDGER' => '_SEARCH:admin_points',
                ],
            ],
            'LOG_ESCROW_CREATED' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'ESCROW_VIEW' => '_SEARCH:points:view_escrow:{ID}',
                ],
            ],
            'LOG_ESCROW_SATISFIED' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'ESCROW_VIEW' => '_SEARCH:points:view_escrow:{ID}',
                ],
            ],
            'LOG_ESCROW_COMPLETED' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'ESCROW_VIEW' => '_SEARCH:points:view_escrow:{ID}',
                ],
            ],
            'LOG_ESCROW_DISPUTED' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'ESCROW_VIEW' => '_SEARCH:points:view_escrow:{ID}',
                ],
            ],
            'LOG_ESCROW_CANCELLED' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'ESCROW_VIEW' => '_SEARCH:points:view_escrow:{ID}',
                ],
            ],
            'LOG_ESCROW_AMENDED' => [
                'flags' => ACTIONLOG_FLAGS_NONE,
                'cma_hook' => 'member',
                'identifier_index' => 0,
                'written_context_index' => 1,
                'followup_page_links' => [
                    'ESCROW_VIEW' => '_SEARCH:points:view_escrow:{ID}',
                ],
            ],
        ];
    }
}
