<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    chat
 */

/**
 * Hook class.
 */
class Hook_addon_registry_chat
{
    /**
     * Get a list of file permissions to set.
     *
     * @param  boolean $runtime Whether to include wildcards represented runtime-created chmoddable files
     * @return array File permissions to set
     */
    public function get_chmod_array(bool $runtime = false) : array
    {
        $chmod = [];
        if ($runtime) {
            $chmod = array_merge(
                $chmod,
                [
                    'data_custom/modules/chat/*.bin',
                    'uploads/personal_sound_effects/*',
                ]
            );
        }
        $chmod = array_merge(
            $chmod,
            [
                'data_custom/modules/chat',
                'uploads/personal_sound_effects',
            ]
        );
        return $chmod;
    }

    /**
     * Get the version of Composr this addon is for (used in generating the TAR filename).
     *
     * @return float Version number
     */
    public function get_version() : float
    {
        return cms_version_number();
    }

    /**
     * Get the minimum required version of the website software needed to use this addon.
     *
     * @return float Minimum required website software version
     */
    public function get_min_cms_version() : float
    {
        return 11.0;
    }

    /**
     * Get the maximum compatible version of the website software to use this addon.
     *
     * @return ?float Maximum compatible website software version (null: no maximum version currently)
     */
    public function get_max_cms_version() : ?float
    {
        return null;
    }

    /**
     * Get the addon category.
     *
     * @return string The category
     */
    public function get_category() : string
    {
        return 'Community';
    }

    /**
     * Get the description of the addon.
     *
     * @return string Description of the addon
     */
    public function get_description() : string
    {
        return 'Chatrooms and instant messaging.';
    }

    /**
     * Get a list of tutorials that apply to this addon.
     *
     * @return array List of tutorials
     */
    public function get_applicable_tutorials() : array
    {
        return [
            'tut_chat',
        ];
    }

    /**
     * Get a mapping of dependency types.
     *
     * @return array A structure specifying dependency information
     */
    public function get_dependencies() : array
    {
        return [
            'requires' => [],
            'recommends' => [],
            'conflicts_with' => [],
        ];
    }

    /**
     * Explicitly say which icon should be used.
     *
     * @return URLPATH Icon
     */
    public function get_default_icon() : string
    {
        return 'themes/default/images/icons/menu/social/chat/chat.svg';
    }

    /**
     * Get a list of files that belong to this addon.
     *
     * @return array List of files
     */
    public function get_file_list() : array
    {
        return [
            'adminzone/pages/modules/admin_chat.php',
            'cms/pages/modules/cms_chat.php',
            'data/sounds/contact_off.mp3',
            'data/sounds/contact_on.mp3',
            'data/sounds/error.mp3',
            'data/sounds/invited.mp3',
            'data/sounds/message_initial.mp3',
            'data/sounds/message_sent.mp3',
            'data/sounds/you_connect.mp3',
            'data_custom/modules/chat/.htaccess',
            'data_custom/modules/chat/index.html',
            'lang/EN/chat.ini',
            'site/download_chat_logs.php',
            'site/messages.php',
            'site/pages/comcode/EN/popup_blockers.txt',
            'site/pages/comcode/EN/userguide_chatcode.txt',
            'site/pages/modules/chat.php',
            'sources/blocks/main_friends_list.php',
            'sources/blocks/side_friends.php',
            'sources/blocks/side_shoutbox.php',
            'sources/chat.php',
            'sources/chat2.php',
            'sources/chat_lobby.php',
            'sources/chat_logs.php',
            'sources/chat_poller.php',
            'sources/chat_sounds.php',
            'sources/chat_stats.php',
            'sources/hooks/blocks/side_stats/chat.php',
            'sources/hooks/modules/admin_import_types/chat.php',
            'sources/hooks/modules/admin_setupwizard/chat.php',
            'sources/hooks/modules/admin_themewizard/chat.php',
            'sources/hooks/modules/chat_bots/.htaccess',
            'sources/hooks/modules/chat_bots/default.php',
            'sources/hooks/modules/chat_bots/index.html',
            'sources/hooks/modules/members/chat.php',
            'sources/hooks/systems/actionlog/chat.php',
            'sources/hooks/systems/addon_registry/chat.php',
            'sources/hooks/systems/block_ui_renderers/chat.php',
            'sources/hooks/systems/commandr_commands/send_chatmessage.php',
            'sources/hooks/systems/commandr_fs/chat.php',
            'sources/hooks/systems/commandr_fs_extended_member/chat_blocking.php',
            'sources/hooks/systems/commandr_fs_extended_member/chat_friends.php',
            'sources/hooks/systems/commandr_fs_extended_member/chat_sound_effects.php',
            'sources/hooks/systems/config/chat_default_post_colour.php',
            'sources/hooks/systems/config/chat_default_post_font.php',
            'sources/hooks/systems/config/chat_flood_timelimit.php',
            'sources/hooks/systems/config/chat_max_messages_to_show.php',
            'sources/hooks/systems/config/chat_message_check_interval.php',
            'sources/hooks/systems/config/chat_message_direction.php',
            'sources/hooks/systems/config/chat_private_room_deletion_time.php',
            'sources/hooks/systems/config/chat_show_stats_count_messages.php',
            'sources/hooks/systems/config/chat_show_stats_count_rooms.php',
            'sources/hooks/systems/config/chat_show_stats_count_users.php',
            'sources/hooks/systems/config/chat_transitory_alert_time.php',
            'sources/hooks/systems/config/group_private_chatrooms.php',
            'sources/hooks/systems/config/max_chat_lobby_friends.php',
            'sources/hooks/systems/config/points_chat.php',
            'sources/hooks/systems/config/sitewide_im.php',
            'sources/hooks/systems/content_meta_aware/chat.php',
            'sources/hooks/systems/notifications/chat.php',
            'sources/hooks/systems/page_groupings/chat.php',
            'sources/hooks/systems/points/chat_message__add.php',
            'sources/hooks/systems/privacy/chat.php',
            'sources/hooks/systems/profiles_tabs/friends.php',
            'sources/hooks/systems/realtime_rain/chat.php',
            'sources/hooks/systems/rss/chat.php',
            'sources/hooks/systems/sitemap/chat.php',
            'sources/hooks/systems/snippets/im_friends_rejig.php',
            'sources/hooks/systems/startup/im.php',
            'sources/hooks/systems/symbols/CHAT_IM.php',
            'sources_custom/hooks/modules/chat_bots/.htaccess',
            'sources_custom/hooks/modules/chat_bots/index.html',
            'themes/default/css/chat.css',
            'themes/default/images/EN/chatcode_editor/index.html',
            'themes/default/images/EN/chatcode_editor/invite.svg',
            'themes/default/images/EN/chatcode_editor/new_room.svg',
            'themes/default/images/EN/chatcode_editor/private_message.svg',
            'themes/default/images/icons/buttons/sound_effects.svg',
            'themes/default/images/icons/menu/social/chat/chat.svg',
            'themes/default/images/icons/menu/social/chat/chatroom_add.svg',
            'themes/default/images/icons/menu/social/chat/index.html',
            'themes/default/images/icons/menu/social/chat/member_blocking.svg',
            'themes/default/images/icons/menu/social/chat/sound.svg',
            'themes/default/images/icons/menu/social/friends.svg',
            'themes/default/images/icons_monochrome/buttons/sound_effects.svg',
            'themes/default/images/icons_monochrome/menu/social/chat/chat.svg',
            'themes/default/images/icons_monochrome/menu/social/chat/chatroom_add.svg',
            'themes/default/images/icons_monochrome/menu/social/chat/index.html',
            'themes/default/images/icons_monochrome/menu/social/chat/member_blocking.svg',
            'themes/default/images/icons_monochrome/menu/social/chat/sound.svg',
            'themes/default/images/icons_monochrome/menu/social/friends.svg',
            'themes/default/javascript/chat.js',
            'themes/default/templates/BLOCK_MAIN_FRIENDS_LIST.tpl',
            'themes/default/templates/BLOCK_SIDE_FRIENDS.tpl',
            'themes/default/templates/BLOCK_SIDE_SHOUTBOX.tpl',
            'themes/default/templates/BLOCK_SIDE_SHOUTBOX_MESSAGE.tpl',
            'themes/default/templates/CHATCODE_EDITOR_BUTTON.tpl',
            'themes/default/templates/CHATCODE_EDITOR_MICRO_BUTTON.tpl',
            'themes/default/templates/CHAT_FRIENDS.tpl',
            'themes/default/templates/CHAT_INVITE.tpl',
            'themes/default/templates/CHAT_LOBBY_IM_AREA.tpl',
            'themes/default/templates/CHAT_LOBBY_IM_PARTICIPANT.tpl',
            'themes/default/templates/CHAT_LOBBY_SCREEN.tpl',
            'themes/default/templates/CHAT_MESSAGE.tpl',
            'themes/default/templates/CHAT_MODERATE_SCREEN.tpl',
            'themes/default/templates/CHAT_PRIVATE.tpl',
            'themes/default/templates/CHAT_ROOM_SCREEN.tpl',
            'themes/default/templates/CHAT_SET_EFFECTS_SCREEN.tpl',
            'themes/default/templates/CHAT_SET_EFFECTS_SETTING_BLOCK.tpl',
            'themes/default/templates/CHAT_SITEWIDE_IM.tpl',
            'themes/default/templates/CHAT_SITEWIDE_IM_POPUP.tpl',
            'themes/default/templates/CHAT_SOUND.tpl',
            'themes/default/templates/CHAT_STAFF_ACTIONS.tpl',
            'themes/default/templates/CNS_MEMBER_PROFILE_FRIENDS.tpl',
            'uploads/personal_sound_effects/.htaccess',
            'uploads/personal_sound_effects/index.html',
        ];
    }

    /**
     * Get mapping between template names and the method of this class that can render a preview of them.
     *
     * @return array The mapping
     */
    public function tpl_previews() : array
    {
        return [
            'templates/CHAT_MODERATE_SCREEN.tpl' => 'administrative__chat_moderate_screen',
            'templates/BLOCK_SIDE_SHOUTBOX_MESSAGE.tpl' => 'block_side_shoutbox',
            'templates/BLOCK_SIDE_SHOUTBOX.tpl' => 'block_side_shoutbox',
            'templates/CHAT_MESSAGE.tpl' => 'chat_message',
            'templates/CHAT_STAFF_ACTIONS.tpl' => 'chat_message',
            'templates/CHAT_PRIVATE.tpl' => 'chat_private',
            'templates/CHAT_INVITE.tpl' => 'chat_invite',
            'templates/CHAT_SOUND.tpl' => 'chat_lobby_screen',
            'templates/CHAT_LOBBY_IM_AREA.tpl' => 'chat_lobby_screen',
            'templates/CHAT_SITEWIDE_IM_POPUP.tpl' => 'chat_sitewide_im_popup',
            'templates/CHAT_LOBBY_IM_PARTICIPANT.tpl' => 'chat_lobby_screen',
            'templates/CHAT_SITEWIDE_IM.tpl' => 'chat_sitewide_im',
            'templates/CHAT_LOBBY_SCREEN.tpl' => 'chat_lobby_screen',
            'templates/CHATCODE_EDITOR_BUTTON.tpl' => 'chat_room_screen',
            'templates/CHATCODE_EDITOR_MICRO_BUTTON.tpl' => 'chat_room_screen',
            'templates/COMCODE_EDITOR_MICRO_BUTTON.tpl' => 'chat_room_screen',
            'templates/CHAT_ROOM_SCREEN.tpl' => 'chat_room_screen',
            'templates/CHAT_SET_EFFECTS_SETTING_BLOCK.tpl' => 'chat_set_effects_screen',
            'templates/CHAT_SET_EFFECTS_SCREEN.tpl' => 'chat_set_effects_screen',
            'templates/BLOCK_MAIN_FRIENDS_LIST.tpl' => 'cns_member_profile_friends',
            'templates/CNS_MEMBER_PROFILE_FRIENDS.tpl' => 'cns_member_profile_friends',
            'templates/CHAT_FRIENDS.tpl' => 'chat_lobby_screen',
            'templates/BLOCK_SIDE_FRIENDS.tpl' => 'block_side_friends',
        ];
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__cns_member_profile_friends() : object
    {
        if (get_forum_type() != 'cns') {
            return do_lorem_template('RED_ALERT', ['TEXT' => do_lang_tempcode('NO_CNS')]);
        }

        require_lang('cns');
        require_css('cns');

        $friend_map = [
            'USERGROUP' => lorem_phrase(),
            'USERNAME' => lorem_phrase(),
            'URL' => placeholder_url(),
            'F_ID' => placeholder_numeric_id(),
            'BOX' => placeholder_table(),
        ];
        $friends_arr = [];
        $friends_arr[] = $friend_map;

        $friends = do_lorem_template('BLOCK_MAIN_FRIENDS_LIST', [
            'BLOCK_ID' => lorem_word(),

            'FRIENDS_MUTUAL' => $friends_arr,
            'FRIENDS_NONMUTUAL' => $friends_arr,
            'FRIENDS_FORWARD' => $friends_arr,
            'EXTRA_GET_PARAMS' => '',
            'PAGINATION' => placeholder_pagination(),
            'BLOCK_PARAMS' => '',
            'MEMBER_ID' => placeholder_numeric_id(),

            'START' => '0',
            'MAX' => '10',
            'START_PARAM' => 'x_start',
            'MAX_PARAM' => 'x_max',
        ]);

        return lorem_globalise(do_lorem_template('CNS_MEMBER_PROFILE_FRIENDS', [
            'MEMBER_ID' => placeholder_numeric_id(),
            'ADD_FRIEND_URL' => placeholder_url(),
            'REMOVE_FRIEND_URL' => placeholder_url(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__chat_moderate_screen() : object
    {
        return lorem_globalise(do_lorem_template('CHAT_MODERATE_SCREEN', [
            'URL' => placeholder_url(),
            'TITLE' => lorem_screen_title(),
            'INTRODUCTION' => lorem_phrase(),
            'CONTENT' => placeholder_table(),
            'LINKS' => placeholder_array(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__chat_message() : object
    {
        if (addon_installed('securitylogging')) {
            require_lang('submitban');
        }

        $chat_actions = do_lorem_template('CHAT_STAFF_ACTIONS', [
            'CHAT_BAN_URL' => placeholder_url(),
            'CHAT_UNBAN_URL' => placeholder_url(),
            'EDIT_URL' => placeholder_url(),
            'BAN_URL' => addon_installed('securitylogging') ? placeholder_url() : '',
        ]);

        return lorem_globalise(do_lorem_template('CHAT_MESSAGE', [
            'SYSTEM_MESSAGE' => lorem_phrase(),
            'STAFF' => '1',
            'OLD_MESSAGES' => lorem_phrase(),
            'AVATAR_URL' => placeholder_avatar(),
            'STAFF_ACTIONS' => $chat_actions,
            'MEMBER_LINK' => lorem_word(),
            'MEMBER_ID' => placeholder_numeric_id(),
            'MESSAGE' => lorem_phrase(),
            'DATE' => placeholder_date(),
            '_TIME' => placeholder_date_raw(),
            'FONT_COLOUR' => '#0000FF',
            'FONT_FACE' => 'Arial',
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__chat_private() : object
    {
        return lorem_globalise(do_lorem_template('CHAT_PRIVATE', [
            'SYSTEM_MESSAGE' => lorem_phrase(),
            'MESSAGE' => lorem_phrase_html(),
            'USERNAME' => lorem_word(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__chat_invite() : object
    {
        return lorem_globalise(do_lorem_template('CHAT_INVITE', [
            'USERNAME' => lorem_word(),
            'CHATROOM' => lorem_phrase(),
            'LINK' => placeholder_link(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_side_shoutbox() : object
    {
        $tpl = do_lorem_template('BLOCK_SIDE_SHOUTBOX_MESSAGE', [
            'MEMBER_ID' => placeholder_first_admin_id(),
            'MEMBER_URL' => placeholder_url(),
            'MEMBER_LINK' => placeholder_link(),
            'MESSAGE' => lorem_phrase(),
            '_TIME' => placeholder_date_raw(),
            'DATE' => placeholder_date(),
        ]);

        return lorem_globalise(do_lorem_template('BLOCK_SIDE_SHOUTBOX', [
            'BLOCK_ID' => lorem_word(),
            'CHATROOM_ID' => strval(db_get_first_id()),
            'NUM_MESSAGES' => placeholder_number(),
            'LAST_MESSAGE_ID' => placeholder_numeric_id(),
            'MESSAGES' => $tpl,
            'URL' => placeholder_url(),
            'BLOCK_PARAMS' => '',
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__chat_sitewide_im() : object
    {
        $sound_effects = [];
        foreach (placeholder_array() as $k => $v) {
            $sound_effects[] = [
                'KEY' => $v,
                'VALUE' => lorem_word_2(),
            ];
        }
        $chat_sound = do_lorem_template('CHAT_SOUND', [
            'SOUND_EFFECTS' => $sound_effects,
        ]);

        $im_area_template = do_lorem_template('CHAT_LOBBY_IM_AREA', [
            'MESSAGES_PHP' => find_script('messages'),
            'CHATROOM_ID' => '__room_id__',
        ]);

        $im_participant_template = do_lorem_template('CHAT_LOBBY_IM_PARTICIPANT', [
            'PROFILE_URL' => placeholder_url(),
            'ID' => '__id__',
            'CHATROOM_ID' => '__room_id__',
            'USERNAME' => '__username__',
            'ONLINE' => '__online__',
            'AVATAR_URL' => '__avatar_url__',
            'MAKE_FRIEND_URL' => placeholder_url(),
            'BLOCK_MEMBER_URL' => placeholder_url(),
        ]);

        return lorem_globalise(do_lorem_template('CHAT_SITEWIDE_IM', [
            'IM_AREA_TEMPLATE' => $im_area_template,
            'IM_PARTICIPANT_TEMPLATE' => $im_participant_template,
            'CHAT_SOUND' => $chat_sound,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_side_friends() : object
    {
        $friends = [];
        foreach (placeholder_array() as $key => $friend) {
            $friends[] = [
                'DATE_RAW' => placeholder_date_raw(),
                'DATE' => placeholder_date(),
                'MEMBER_PROFILE_URL' => placeholder_url(),
                'MEMBER_ID' => strval($key),
                'USERNAME' => lorem_word(),
                'ONLINE_TEXT' => lorem_phrase(),
                'ONLINE' => false,
            ];
        }

        $friends_tpl = do_lorem_template('CHAT_FRIENDS', [
            'FRIENDS_ONLINE' => $friends,
            'FRIENDS_OFFLINE' => $friends,
            'FRIENDS' => $friends,
            'CAN_IM' => true,
            'ONLINE_URL' => placeholder_url(),
            'SIMPLER' => true,
        ]);

        return lorem_globalise(do_lorem_template('BLOCK_SIDE_FRIENDS', [
            'BLOCK_ID' => lorem_word(),
            'FRIENDS' => $friends_tpl,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__chat_lobby_screen() : object
    {
        $sound_effects = [];
        foreach (placeholder_array() as $k => $v) {
            $sound_effects[] = [
                'KEY' => $v,
                'VALUE' => lorem_word_2(),
            ];
        }
        $chat_sound = do_lorem_template('CHAT_SOUND', [
            'SOUND_EFFECTS' => $sound_effects,
        ]);

        $im_area_template = do_lorem_template('CHAT_LOBBY_IM_AREA', [
            'MESSAGES_PHP' => find_script('messages'),
            'CHATROOM_ID' => '__room_id__',
        ]);

        $im_participant_template = do_lorem_template('CHAT_LOBBY_IM_PARTICIPANT', [
            'PROFILE_URL' => placeholder_url(),
            'ID' => '__id__',
            'CHATROOM_ID' => '__room_id__',
            'USERNAME' => '__username__',
            'ONLINE' => '__online__',
            'AVATAR_URL' => '__avatar_url__',
            'MAKE_FRIEND_URL' => placeholder_url(),
            'BLOCK_MEMBER_URL' => placeholder_url(),
        ]);

        $chatrooms = [];

        foreach (placeholder_array() as $key => $room) {
            $users = [
                '1' => 'Guest',
                '2' => 'admin',
            ];

            $usernames = new Tempcode();

            foreach ($users as $user) {
                $usernames->attach(do_lorem_template('CNS_USER_MEMBER', [
                    'FIRST' => $usernames->is_empty(),
                    'PROFILE_URL' => placeholder_url(),
                    'USERNAME' => $user,
                    'MEMBER_ID' => placeholder_numeric_id(),
                    'COLOUR' => 'black',
                    'AT' => lorem_phrase(),
                ]));
            }

            $chatrooms[] = [
                'PRIVATE' => true,
                'ID' => strval($key),
                'NAME' => $room,
                'USERNAMES' => $usernames,
                'URL' => placeholder_url(),
            ];
        }

        $friends = [];
        foreach (placeholder_array() as $key => $friend) {
            $friends[] = [
                'DATE_RAW' => placeholder_date_raw(),
                'DATE' => placeholder_date(),
                'MEMBER_PROFILE_URL' => placeholder_url(),
                'MEMBER_ID' => strval($key),
                'USERNAME' => lorem_word(),
                'ONLINE_TEXT' => lorem_phrase(),
                'ONLINE' => false,
            ];
        }

        $friends_tpl = do_lorem_template('CHAT_FRIENDS', [
            'FRIENDS_ONLINE' => $friends,
            'FRIENDS_OFFLINE' => $friends,
            'FRIENDS' => $friends,
            'CAN_IM' => true,
            'ONLINE_URL' => placeholder_url(),
            'SIMPLER' => false,
        ]);

        return lorem_globalise(do_lorem_template('CHAT_LOBBY_SCREEN', [
            'TITLE' => lorem_screen_title(),
            'MESSAGE' => lorem_phrase(),
            'CHAT_SOUND' => $chat_sound,
            'IM_PARTICIPANT_TEMPLATE' => $im_participant_template,
            'IM_AREA_TEMPLATE' => $im_area_template,
            'CAN_IM' => true,
            'FRIENDS' => $friends_tpl,
            'URL_ADD_FRIEND' => placeholder_url(),
            'URL_REMOVE_FRIENDS' => placeholder_url(),
            'CHATROOMS' => $chatrooms,
            'PRIVATE_CHATROOM' => placeholder_link(),
            'MOD_LINK' => placeholder_link(),
            'BLOCKING_LINK' => placeholder_link(),
            'SETEFFECTS_LINK' => placeholder_link(),
            'ADD_CHATROOM_URL' => placeholder_url(),
            'MEMBER_ID' => placeholder_numeric_id(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__chat_room_screen() : object
    {
        require_lang('comcode');
        require_javascript('chat');

        $sound_effects = [];
        foreach (placeholder_array() as $k => $v) {
            $sound_effects[] = [
                'KEY' => $v,
                'VALUE' => lorem_word_2(),
            ];
        }
        $chat_sound = do_lorem_template('CHAT_SOUND', [
            'SOUND_EFFECTS' => $sound_effects,
        ]);

        $_buttons = [
            'private_message',
            'invite',
            'new_room'
        ];

        $buttons = new Tempcode();
        foreach ($_buttons as $button) {
            $buttons->attach(do_lorem_template('CHATCODE_EDITOR_BUTTON', [
                'TITLE' => do_lang_tempcode('INPUT_CHATCODE_' . $button),
                'B' => $button,
            ]));
        }

        $micro_buttons = new Tempcode();
        $_micro_buttons = [
            'b',
            'i'
        ];

        $micro_buttons->attach(do_lorem_template('CHATCODE_EDITOR_MICRO_BUTTON', [
            'TITLE' => lorem_phrase(),
            'B' => 'new_room',
        ]));

        foreach ($_micro_buttons as $button) {
            $micro_buttons->attach(do_lorem_template('COMCODE_EDITOR_MICRO_BUTTON', [
                'FIELD_NAME' => 'post',
                'TITLE' => do_lang_tempcode('INPUT_COMCODE_' . $button),
                'B' => $button,
                'IS_POSTING_FIELD' => false,
            ]));
        }

        $users = [
            '1' => 'Guest',
            '2' => 'admin',
        ];

        $usernames = new Tempcode();
        foreach ($users as $user) {
            $usernames->attach(do_lorem_template('CNS_USER_MEMBER', [
                'FIRST' => $usernames->is_empty(),
                'PROFILE_URL' => placeholder_url(),
                'USERNAME' => $user,
                'MEMBER_ID' => placeholder_numeric_id(),
                'COLOUR' => 'black',
                'AT' => lorem_phrase(),
            ]));
        }

        return lorem_globalise(do_lorem_template('CHAT_ROOM_SCREEN', [
            'CHATTERS' => $usernames,
            'CHAT_SOUND' => $chat_sound,
            'CHATROOM_ID' => placeholder_number(),
            'DEBUG' => '0',
            'MESSAGES_PHP' => find_script('messages'),
            'CHATROOM_NAME' => lorem_word(),
            'MICRO_BUTTONS' => $micro_buttons,
            'BUTTONS' => $buttons,
            'YOUR_NAME' => lorem_word(),
            'MESSAGES_URL' => placeholder_url(),
            'POSTING_URL' => placeholder_url(),
            'OPTIONS_URL' => placeholder_url(),
            'SUBMIT_VALUE' => lorem_word(),
            'INTRODUCTION' => '',
            'TITLE' => lorem_screen_title(),
            'LINKS' => ['admin/edit2' => placeholder_link(), 'checklist/toggle' => placeholder_link()],
            'TEXT_COLOUR_DEFAULT' => lorem_word(),
            'FONT_NAME_DEFAULT' => 'Tahoma',
            'CHATCODE_HELP' => placeholder_url(),
            'COMCODE_HELP' => placeholder_url(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__chat_set_effects_screen() : object
    {
        require_javascript('checking');
        require_javascript('plupload');

        require_css('forms');

        $setting_blocks = new Tempcode();
        foreach (placeholder_array() as $member_id => $values) {
            $effects = [];
            foreach (placeholder_array() as $k => $v) {
                $effects[] = [
                    'KEY' => strval($k),
                    'VALUE' => $v,
                    'MEMBER_ID' => strval($member_id),
                    'USERNAME' => lorem_phrase(),
                    'EFFECT_TITLE' => lorem_word(),
                    'EFFECT_SHORT' => lorem_word_2(),
                    'EFFECT' => lorem_word(),
                ];
            }
            $block = do_lorem_template('CHAT_SET_EFFECTS_SETTING_BLOCK', [
                'HAS_SOME' => false,
                'EFFECTS' => $effects,
                'LIBRARY' => placeholder_array(),
            ]);
            $setting_blocks->attach($block);
        }

        $sound_effects = [];
        foreach (placeholder_array() as $k => $v) {
            $sound_effects[] = [
                'KEY' => $v,
                'VALUE' => lorem_word_2(),
            ];
        }
        $chat_sound = do_lorem_template('CHAT_SOUND', [
            'SOUND_EFFECTS' => $sound_effects,
        ]);

        return lorem_globalise(do_lorem_template('CHAT_SET_EFFECTS_SCREEN', [
            'TITLE' => lorem_screen_title(),
            'SUBMIT_ICON' => 'buttons/save',
            'SUBMIT_NAME' => lorem_word(),
            'HIDDEN' => '',
            'POST_URL' => placeholder_url(),
            'SETTING_BLOCKS' => $setting_blocks,
            'CHAT_SOUND' => $chat_sound,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__chat_sitewide_im_popup() : object
    {
        $im_area_template = do_lorem_template('CHAT_LOBBY_IM_AREA', [
            'MESSAGES_PHP' => find_script('messages'),
            'CHATROOM_ID' => placeholder_numeric_id(),
        ]);

        $sound_effects = [];
        foreach (placeholder_array() as $k => $v) {
            $sound_effects[] = [
                'KEY' => $v,
                'VALUE' => lorem_word_2(),
            ];
        }
        $chat_sound = do_lorem_template('CHAT_SOUND', [
            'SOUND_EFFECTS' => $sound_effects,
        ]);

        return lorem_globalise(do_lorem_template('CHAT_SITEWIDE_IM_POPUP', [
            'CONTENT' => $im_area_template,
            'CHAT_SOUND' => $chat_sound,
        ]), null, '', true);
    }

    /**
     * Uninstall default content.
     */
    public function uninstall_test_content()
    {
        require_code('chat2');

        $to_delete = $GLOBALS['SITE_DB']->query_select('chat_messages', ['id'], [$GLOBALS['SITE_DB']->translate_field_ref('the_message') => lorem_phrase()]);
        foreach ($to_delete as $record) {
            delete_chat_messages(['id' => $record['id']]);
        }

        $to_delete = $GLOBALS['SITE_DB']->query_select('chat_rooms', ['id'], ['room_name' => lorem_phrase()]);
        foreach ($to_delete as $record) {
            delete_chatroom($record['id']);
        }

        $test_member = $GLOBALS['FORUM_DRIVER']->get_member_from_username('test');
        if (($test_member !== null) && ($test_member != get_member())) {
            friend_remove(get_member(), $test_member);
            friend_remove($test_member, get_member());
        }
    }

    /**
     * Install default content.
     */
    public function install_test_content()
    {
        require_code('chat2');

        $room_id = add_chatroom(lorem_phrase(), lorem_phrase(), get_member(), '', '', '', '', fallback_lang());

        $map = [
            'system_message' => 0,
            'ip_address' => get_ip_address(),
            'room_id' => $room_id,
            'member_id' => get_member(),
            'date_and_time' => time(),
            'text_colour' => get_option('chat_default_post_colour'),
            'font_name' => get_option('chat_default_post_font'),
        ];
        $map += insert_lang_comcode('the_message', lorem_phrase(), 4);
        $GLOBALS['SITE_DB']->query_insert('chat_messages', $map);

        $test_member = $GLOBALS['FORUM_DRIVER']->get_member_from_username('test');
        if (($test_member !== null) && ($test_member != get_member())) {
            friend_add(get_member(), $test_member);
            friend_add($test_member, get_member());
        }
    }
}
