<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    commandr
 */

/**
 * Hook class.
 */
class Hook_addon_registry_commandr
{
    /**
     * Get a list of file permissions to set.
     *
     * @param  boolean $runtime Whether to include wildcards represented runtime-created chmoddable files
     * @return array File permissions to set
     */
    public function get_chmod_array(bool $runtime = false) : array
    {
        return [];
    }

    /**
     * Get the version of Composr this addon is for (used in generating the TAR filename).
     *
     * @return float Version number
     */
    public function get_version() : float
    {
        return cms_version_number();
    }

    /**
     * Get the minimum required version of the website software needed to use this addon.
     *
     * @return float Minimum required website software version
     */
    public function get_min_cms_version() : float
    {
        return 11.0;
    }

    /**
     * Get the maximum compatible version of the website software to use this addon.
     *
     * @return ?float Maximum compatible website software version (null: no maximum version currently)
     */
    public function get_max_cms_version() : ?float
    {
        return null;
    }

    /**
     * Get the addon category.
     *
     * @return string The category
     */
    public function get_category() : string
    {
        return 'Admin Utilities';
    }

    /**
     * Get the description of the addon.
     *
     * @return string Description of the addon
     */
    public function get_description() : string
    {
        return 'A command-line environment for managing your website, designed for Linux/Unix lovers.';
    }

    /**
     * Get a list of tutorials that apply to this addon.
     *
     * @return array List of tutorials
     */
    public function get_applicable_tutorials() : array
    {
        return [
            'tut_commandr',
            'tut_repository',
        ];
    }

    /**
     * Get a mapping of dependency types.
     *
     * @return array A structure specifying dependency information
     */
    public function get_dependencies() : array
    {
        return [
            'requires' => [],
            'recommends' => [],
            'conflicts_with' => [],
        ];
    }

    /**
     * Explicitly say which icon should be used.
     *
     * @return URLPATH Icon
     */
    public function get_default_icon() : string
    {
        return 'themes/default/images/icons/menu/adminzone/tools/commandr.svg';
    }

    /**
     * Get a list of files that belong to this addon.
     *
     * @return array List of files
     */
    public function get_file_list() : array
    {
        return [
            'adminzone/pages/modules/admin_commandr.php',
            'data/commandr.php',
            'data/modules/admin_commandr/.htaccess',
            'data/modules/admin_commandr/admin_commandrsample_script',
            'data/modules/admin_commandr/index.html',
            'data/modules/admin_commandr/sample_script',
            'data/modules/admin_commandr/test_script',
            'lang/EN/commandr.ini',
            'sources/commandr.php',
            'sources/commandr_fs.php',
            'sources/hooks/systems/actionlog/commandr.php',
            'sources/hooks/systems/addon_registry/commandr.php',
            'sources/hooks/systems/commandr_commands/.htaccess',
            'sources/hooks/systems/commandr_commands/alien_check.php',
            'sources/hooks/systems/commandr_commands/antispam_check.php',
            'sources/hooks/systems/commandr_commands/append.php',
            'sources/hooks/systems/commandr_commands/ban_ip.php',
            'sources/hooks/systems/commandr_commands/ban_member.php',
            'sources/hooks/systems/commandr_commands/bsod.php',
            'sources/hooks/systems/commandr_commands/call.php',
            'sources/hooks/systems/commandr_commands/cat.php',
            'sources/hooks/systems/commandr_commands/cd.php',
            'sources/hooks/systems/commandr_commands/check_perms.php',
            'sources/hooks/systems/commandr_commands/clear.php',
            'sources/hooks/systems/commandr_commands/clear_caches.php',
            'sources/hooks/systems/commandr_commands/closed.php',
            'sources/hooks/systems/commandr_commands/commands.php',
            'sources/hooks/systems/commandr_commands/cp.php',
            'sources/hooks/systems/commandr_commands/cpdir.php',
            'sources/hooks/systems/commandr_commands/cpf_decrypt.php',
            'sources/hooks/systems/commandr_commands/cpf_encrypt.php',
            'sources/hooks/systems/commandr_commands/css_cleanup.php',
            'sources/hooks/systems/commandr_commands/database_upgrade.php',
            'sources/hooks/systems/commandr_commands/date.php',
            'sources/hooks/systems/commandr_commands/db_search.php',
            'sources/hooks/systems/commandr_commands/db_table_sizes.php',
            'sources/hooks/systems/commandr_commands/deep_clean.php',
            'sources/hooks/systems/commandr_commands/directory_sizes.php',
            'sources/hooks/systems/commandr_commands/echo.php',
            'sources/hooks/systems/commandr_commands/edit.php',
            'sources/hooks/systems/commandr_commands/exit.php',
            'sources/hooks/systems/commandr_commands/find.php',
            'sources/hooks/systems/commandr_commands/find_codes.php',
            'sources/hooks/systems/commandr_commands/find_commandr_fs_filename_via_id.php',
            'sources/hooks/systems/commandr_commands/find_entry_points.php',
            'sources/hooks/systems/commandr_commands/find_guid_via_id.php',
            'sources/hooks/systems/commandr_commands/find_id_via_commandr_fs_filename.php',
            'sources/hooks/systems/commandr_commands/find_id_via_guid.php',
            'sources/hooks/systems/commandr_commands/find_id_via_label.php',
            'sources/hooks/systems/commandr_commands/find_label_via_id.php',
            'sources/hooks/systems/commandr_commands/fs_search.php',
            'sources/hooks/systems/commandr_commands/grep.php',
            'sources/hooks/systems/commandr_commands/help.php',
            'sources/hooks/systems/commandr_commands/index.html',
            'sources/hooks/systems/commandr_commands/integrity_check.php',
            'sources/hooks/systems/commandr_commands/ls.php',
            'sources/hooks/systems/commandr_commands/mkdir.php',
            'sources/hooks/systems/commandr_commands/mv.php',
            'sources/hooks/systems/commandr_commands/mvdir.php',
            'sources/hooks/systems/commandr_commands/obfuscate_directory.php',
            'sources/hooks/systems/commandr_commands/passwd.php',
            'sources/hooks/systems/commandr_commands/phpinfo.php',
            'sources/hooks/systems/commandr_commands/pwd.php',
            'sources/hooks/systems/commandr_commands/read.php',
            'sources/hooks/systems/commandr_commands/reset.php',
            'sources/hooks/systems/commandr_commands/rm.php',
            'sources/hooks/systems/commandr_commands/rmdir.php',
            'sources/hooks/systems/commandr_commands/set_comment_forum.php',
            'sources/hooks/systems/commandr_commands/sql_dump.php',
            'sources/hooks/systems/commandr_commands/test_mail.php',
            'sources/hooks/systems/commandr_commands/time.php',
            'sources/hooks/systems/commandr_commands/untar.php',
            'sources/hooks/systems/commandr_commands/users_online.php',
            'sources/hooks/systems/commandr_commands/version.php',
            'sources/hooks/systems/commandr_commands/whoami.php',
            'sources/hooks/systems/commandr_commands/write.php',
            'sources/hooks/systems/commandr_fs/.htaccess',
            'sources/hooks/systems/commandr_fs/bin.php',
            'sources/hooks/systems/commandr_fs/database.php',
            'sources/hooks/systems/commandr_fs/etc.php',
            'sources/hooks/systems/commandr_fs/index.html',
            'sources/hooks/systems/commandr_fs/raw.php',
            'sources/hooks/systems/commandr_fs/root.php',
            'sources/hooks/systems/commandr_fs_extended_config/.htaccess',
            'sources/hooks/systems/commandr_fs_extended_config/index.html',
            'sources/hooks/systems/commandr_fs_extended_config/privileges.php',
            'sources/hooks/systems/commandr_fs_extended_member/.htaccess',
            'sources/hooks/systems/commandr_fs_extended_member/index.html',
            'sources/hooks/systems/config/bottom_show_commandr_button.php',
            'sources/hooks/systems/config/days_to_keep__resource_fs_log.php',
            'sources/hooks/systems/logs/commandr.php',
            'sources/hooks/systems/page_groupings/commandr.php',
            'sources/hooks/systems/privacy/commandr.php',
            'sources/hooks/systems/snippets/commandr.php',
            'sources/resource_fs.php',
            'sources/resource_fs_base_class.php',
            'sources_custom/hooks/systems/commandr_commands/.htaccess',
            'sources_custom/hooks/systems/commandr_commands/index.html',
            'sources_custom/hooks/systems/commandr_fs/.htaccess',
            'sources_custom/hooks/systems/commandr_fs/index.html',
            'sources_custom/hooks/systems/commandr_fs_extended_config/.htaccess',
            'sources_custom/hooks/systems/commandr_fs_extended_config/index.html',
            'sources_custom/hooks/systems/commandr_fs_extended_member/.htaccess',
            'sources_custom/hooks/systems/commandr_fs_extended_member/index.html',
            'themes/default/css/_commandr_colours.css',
            'themes/default/css/commandr.css',
            'themes/default/images/icons/menu/adminzone/tools/commandr.svg',
            'themes/default/images/icons/tool_buttons/commandr_off.svg',
            'themes/default/images/icons/tool_buttons/commandr_on.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/commandr.svg',
            'themes/default/images/icons_monochrome/tool_buttons/commandr_off.svg',
            'themes/default/images/icons_monochrome/tool_buttons/commandr_on.svg',
            'themes/default/javascript/button_commandr.js',
            'themes/default/javascript/commandr.js',
            'themes/default/templates/COMMANDR_ARRAY.tpl',
            'themes/default/templates/COMMANDR_BOX.tpl',
            'themes/default/templates/COMMANDR_COMMAND.tpl',
            'themes/default/templates/COMMANDR_COMMANDS.tpl',
            'themes/default/templates/COMMANDR_EDIT.tpl',
            'themes/default/templates/COMMANDR_ENTRY_POINTS.tpl',
            'themes/default/templates/COMMANDR_FIND_CODES.tpl',
            'themes/default/templates/COMMANDR_HELP.tpl',
            'themes/default/templates/COMMANDR_LS.tpl',
            'themes/default/templates/COMMANDR_MAIN.tpl',
            'themes/default/templates/COMMANDR_MAIN_SCREEN.tpl',
            'themes/default/templates/COMMANDR_RSS.tpl',
            'themes/default/templates/COMMANDR_USERS_ONLINE.tpl',
            'themes/default/templates/COMMANDR_WHOIS.tpl',
        ];
    }

    /**
     * Get mapping between template names and the method of this class that can render a preview of them.
     *
     * @return array The mapping
     */
    public function tpl_previews() : array
    {
        return [
            'templates/COMMANDR_MAIN.tpl' => 'administrative__commandr_main_screen',
            'templates/COMMANDR_MAIN_SCREEN.tpl' => 'administrative__commandr_main_screen',
            'templates/COMMANDR_COMMAND.tpl' => 'administrative__commandr_command',
            'templates/COMMANDR_ARRAY.tpl' => 'administrative__commandr_array',
            'templates/COMMANDR_HELP.tpl' => 'administrative__commandr_help',
            'templates/COMMANDR_BOX.tpl' => 'administrative__commandr_box',
            'templates/COMMANDR_COMMANDS.tpl' => 'administrative__commandr_commands',
            'templates/COMMANDR_RSS.tpl' => 'administrative__commandr_rss',
            'templates/COMMANDR_EDIT.tpl' => 'administrative__commandr_edit',
            'templates/COMMANDR_USERS_ONLINE.tpl' => 'administrative__commandr_users_online',
            'templates/COMMANDR_FIND_CODES.tpl' => 'administrative__commandr_find_codes',
            'templates/COMMANDR_WHOIS.tpl' => 'administrative__commandr_whois',
            'templates/COMMANDR_ENTRY_POINTS.tpl' => 'administrative__commandr_entry_points',
            'templates/COMMANDR_LS.tpl' => 'administrative__commandr_ls',
        ];
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__commandr_main_screen() : object
    {
        $content = do_lorem_template('COMMANDR_MAIN', [
            'COMMANDS' => lorem_phrase(),
            'SUBMIT_URL' => placeholder_url(),
            'PROMPT' => lorem_phrase(),
        ]);

        return lorem_globalise(do_lorem_template('COMMANDR_MAIN_SCREEN', [
            'TITLE' => lorem_screen_title(),
            'CONTENT' => $content,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__commandr_command() : object
    {
        return lorem_globalise(do_lorem_template('COMMANDR_COMMAND', [
            'METHOD' => lorem_phrase(),
            'STDOUT' => lorem_phrase(),
            'STDHTML' => lorem_phrase(),
            'STDERR' => lorem_phrase(),
            'STDCOMMAND' => null,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__commandr_array() : object
    {
        $elements = [];
        $elements[] = [
            'KEY' => lorem_phrase(),
            'VALUE' => lorem_phrase(),
        ];

        return lorem_globalise(do_lorem_template('COMMANDR_ARRAY', [
            'ELEMENTS' => $elements,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__commandr_help() : object
    {
        return lorem_globalise(do_lorem_template('COMMANDR_HELP', [
            'INTRODUCTION' => lorem_phrase(),
            'OPTIONS' => placeholder_array(),
            'PARAMETERS' => placeholder_array(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__commandr_box() : object
    {
        return lorem_globalise(do_lorem_template('COMMANDR_BOX', [
            'HTML' => lorem_sentence_html(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__commandr_commands() : object
    {
        return lorem_globalise(do_lorem_template('COMMANDR_COMMANDS', [
            'COMMANDS' => placeholder_array(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__commandr_rss() : object
    {
        $content = [];
        $content[] = [
            'FULL_URL' => placeholder_url(),
            'NEWS_TITLE' => lorem_phrase(),
            'DATE' => placeholder_date(),
            'SUMMARY' => lorem_paragraph(),
        ];

        return lorem_globalise(do_lorem_template('COMMANDR_RSS', [
            'TITLE' => lorem_phrase(),
            'CONTENT' => $content,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__commandr_edit() : object
    {
        return lorem_globalise(do_lorem_template('COMMANDR_EDIT', [
            'FILE' => lorem_phrase(),
            'SUBMIT_URL' => placeholder_url(),
            'FILE_CONTENTS' => lorem_sentence(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__commandr_users_online() : object
    {
        $memb = [];
        foreach (placeholder_array() as $k => $v) {
            $memb[$v] = $k;
        }
        return lorem_globalise(do_lorem_template('COMMANDR_USERS_ONLINE', [
            'MEMBERS' => $memb,
            '_GUESTS' => placeholder_number(),
            'GUESTS' => placeholder_number(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__commandr_find_codes() : object
    {
        return lorem_globalise(do_lorem_template('COMMANDR_FIND_CODES', [
            'FILES' => placeholder_array(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__commandr_whois() : object
    {
        return lorem_globalise(do_lorem_template('COMMANDR_WHOIS', [
            'STATS' => lorem_phrase(),
            'IP_LIST' => placeholder_list_item(),
            'MEMBER_ID' => placeholder_numeric_id(),
            'IP' => placeholder_ip(),
            'USERNAME' => lorem_word(),
            'EMAIL_ADDRESS' => lorem_phrase(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__commandr_entry_points() : object
    {
        $points = [];
        foreach (placeholder_array() as $k => $v) {
            $points[$v] = $k;
        }
        return lorem_globalise(do_lorem_template('COMMANDR_ENTRY_POINTS', [
            'ENTRY_POINTS' => $points,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__commandr_ls() : object
    {
        $directories = [];
        foreach (placeholder_array() as $k => $v) {
            $directories[] =             [
                'FILENAME' => $v,
                'FILESIZE' => lorem_word(),
                'MTIME' => placeholder_date(),
            ];
        }

        $files = [];
        foreach (placeholder_array() as $k => $v) {
            $files[] =             [
                'FILENAME' => $v,
                'FILESIZE' => lorem_word(),
                'MTIME' => placeholder_date(),
            ];
        }

        return lorem_globalise(do_lorem_template('COMMANDR_LS', [
            'DIRECTORY' => lorem_phrase(),
            'DIRECTORIES' => $directories,
            'FILES' => $files,
        ]), null, '', true);
    }
}
