<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core_all_icons
 */

/**
 * Hook class.
 */
class Hook_addon_registry_core_all_icons
{
    /**
     * Get a list of file permissions to set.
     *
     * @param  boolean $runtime Whether to include wildcards represented runtime-created chmoddable files
     * @return array File permissions to set
     */
    public function get_chmod_array(bool $runtime = false) : array
    {
        return [];
    }

    /**
     * Get the version of Composr this addon is for (used in generating the TAR filename).
     *
     * @return float Version number
     */
    public function get_version() : float
    {
        return cms_version_number();
    }

    /**
     * Get the minimum required version of the website software needed to use this addon.
     *
     * @return float Minimum required website software version
     */
    public function get_min_cms_version() : float
    {
        return 11.0;
    }

    /**
     * Get the maximum compatible version of the website software to use this addon.
     *
     * @return ?float Maximum compatible website software version (null: no maximum version currently)
     */
    public function get_max_cms_version() : ?float
    {
        return null;
    }

    /**
     * Get the addon category.
     *
     * @return string The category
     */
    public function get_category() : string
    {
        return 'Graphical';
    }

    /**
     * Get the description of the addon.
     *
     * @return string Description of the addon
     */
    public function get_description() : string
    {
        return 'The full Composr icon set, including extra icons and icons from all bundled addons (to make them available even if they are not installed)';
    }

    /**
     * Get a list of tutorials that apply to this addon.
     *
     * @return array List of tutorials
     */
    public function get_applicable_tutorials() : array
    {
        return [
            'tut_themes',
        ];
    }

    /**
     * Get a mapping of dependency types.
     *
     * @return array A structure specifying dependency information
     */
    public function get_dependencies() : array
    {
        return [
            'requires' => [],
            'recommends' => [],
            'conflicts_with' => [],
        ];
    }

    /**
     * Explicitly say which icon should be used.
     *
     * @return URLPATH Icon
     */
    public function get_default_icon() : string
    {
        return 'themes/default/images/icons/admin/component.svg';
    }

    /**
     * Get a list of files that belong to this addon.
     *
     * @return array List of files
     */
    public function get_file_list() : array
    {
        return [
            'sources/hooks/systems/addon_registry/core_all_icons.php',
            'themes/default/images/icons/admin/add.svg',
            'themes/default/images/icons/admin/add_one_category.svg',
            'themes/default/images/icons/admin/add_to_category.svg',
            'themes/default/images/icons/admin/back.svg',
            'themes/default/images/icons/admin/component.svg',
            'themes/default/images/icons/admin/delete.svg',
            'themes/default/images/icons/admin/delete2.svg',
            'themes/default/images/icons/admin/delete3.svg',
            'themes/default/images/icons/admin/edit.svg',
            'themes/default/images/icons/admin/edit2.svg',
            'themes/default/images/icons/admin/edit_one_category.svg',
            'themes/default/images/icons/admin/edit_this.svg',
            'themes/default/images/icons/admin/edit_this_category.svg',
            'themes/default/images/icons/admin/export.svg',
            'themes/default/images/icons/admin/export_spreadsheet.svg',
            'themes/default/images/icons/admin/import.svg',
            'themes/default/images/icons/admin/import_spreadsheet.svg',
            'themes/default/images/icons/admin/index.html',
            'themes/default/images/icons/admin/install.svg',
            'themes/default/images/icons/admin/merge.svg',
            'themes/default/images/icons/admin/move.svg',
            'themes/default/images/icons/admin/reinstall.svg',
            'themes/default/images/icons/admin/remove.svg',
            'themes/default/images/icons/admin/revisions.svg',
            'themes/default/images/icons/admin/sync.svg',
            'themes/default/images/icons/admin/tool.svg',
            'themes/default/images/icons/admin/tools.svg',
            'themes/default/images/icons/admin/translate.svg',
            'themes/default/images/icons/admin/upgrade.svg',
            'themes/default/images/icons/admin/view_archive.svg',
            'themes/default/images/icons/admin/view_this.svg',
            'themes/default/images/icons/admin/view_this_category.svg',
            'themes/default/images/icons/admin/warn.svg',
            'themes/default/images/icons/admin/wiki_edit_tree.svg',
            'themes/default/images/icons/admin/xml.svg',
            'themes/default/images/icons/arrow_box/arrow_box.svg',
            'themes/default/images/icons/arrow_box/arrow_box_hover.svg',
            'themes/default/images/icons/arrow_box/index.html',
            'themes/default/images/icons/birthday.svg',
            'themes/default/images/icons/booking/blacked.svg',
            'themes/default/images/icons/booking/book.svg',
            'themes/default/images/icons/booking/bookable.svg',
            'themes/default/images/icons/booking/booking.svg',
            'themes/default/images/icons/booking/index.html',
            'themes/default/images/icons/booking/supplement.svg',
            'themes/default/images/icons/breadcrumbs.svg',
            'themes/default/images/icons/buttons/add_ticket.svg',
            'themes/default/images/icons/buttons/add_topic.svg',
            'themes/default/images/icons/buttons/advanced.svg',
            'themes/default/images/icons/buttons/all.svg',
            'themes/default/images/icons/buttons/all2.svg',
            'themes/default/images/icons/buttons/back.svg',
            'themes/default/images/icons/buttons/calculate.svg',
            'themes/default/images/icons/buttons/cancel.svg',
            'themes/default/images/icons/buttons/cancel2.svg',
            'themes/default/images/icons/buttons/cart_add.svg',
            'themes/default/images/icons/buttons/cart_checkout.svg',
            'themes/default/images/icons/buttons/cart_empty.svg',
            'themes/default/images/icons/buttons/cart_update.svg',
            'themes/default/images/icons/buttons/choose.svg',
            'themes/default/images/icons/buttons/clear.svg',
            'themes/default/images/icons/buttons/close.svg',
            'themes/default/images/icons/buttons/closed.svg',
            'themes/default/images/icons/buttons/convert.svg',
            'themes/default/images/icons/buttons/copy.svg',
            'themes/default/images/icons/buttons/download.svg',
            'themes/default/images/icons/buttons/filter.svg',
            'themes/default/images/icons/buttons/forum.svg',
            'themes/default/images/icons/buttons/full_size.svg',
            'themes/default/images/icons/buttons/ignore.svg',
            'themes/default/images/icons/buttons/index.html',
            'themes/default/images/icons/buttons/linear.svg',
            'themes/default/images/icons/buttons/mark_read.svg',
            'themes/default/images/icons/buttons/mark_unread.svg',
            'themes/default/images/icons/buttons/more.svg',
            'themes/default/images/icons/buttons/new_comment.svg',
            'themes/default/images/icons/buttons/new_post_full.svg',
            'themes/default/images/icons/buttons/new_quote.svg',
            'themes/default/images/icons/buttons/new_reply.svg',
            'themes/default/images/icons/buttons/new_reply_staff_only.svg',
            'themes/default/images/icons/buttons/next.svg',
            'themes/default/images/icons/buttons/next_none.svg',
            'themes/default/images/icons/buttons/no.svg',
            'themes/default/images/icons/buttons/notifications_disable.svg',
            'themes/default/images/icons/buttons/notifications_enable.svg',
            'themes/default/images/icons/buttons/pause.svg',
            'themes/default/images/icons/buttons/points.svg',
            'themes/default/images/icons/buttons/preview.svg',
            'themes/default/images/icons/buttons/previous.svg',
            'themes/default/images/icons/buttons/previous_none.svg',
            'themes/default/images/icons/buttons/proceed.svg',
            'themes/default/images/icons/buttons/proceed2.svg',
            'themes/default/images/icons/buttons/redirect.svg',
            'themes/default/images/icons/buttons/report.svg',
            'themes/default/images/icons/buttons/save.svg',
            'themes/default/images/icons/buttons/search.svg',
            'themes/default/images/icons/buttons/send.svg',
            'themes/default/images/icons/buttons/settings.svg',
            'themes/default/images/icons/buttons/shrink_size.svg',
            'themes/default/images/icons/buttons/simple.svg',
            'themes/default/images/icons/buttons/skip.svg',
            'themes/default/images/icons/buttons/slideshow.svg',
            'themes/default/images/icons/buttons/sort.svg',
            'themes/default/images/icons/buttons/sound_effects.svg',
            'themes/default/images/icons/buttons/threaded.svg',
            'themes/default/images/icons/buttons/thumbnail.svg',
            'themes/default/images/icons/buttons/undo.svg',
            'themes/default/images/icons/buttons/upload.svg',
            'themes/default/images/icons/buttons/whisper.svg',
            'themes/default/images/icons/buttons/yes.svg',
            'themes/default/images/icons/calendar/activity.svg',
            'themes/default/images/icons/calendar/anniversary.svg',
            'themes/default/images/icons/calendar/appointment.svg',
            'themes/default/images/icons/calendar/birthday.svg',
            'themes/default/images/icons/calendar/commitment.svg',
            'themes/default/images/icons/calendar/duty.svg',
            'themes/default/images/icons/calendar/festival.svg',
            'themes/default/images/icons/calendar/general.svg',
            'themes/default/images/icons/calendar/index.html',
            'themes/default/images/icons/calendar/public_holiday.svg',
            'themes/default/images/icons/calendar/rss.svg',
            'themes/default/images/icons/calendar/system_command.svg',
            'themes/default/images/icons/calendar/vacation.svg',
            'themes/default/images/icons/carousel/button_left.svg',
            'themes/default/images/icons/carousel/button_left_hover.svg',
            'themes/default/images/icons/carousel/button_right.svg',
            'themes/default/images/icons/carousel/button_right_hover.svg',
            'themes/default/images/icons/carousel/index.html',
            'themes/default/images/icons/checklist/checklist_done.svg',
            'themes/default/images/icons/checklist/checklist_na.svg',
            'themes/default/images/icons/checklist/checklist_todo.svg',
            'themes/default/images/icons/checklist/index.html',
            'themes/default/images/icons/checklist/toggle.svg',
            'themes/default/images/icons/checklist/toggle2.svg',
            'themes/default/images/icons/cns_general/index.html',
            'themes/default/images/icons/cns_general/is_off.svg',
            'themes/default/images/icons/cns_general/is_on.svg',
            'themes/default/images/icons/cns_general/new_posts.svg',
            'themes/default/images/icons/cns_general/new_posts_redirect.svg',
            'themes/default/images/icons/cns_general/no_new_posts.svg',
            'themes/default/images/icons/cns_general/no_new_posts_redirect.svg',
            'themes/default/images/icons/cns_general/redirect.svg',
            'themes/default/images/icons/cns_topic_modifiers/announcement.svg',
            'themes/default/images/icons/cns_topic_modifiers/closed.svg',
            'themes/default/images/icons/cns_topic_modifiers/hot.svg',
            'themes/default/images/icons/cns_topic_modifiers/index.html',
            'themes/default/images/icons/cns_topic_modifiers/involved.svg',
            'themes/default/images/icons/cns_topic_modifiers/not_validated.svg',
            'themes/default/images/icons/cns_topic_modifiers/pinned.svg',
            'themes/default/images/icons/cns_topic_modifiers/poll.svg',
            'themes/default/images/icons/cns_topic_modifiers/unread.svg',
            'themes/default/images/icons/comcode_editor/apply_changes.svg',
            'themes/default/images/icons/comcode_editor/b.svg',
            'themes/default/images/icons/comcode_editor/block.svg',
            'themes/default/images/icons/comcode_editor/box.svg',
            'themes/default/images/icons/comcode_editor/code.svg',
            'themes/default/images/icons/comcode_editor/comcode.svg',
            'themes/default/images/icons/comcode_editor/email.svg',
            'themes/default/images/icons/comcode_editor/hide.svg',
            'themes/default/images/icons/comcode_editor/html.svg',
            'themes/default/images/icons/comcode_editor/i.svg',
            'themes/default/images/icons/comcode_editor/img.svg',
            'themes/default/images/icons/comcode_editor/index.html',
            'themes/default/images/icons/comcode_editor/list.svg',
            'themes/default/images/icons/comcode_editor/page.svg',
            'themes/default/images/icons/comcode_editor/quote.svg',
            'themes/default/images/icons/comcode_editor/s.svg',
            'themes/default/images/icons/comcode_editor/thumb.svg',
            'themes/default/images/icons/comcode_editor/u.svg',
            'themes/default/images/icons/comcode_editor/url.svg',
            'themes/default/images/icons/contact_methods/address.svg',
            'themes/default/images/icons/contact_methods/email.svg',
            'themes/default/images/icons/contact_methods/index.html',
            'themes/default/images/icons/contact_methods/telephone.svg',
            'themes/default/images/icons/content_types/audio.svg',
            'themes/default/images/icons/content_types/image.svg',
            'themes/default/images/icons/content_types/index.html',
            'themes/default/images/icons/content_types/member.svg',
            'themes/default/images/icons/content_types/multimedia.svg',
            'themes/default/images/icons/content_types/page.svg',
            'themes/default/images/icons/content_types/post.svg',
            'themes/default/images/icons/content_types/topic.svg',
            'themes/default/images/icons/content_types/video.svg',
            'themes/default/images/icons/editor/comcode.svg',
            'themes/default/images/icons/editor/index.html',
            'themes/default/images/icons/editor/insert_emoticons.svg',
            'themes/default/images/icons/editor/wysiwyg_off.svg',
            'themes/default/images/icons/editor/wysiwyg_on.svg',
            'themes/default/images/icons/features.svg',
            'themes/default/images/icons/feedback/comment.svg',
            'themes/default/images/icons/feedback/comments_topic.svg',
            'themes/default/images/icons/feedback/dislike.svg',
            'themes/default/images/icons/feedback/dislike2.svg',
            'themes/default/images/icons/feedback/index.html',
            'themes/default/images/icons/feedback/like.svg',
            'themes/default/images/icons/feedback/like2.svg',
            'themes/default/images/icons/feedback/rate.svg',
            'themes/default/images/icons/feedback/rating.svg',
            'themes/default/images/icons/file_types/email_link.svg',
            'themes/default/images/icons/file_types/external_link.svg',
            'themes/default/images/icons/file_types/index.html',
            'themes/default/images/icons/file_types/page_archive.svg',
            'themes/default/images/icons/file_types/page_css.svg',
            'themes/default/images/icons/file_types/page_doc.svg',
            'themes/default/images/icons/file_types/page_feed.svg',
            'themes/default/images/icons/file_types/page_js.svg',
            'themes/default/images/icons/file_types/page_media.svg',
            'themes/default/images/icons/file_types/page_odp.svg',
            'themes/default/images/icons/file_types/page_ods.svg',
            'themes/default/images/icons/file_types/page_odt.svg',
            'themes/default/images/icons/file_types/page_pdf.svg',
            'themes/default/images/icons/file_types/page_ppt.svg',
            'themes/default/images/icons/file_types/page_torrent.svg',
            'themes/default/images/icons/file_types/page_tpl.svg',
            'themes/default/images/icons/file_types/page_txt.svg',
            'themes/default/images/icons/file_types/page_xls.svg',
            'themes/default/images/icons/file_types/page_xml.svg',
            'themes/default/images/icons/help.svg',
            'themes/default/images/icons/helper_panel/hide.svg',
            'themes/default/images/icons/helper_panel/index.html',
            'themes/default/images/icons/helper_panel/show.svg',
            'themes/default/images/icons/index.html',
            'themes/default/images/icons/links/amazon.svg',
            'themes/default/images/icons/links/apple.svg',
            'themes/default/images/icons/links/baidu_tieba.svg',
            'themes/default/images/icons/links/bandcamp.svg',
            'themes/default/images/icons/links/bitcoin.svg',
            'themes/default/images/icons/links/contact_member.svg',
            'themes/default/images/icons/links/dailymotion.svg',
            'themes/default/images/icons/links/diaspora.svg',
            'themes/default/images/icons/links/discord.svg',
            'themes/default/images/icons/links/download_as_archive.svg',
            'themes/default/images/icons/links/dropbox.svg',
            'themes/default/images/icons/links/dtube.svg',
            'themes/default/images/icons/links/facebook.svg',
            'themes/default/images/icons/links/favorites.svg',
            'themes/default/images/icons/links/flattr.svg',
            'themes/default/images/icons/links/github.svg',
            'themes/default/images/icons/links/gitlab.svg',
            'themes/default/images/icons/links/google.svg',
            'themes/default/images/icons/links/hacker_news.svg',
            'themes/default/images/icons/links/index.html',
            'themes/default/images/icons/links/instagram.svg',
            'themes/default/images/icons/links/jabber.svg',
            'themes/default/images/icons/links/line.svg',
            'themes/default/images/icons/links/linkedin.svg',
            'themes/default/images/icons/links/mastodon.svg',
            'themes/default/images/icons/links/microsoft.svg',
            'themes/default/images/icons/links/minds.svg',
            'themes/default/images/icons/links/patreon.svg',
            'themes/default/images/icons/links/paypal.svg',
            'themes/default/images/icons/links/pinterest.svg',
            'themes/default/images/icons/links/playstation_network.svg',
            'themes/default/images/icons/links/print.svg',
            'themes/default/images/icons/links/quora.svg',
            'themes/default/images/icons/links/qzone.svg',
            'themes/default/images/icons/links/reddit.svg',
            'themes/default/images/icons/links/rss.svg',
            'themes/default/images/icons/links/sina_weibo.svg',
            'themes/default/images/icons/links/skype.svg',
            'themes/default/images/icons/links/slashdot.svg',
            'themes/default/images/icons/links/snapchat.svg',
            'themes/default/images/icons/links/soundcloud.svg',
            'themes/default/images/icons/links/spotify.svg',
            'themes/default/images/icons/links/stack_overflow.svg',
            'themes/default/images/icons/links/stackexchange.svg',
            'themes/default/images/icons/links/steam.svg',
            'themes/default/images/icons/links/steemit.svg',
            'themes/default/images/icons/links/telegram.svg',
            'themes/default/images/icons/links/tiktok.svg',
            'themes/default/images/icons/links/tumblr.svg',
            'themes/default/images/icons/links/twitch.svg',
            'themes/default/images/icons/links/twitter.svg',
            'themes/default/images/icons/links/utopian.svg',
            'themes/default/images/icons/links/viber.svg',
            'themes/default/images/icons/links/vimeo.svg',
            'themes/default/images/icons/links/vkontakte.svg',
            'themes/default/images/icons/links/warning_add.svg',
            'themes/default/images/icons/links/wechat.svg',
            'themes/default/images/icons/links/whatsapp.svg',
            'themes/default/images/icons/links/xbox_live.svg',
            'themes/default/images/icons/links/yahoo.svg',
            'themes/default/images/icons/links/youtube.svg',
            'themes/default/images/icons/media_set/index.html',
            'themes/default/images/icons/media_set/lightbox_close.svg',
            'themes/default/images/icons/media_set/next.svg',
            'themes/default/images/icons/media_set/previous.svg',
            'themes/default/images/icons/menu/adminzone/adminzone.svg',
            'themes/default/images/icons/menu/adminzone/audit.svg',
            'themes/default/images/icons/menu/adminzone/audit/actionlog.svg',
            'themes/default/images/icons/menu/adminzone/audit/content_reviews.svg',
            'themes/default/images/icons/menu/adminzone/audit/ecommerce/cash_flow.svg',
            'themes/default/images/icons/menu/adminzone/audit/ecommerce/create_invoice.svg',
            'themes/default/images/icons/menu/adminzone/audit/ecommerce/ecommerce.svg',
            'themes/default/images/icons/menu/adminzone/audit/ecommerce/index.html',
            'themes/default/images/icons/menu/adminzone/audit/ecommerce/invoices.svg',
            'themes/default/images/icons/menu/adminzone/audit/ecommerce/profit_loss.svg',
            'themes/default/images/icons/menu/adminzone/audit/ecommerce/sales.svg',
            'themes/default/images/icons/menu/adminzone/audit/ecommerce/subscriptions.svg',
            'themes/default/images/icons/menu/adminzone/audit/ecommerce/transactions_log.svg',
            'themes/default/images/icons/menu/adminzone/audit/ecommerce/undispatched_orders.svg',
            'themes/default/images/icons/menu/adminzone/audit/email_log.svg',
            'themes/default/images/icons/menu/adminzone/audit/errorlog.svg',
            'themes/default/images/icons/menu/adminzone/audit/index.html',
            'themes/default/images/icons/menu/adminzone/audit/not_validated.svg',
            'themes/default/images/icons/menu/adminzone/audit/points_log.svg',
            'themes/default/images/icons/menu/adminzone/audit/realtime_rain.svg',
            'themes/default/images/icons/menu/adminzone/audit/security_log.svg',
            'themes/default/images/icons/menu/adminzone/audit/statistics/demographics.svg',
            'themes/default/images/icons/menu/adminzone/audit/statistics/geolocate.svg',
            'themes/default/images/icons/menu/adminzone/audit/statistics/index.html',
            'themes/default/images/icons/menu/adminzone/audit/statistics/load_times.svg',
            'themes/default/images/icons/menu/adminzone/audit/statistics/page_views.svg',
            'themes/default/images/icons/menu/adminzone/audit/statistics/search.svg',
            'themes/default/images/icons/menu/adminzone/audit/statistics/statistics.svg',
            'themes/default/images/icons/menu/adminzone/audit/statistics/submits.svg',
            'themes/default/images/icons/menu/adminzone/audit/statistics/top_referrers.svg',
            'themes/default/images/icons/menu/adminzone/audit/statistics/users_online.svg',
            'themes/default/images/icons/menu/adminzone/audit/trackbacks.svg',
            'themes/default/images/icons/menu/adminzone/home.svg',
            'themes/default/images/icons/menu/adminzone/index.html',
            'themes/default/images/icons/menu/adminzone/security.svg',
            'themes/default/images/icons/menu/adminzone/security/index.html',
            'themes/default/images/icons/menu/adminzone/security/ip_ban.svg',
            'themes/default/images/icons/menu/adminzone/security/ldap.svg',
            'themes/default/images/icons/menu/adminzone/security/permissions/index.html',
            'themes/default/images/icons/menu/adminzone/security/permissions/match_keys.svg',
            'themes/default/images/icons/menu/adminzone/security/permissions/permission_tree_editor.svg',
            'themes/default/images/icons/menu/adminzone/security/permissions/privileges.svg',
            'themes/default/images/icons/menu/adminzone/security/usergroups_temp.svg',
            'themes/default/images/icons/menu/adminzone/security/wordfilter.svg',
            'themes/default/images/icons/menu/adminzone/setup.svg',
            'themes/default/images/icons/menu/adminzone/setup/awards.svg',
            'themes/default/images/icons/menu/adminzone/setup/config/base_config.svg',
            'themes/default/images/icons/menu/adminzone/setup/config/config.svg',
            'themes/default/images/icons/menu/adminzone/setup/config/index.html',
            'themes/default/images/icons/menu/adminzone/setup/custom_comcode.svg',
            'themes/default/images/icons/menu/adminzone/setup/ecommerce_products.svg',
            'themes/default/images/icons/menu/adminzone/setup/index.html',
            'themes/default/images/icons/menu/adminzone/setup/notifications.svg',
            'themes/default/images/icons/menu/adminzone/setup/oauth.svg',
            'themes/default/images/icons/menu/adminzone/setup/setupwizard.svg',
            'themes/default/images/icons/menu/adminzone/setup/welcome_emails.svg',
            'themes/default/images/icons/menu/adminzone/setup/xml_fields.svg',
            'themes/default/images/icons/menu/adminzone/sponsors.svg',
            'themes/default/images/icons/menu/adminzone/structure.svg',
            'themes/default/images/icons/menu/adminzone/structure/addons.svg',
            'themes/default/images/icons/menu/adminzone/structure/aggregate_types.svg',
            'themes/default/images/icons/menu/adminzone/structure/breadcrumbs.svg',
            'themes/default/images/icons/menu/adminzone/structure/forum/index.html',
            'themes/default/images/icons/menu/adminzone/structure/forum/multi_moderations.svg',
            'themes/default/images/icons/menu/adminzone/structure/forum/post_templates.svg',
            'themes/default/images/icons/menu/adminzone/structure/index.html',
            'themes/default/images/icons/menu/adminzone/structure/menus.svg',
            'themes/default/images/icons/menu/adminzone/structure/redirects.svg',
            'themes/default/images/icons/menu/adminzone/structure/sitemap/index.html',
            'themes/default/images/icons/menu/adminzone/structure/sitemap/sitemap_editor.svg',
            'themes/default/images/icons/menu/adminzone/structure/zones/index.html',
            'themes/default/images/icons/menu/adminzone/structure/zones/zone_editor.svg',
            'themes/default/images/icons/menu/adminzone/structure/zones/zones.svg',
            'themes/default/images/icons/menu/adminzone/style.svg',
            'themes/default/images/icons/menu/adminzone/style/debrand.svg',
            'themes/default/images/icons/menu/adminzone/style/emoticons.svg',
            'themes/default/images/icons/menu/adminzone/style/index.html',
            'themes/default/images/icons/menu/adminzone/style/language/criticise_language.svg',
            'themes/default/images/icons/menu/adminzone/style/language/index.html',
            'themes/default/images/icons/menu/adminzone/style/language/language.svg',
            'themes/default/images/icons/menu/adminzone/style/language/language_content.svg',
            'themes/default/images/icons/menu/adminzone/style/quotes.svg',
            'themes/default/images/icons/menu/adminzone/style/themes/css.svg',
            'themes/default/images/icons/menu/adminzone/style/themes/index.html',
            'themes/default/images/icons/menu/adminzone/style/themes/logowizard.svg',
            'themes/default/images/icons/menu/adminzone/style/themes/templates.svg',
            'themes/default/images/icons/menu/adminzone/style/themes/theme_images.svg',
            'themes/default/images/icons/menu/adminzone/style/themes/themes.svg',
            'themes/default/images/icons/menu/adminzone/style/themes/themewizard.svg',
            'themes/default/images/icons/menu/adminzone/tools.svg',
            'themes/default/images/icons/menu/adminzone/tools/broken_urls.svg',
            'themes/default/images/icons/menu/adminzone/tools/bulk_content_actions/backups.svg',
            'themes/default/images/icons/menu/adminzone/tools/bulk_content_actions/index.html',
            'themes/default/images/icons/menu/adminzone/tools/cleanup.svg',
            'themes/default/images/icons/menu/adminzone/tools/code_editor.svg',
            'themes/default/images/icons/menu/adminzone/tools/commandr.svg',
            'themes/default/images/icons/menu/adminzone/tools/health_check.svg',
            'themes/default/images/icons/menu/adminzone/tools/index.html',
            'themes/default/images/icons/menu/adminzone/tools/newsletter/index.html',
            'themes/default/images/icons/menu/adminzone/tools/newsletter/newsletter_email_bounce.svg',
            'themes/default/images/icons/menu/adminzone/tools/newsletter/newsletter_from_changes.svg',
            'themes/default/images/icons/menu/adminzone/tools/newsletter/subscribers.svg',
            'themes/default/images/icons/menu/adminzone/tools/phpinfo.svg',
            'themes/default/images/icons/menu/adminzone/tools/upgrade.svg',
            'themes/default/images/icons/menu/adminzone/tools/users/custom_profile_fields.svg',
            'themes/default/images/icons/menu/adminzone/tools/users/delete_lurkers.svg',
            'themes/default/images/icons/menu/adminzone/tools/users/index.html',
            'themes/default/images/icons/menu/adminzone/tools/users/investigate_user.svg',
            'themes/default/images/icons/menu/adminzone/tools/users/member_add.svg',
            'themes/default/images/icons/menu/adminzone/tools/users/member_edit.svg',
            'themes/default/images/icons/menu/adminzone/tools/users/merge_members.svg',
            'themes/default/images/icons/menu/cms/author_set_own_profile.svg',
            'themes/default/images/icons/menu/cms/banners.svg',
            'themes/default/images/icons/menu/cms/blog.svg',
            'themes/default/images/icons/menu/cms/catalogues/add_one_catalogue.svg',
            'themes/default/images/icons/menu/cms/catalogues/edit_one_catalogue.svg',
            'themes/default/images/icons/menu/cms/catalogues/edit_this_catalogue.svg',
            'themes/default/images/icons/menu/cms/catalogues/index.html',
            'themes/default/images/icons/menu/cms/clubs.svg',
            'themes/default/images/icons/menu/cms/cms.svg',
            'themes/default/images/icons/menu/cms/comcode_page_edit.svg',
            'themes/default/images/icons/menu/cms/downloads/add_one_licence.svg',
            'themes/default/images/icons/menu/cms/downloads/edit_one_licence.svg',
            'themes/default/images/icons/menu/cms/downloads/index.html',
            'themes/default/images/icons/menu/cms/filedump.svg',
            'themes/default/images/icons/menu/cms/galleries/add_one_image.svg',
            'themes/default/images/icons/menu/cms/galleries/add_one_multimedia.svg',
            'themes/default/images/icons/menu/cms/galleries/add_one_video.svg',
            'themes/default/images/icons/menu/cms/galleries/edit_one_image.svg',
            'themes/default/images/icons/menu/cms/galleries/edit_one_multimedia.svg',
            'themes/default/images/icons/menu/cms/galleries/edit_one_video.svg',
            'themes/default/images/icons/menu/cms/galleries/index.html',
            'themes/default/images/icons/menu/cms/index.html',
            'themes/default/images/icons/menu/cms/quiz/find_winners.svg',
            'themes/default/images/icons/menu/cms/quiz/index.html',
            'themes/default/images/icons/menu/cms/quiz/quiz_results.svg',
            'themes/default/images/icons/menu/home.svg',
            'themes/default/images/icons/menu/index.html',
            'themes/default/images/icons/menu/menu/home.svg',
            'themes/default/images/icons/menu/menu/index.html',
            'themes/default/images/icons/menu/pages.svg',
            'themes/default/images/icons/menu/pages/about_us.svg',
            'themes/default/images/icons/menu/pages/advertise.svg',
            'themes/default/images/icons/menu/pages/donate.svg',
            'themes/default/images/icons/menu/pages/guestbook.svg',
            'themes/default/images/icons/menu/pages/home.svg',
            'themes/default/images/icons/menu/pages/index.html',
            'themes/default/images/icons/menu/pages/keymap.svg',
            'themes/default/images/icons/menu/pages/privacy_policy.svg',
            'themes/default/images/icons/menu/pages/rules.svg',
            'themes/default/images/icons/menu/rich_content.svg',
            'themes/default/images/icons/menu/rich_content/atoz.svg',
            'themes/default/images/icons/menu/rich_content/authors.svg',
            'themes/default/images/icons/menu/rich_content/calendar.svg',
            'themes/default/images/icons/menu/rich_content/catalogues/catalogues.svg',
            'themes/default/images/icons/menu/rich_content/catalogues/contacts.svg',
            'themes/default/images/icons/menu/rich_content/catalogues/faqs.svg',
            'themes/default/images/icons/menu/rich_content/catalogues/index.html',
            'themes/default/images/icons/menu/rich_content/catalogues/links.svg',
            'themes/default/images/icons/menu/rich_content/catalogues/products.svg',
            'themes/default/images/icons/menu/rich_content/catalogues/projects.svg',
            'themes/default/images/icons/menu/rich_content/downloads.svg',
            'themes/default/images/icons/menu/rich_content/ecommerce/index.html',
            'themes/default/images/icons/menu/rich_content/ecommerce/orders.svg',
            'themes/default/images/icons/menu/rich_content/ecommerce/purchase.svg',
            'themes/default/images/icons/menu/rich_content/ecommerce/shopping_cart.svg',
            'themes/default/images/icons/menu/rich_content/galleries.svg',
            'themes/default/images/icons/menu/rich_content/index.html',
            'themes/default/images/icons/menu/rich_content/news.svg',
            'themes/default/images/icons/menu/rich_content/quiz.svg',
            'themes/default/images/icons/menu/rich_content/wiki.svg',
            'themes/default/images/icons/menu/rich_content/wiki/index.html',
            'themes/default/images/icons/menu/rich_content/wiki/random_page.svg',
            'themes/default/images/icons/menu/site_meta.svg',
            'themes/default/images/icons/menu/site_meta/contact_us.svg',
            'themes/default/images/icons/menu/site_meta/index.html',
            'themes/default/images/icons/menu/site_meta/newsletters.svg',
            'themes/default/images/icons/menu/site_meta/recommend.svg',
            'themes/default/images/icons/menu/site_meta/tickets.svg',
            'themes/default/images/icons/menu/site_meta/user_actions/concede.svg',
            'themes/default/images/icons/menu/site_meta/user_actions/index.html',
            'themes/default/images/icons/menu/site_meta/user_actions/invisible.svg',
            'themes/default/images/icons/menu/site_meta/user_actions/join.svg',
            'themes/default/images/icons/menu/site_meta/user_actions/login.svg',
            'themes/default/images/icons/menu/site_meta/user_actions/logout.svg',
            'themes/default/images/icons/menu/site_meta/user_actions/lost_password.svg',
            'themes/default/images/icons/menu/social.svg',
            'themes/default/images/icons/menu/social/chat/chat.svg',
            'themes/default/images/icons/menu/social/chat/chatroom_add.svg',
            'themes/default/images/icons/menu/social/chat/index.html',
            'themes/default/images/icons/menu/social/chat/member_blocking.svg',
            'themes/default/images/icons/menu/social/chat/sound.svg',
            'themes/default/images/icons/menu/social/forum/forums.svg',
            'themes/default/images/icons/menu/social/forum/index.html',
            'themes/default/images/icons/menu/social/forum/inline_personal_posts.svg',
            'themes/default/images/icons/menu/social/forum/vforums/index.html',
            'themes/default/images/icons/menu/social/forum/vforums/involved_topics.svg',
            'themes/default/images/icons/menu/social/forum/vforums/posts_since_last_visit.svg',
            'themes/default/images/icons/menu/social/forum/vforums/recently_read_topics.svg',
            'themes/default/images/icons/menu/social/forum/vforums/unanswered_topics.svg',
            'themes/default/images/icons/menu/social/forum/vforums/unread_topics.svg',
            'themes/default/images/icons/menu/social/friends.svg',
            'themes/default/images/icons/menu/social/groups.svg',
            'themes/default/images/icons/menu/social/index.html',
            'themes/default/images/icons/menu/social/leader_board.svg',
            'themes/default/images/icons/menu/social/members.svg',
            'themes/default/images/icons/menu/social/points.svg',
            'themes/default/images/icons/menu/social/polls.svg',
            'themes/default/images/icons/menu/social/profile.svg',
            'themes/default/images/icons/menu/social/users_online.svg',
            'themes/default/images/icons/menu/social/warnings.svg',
            'themes/default/images/icons/menu/welcome.svg',
            'themes/default/images/icons/menus/index.html',
            'themes/default/images/icons/menus/menu.svg',
            'themes/default/images/icons/menus/menu_bullet.svg',
            'themes/default/images/icons/menus/menu_bullet_current.svg',
            'themes/default/images/icons/menus/menu_bullet_expand.svg',
            'themes/default/images/icons/menus/menu_bullet_expand_hover.svg',
            'themes/default/images/icons/menus/menu_bullet_hover.svg',
            'themes/default/images/icons/menus/mobile_menu.svg',
            'themes/default/images/icons/news/art.svg',
            'themes/default/images/icons/news/business.svg',
            'themes/default/images/icons/news/community.svg',
            'themes/default/images/icons/news/difficulties.svg',
            'themes/default/images/icons/news/entertainment.svg',
            'themes/default/images/icons/news/general.svg',
            'themes/default/images/icons/news/index.html',
            'themes/default/images/icons/news/technology.svg',
            'themes/default/images/icons/no_image.svg',
            'themes/default/images/icons/realtime_rain/email.svg',
            'themes/default/images/icons/realtime_rain/index.html',
            'themes/default/images/icons/realtime_rain/news.svg',
            'themes/default/images/icons/realtime_rain/next_but.svg',
            'themes/default/images/icons/realtime_rain/phone.svg',
            'themes/default/images/icons/realtime_rain/previous_but.svg',
            'themes/default/images/icons/realtime_rain/searchengine.svg',
            'themes/default/images/icons/results/index.html',
            'themes/default/images/icons/results/sortablefield_asc.svg',
            'themes/default/images/icons/results/sortablefield_desc.svg',
            'themes/default/images/icons/sortable_tables/filter.svg',
            'themes/default/images/icons/sortable_tables/index.html',
            'themes/default/images/icons/sortable_tables/sortable.svg',
            'themes/default/images/icons/spare/1.svg',
            'themes/default/images/icons/spare/2.svg',
            'themes/default/images/icons/spare/3.svg',
            'themes/default/images/icons/spare/4.svg',
            'themes/default/images/icons/spare/5.svg',
            'themes/default/images/icons/spare/6.svg',
            'themes/default/images/icons/spare/7.svg',
            'themes/default/images/icons/spare/8.svg',
            'themes/default/images/icons/spare/activity.svg',
            'themes/default/images/icons/spare/administration.svg',
            'themes/default/images/icons/spare/advice_and_guidance.svg',
            'themes/default/images/icons/spare/analytics.svg',
            'themes/default/images/icons/spare/book.svg',
            'themes/default/images/icons/spare/business_development.svg',
            'themes/default/images/icons/spare/classifieds.svg',
            'themes/default/images/icons/spare/collaboration.svg',
            'themes/default/images/icons/spare/compare.svg',
            'themes/default/images/icons/spare/computer.svg',
            'themes/default/images/icons/spare/content.svg',
            'themes/default/images/icons/spare/contributing.svg',
            'themes/default/images/icons/spare/credit.svg',
            'themes/default/images/icons/spare/css.svg',
            'themes/default/images/icons/spare/development.svg',
            'themes/default/images/icons/spare/disaster.svg',
            'themes/default/images/icons/spare/feedback_features.svg',
            'themes/default/images/icons/spare/fun_and_games.svg',
            'themes/default/images/icons/spare/gifts.svg',
            'themes/default/images/icons/spare/heartbreak.svg',
            'themes/default/images/icons/spare/idea.svg',
            'themes/default/images/icons/spare/index.html',
            'themes/default/images/icons/spare/installation.svg',
            'themes/default/images/icons/spare/internationalisation.svg',
            'themes/default/images/icons/spare/internet_technology.svg',
            'themes/default/images/icons/spare/introduction.svg',
            'themes/default/images/icons/spare/javascript.svg',
            'themes/default/images/icons/spare/maintenance.svg',
            'themes/default/images/icons/spare/mobile.svg',
            'themes/default/images/icons/spare/open_source.svg',
            'themes/default/images/icons/spare/opinion.svg',
            'themes/default/images/icons/spare/performance.svg',
            'themes/default/images/icons/spare/php.svg',
            'themes/default/images/icons/spare/popular.svg',
            'themes/default/images/icons/spare/power_tools.svg',
            'themes/default/images/icons/spare/promote.svg',
            'themes/default/images/icons/spare/recent.svg',
            'themes/default/images/icons/spare/referrals.svg',
            'themes/default/images/icons/spare/report_usability.svg',
            'themes/default/images/icons/spare/roles/agency.svg',
            'themes/default/images/icons/spare/roles/business_person.svg',
            'themes/default/images/icons/spare/roles/consultant.svg',
            'themes/default/images/icons/spare/roles/content_writer.svg',
            'themes/default/images/icons/spare/roles/designer.svg',
            'themes/default/images/icons/spare/roles/developer.svg',
            'themes/default/images/icons/spare/roles/friend.svg',
            'themes/default/images/icons/spare/roles/index.html',
            'themes/default/images/icons/spare/roles/project_manager.svg',
            'themes/default/images/icons/spare/roles/sales_person.svg',
            'themes/default/images/icons/spare/roles/tester.svg',
            'themes/default/images/icons/spare/roles/trainer.svg',
            'themes/default/images/icons/spare/roles/translator.svg',
            'themes/default/images/icons/spare/roles/webmaster.svg',
            'themes/default/images/icons/spare/seo.svg',
            'themes/default/images/icons/spare/social.svg',
            'themes/default/images/icons/spare/sponsored.svg',
            'themes/default/images/icons/spare/third_party_integration.svg',
            'themes/default/images/icons/spare/video2.svg',
            'themes/default/images/icons/spare/web_standards_and_accessibility.svg',
            'themes/default/images/icons/spare/webhosting.svg',
            'themes/default/images/icons/spare/workflows.svg',
            'themes/default/images/icons/spare/world.svg',
            'themes/default/images/icons/status/index.html',
            'themes/default/images/icons/status/inform.svg',
            'themes/default/images/icons/status/notice.svg',
            'themes/default/images/icons/status/warn.svg',
            'themes/default/images/icons/tabs/index.html',
            'themes/default/images/icons/tabs/member_account/edit/avatar.svg',
            'themes/default/images/icons/tabs/member_account/edit/data.svg',
            'themes/default/images/icons/tabs/member_account/edit/delete.svg',
            'themes/default/images/icons/tabs/member_account/edit/index.html',
            'themes/default/images/icons/tabs/member_account/edit/photo.svg',
            'themes/default/images/icons/tabs/member_account/edit/profile.svg',
            'themes/default/images/icons/tabs/member_account/edit/settings.svg',
            'themes/default/images/icons/tabs/member_account/edit/signature.svg',
            'themes/default/images/icons/tabs/member_account/edit/title.svg',
            'themes/default/images/icons/tabs/member_account/index.html',
            'themes/default/images/icons/tiers/bronze.svg',
            'themes/default/images/icons/tiers/gold.svg',
            'themes/default/images/icons/tiers/index.html',
            'themes/default/images/icons/tiers/platinum.svg',
            'themes/default/images/icons/tiers/silver.svg',
            'themes/default/images/icons/tool_buttons/commandr_off.svg',
            'themes/default/images/icons/tool_buttons/commandr_on.svg',
            'themes/default/images/icons/tool_buttons/inbox.svg',
            'themes/default/images/icons/tool_buttons/inbox2.svg',
            'themes/default/images/icons/tool_buttons/index.html',
            'themes/default/images/icons/tool_buttons/notifications.svg',
            'themes/default/images/icons/tool_buttons/notifications2.svg',
            'themes/default/images/icons/tool_buttons/realtime_rain_off.svg',
            'themes/default/images/icons/tool_buttons/realtime_rain_on.svg',
            'themes/default/images/icons/tool_buttons/sitemap.svg',
            'themes/default/images/icons/tool_buttons/software_chat.svg',
            'themes/default/images/icons/tool_buttons/top.svg',
            'themes/default/images/icons/tool_buttons/version_desktop.svg',
            'themes/default/images/icons/tool_buttons/version_mobile.svg',
            'themes/default/images/icons/trays/contract.svg',
            'themes/default/images/icons/trays/expand.svg',
            'themes/default/images/icons/trays/expcon.svg',
            'themes/default/images/icons/trays/index.html',
            'themes/default/images/icons/tree_field/category.svg',
            'themes/default/images/icons/tree_field/collapse.svg',
            'themes/default/images/icons/tree_field/entry.svg',
            'themes/default/images/icons/tree_field/expand.svg',
            'themes/default/images/icons/tree_field/index.html',
            'themes/default/images/icons/wiki/index.html',
            'themes/default/images/icons/wiki/link.svg',
            'themes/default/images/icons/wiki/link_hover.svg',
            'themes/default/images/icons_monochrome/admin/add.svg',
            'themes/default/images/icons_monochrome/admin/add_one_category.svg',
            'themes/default/images/icons_monochrome/admin/add_to_category.svg',
            'themes/default/images/icons_monochrome/admin/back.svg',
            'themes/default/images/icons_monochrome/admin/component.svg',
            'themes/default/images/icons_monochrome/admin/delete.svg',
            'themes/default/images/icons_monochrome/admin/delete2.svg',
            'themes/default/images/icons_monochrome/admin/delete3.svg',
            'themes/default/images/icons_monochrome/admin/edit.svg',
            'themes/default/images/icons_monochrome/admin/edit2.svg',
            'themes/default/images/icons_monochrome/admin/edit_one_category.svg',
            'themes/default/images/icons_monochrome/admin/edit_this.svg',
            'themes/default/images/icons_monochrome/admin/edit_this_category.svg',
            'themes/default/images/icons_monochrome/admin/export.svg',
            'themes/default/images/icons_monochrome/admin/export_spreadsheet.svg',
            'themes/default/images/icons_monochrome/admin/import.svg',
            'themes/default/images/icons_monochrome/admin/import_spreadsheet.svg',
            'themes/default/images/icons_monochrome/admin/index.html',
            'themes/default/images/icons_monochrome/admin/install.svg',
            'themes/default/images/icons_monochrome/admin/merge.svg',
            'themes/default/images/icons_monochrome/admin/move.svg',
            'themes/default/images/icons_monochrome/admin/reinstall.svg',
            'themes/default/images/icons_monochrome/admin/remove.svg',
            'themes/default/images/icons_monochrome/admin/revisions.svg',
            'themes/default/images/icons_monochrome/admin/sync.svg',
            'themes/default/images/icons_monochrome/admin/tool.svg',
            'themes/default/images/icons_monochrome/admin/tools.svg',
            'themes/default/images/icons_monochrome/admin/translate.svg',
            'themes/default/images/icons_monochrome/admin/upgrade.svg',
            'themes/default/images/icons_monochrome/admin/view_archive.svg',
            'themes/default/images/icons_monochrome/admin/view_this.svg',
            'themes/default/images/icons_monochrome/admin/view_this_category.svg',
            'themes/default/images/icons_monochrome/admin/warn.svg',
            'themes/default/images/icons_monochrome/admin/wiki_edit_tree.svg',
            'themes/default/images/icons_monochrome/admin/xml.svg',
            'themes/default/images/icons_monochrome/arrow_box/arrow_box.svg',
            'themes/default/images/icons_monochrome/arrow_box/arrow_box_hover.svg',
            'themes/default/images/icons_monochrome/arrow_box/index.html',
            'themes/default/images/icons_monochrome/birthday.svg',
            'themes/default/images/icons_monochrome/booking/blacked.svg',
            'themes/default/images/icons_monochrome/booking/book.svg',
            'themes/default/images/icons_monochrome/booking/bookable.svg',
            'themes/default/images/icons_monochrome/booking/booking.svg',
            'themes/default/images/icons_monochrome/booking/index.html',
            'themes/default/images/icons_monochrome/booking/supplement.svg',
            'themes/default/images/icons_monochrome/breadcrumbs.svg',
            'themes/default/images/icons_monochrome/buttons/add_ticket.svg',
            'themes/default/images/icons_monochrome/buttons/add_topic.svg',
            'themes/default/images/icons_monochrome/buttons/advanced.svg',
            'themes/default/images/icons_monochrome/buttons/all.svg',
            'themes/default/images/icons_monochrome/buttons/all2.svg',
            'themes/default/images/icons_monochrome/buttons/back.svg',
            'themes/default/images/icons_monochrome/buttons/calculate.svg',
            'themes/default/images/icons_monochrome/buttons/cancel.svg',
            'themes/default/images/icons_monochrome/buttons/cancel2.svg',
            'themes/default/images/icons_monochrome/buttons/cart_add.svg',
            'themes/default/images/icons_monochrome/buttons/cart_checkout.svg',
            'themes/default/images/icons_monochrome/buttons/cart_empty.svg',
            'themes/default/images/icons_monochrome/buttons/cart_update.svg',
            'themes/default/images/icons_monochrome/buttons/choose.svg',
            'themes/default/images/icons_monochrome/buttons/clear.svg',
            'themes/default/images/icons_monochrome/buttons/close.svg',
            'themes/default/images/icons_monochrome/buttons/closed.svg',
            'themes/default/images/icons_monochrome/buttons/convert.svg',
            'themes/default/images/icons_monochrome/buttons/copy.svg',
            'themes/default/images/icons_monochrome/buttons/download.svg',
            'themes/default/images/icons_monochrome/buttons/filter.svg',
            'themes/default/images/icons_monochrome/buttons/forum.svg',
            'themes/default/images/icons_monochrome/buttons/full_size.svg',
            'themes/default/images/icons_monochrome/buttons/ignore.svg',
            'themes/default/images/icons_monochrome/buttons/index.html',
            'themes/default/images/icons_monochrome/buttons/linear.svg',
            'themes/default/images/icons_monochrome/buttons/mark_read.svg',
            'themes/default/images/icons_monochrome/buttons/mark_unread.svg',
            'themes/default/images/icons_monochrome/buttons/more.svg',
            'themes/default/images/icons_monochrome/buttons/new_comment.svg',
            'themes/default/images/icons_monochrome/buttons/new_post_full.svg',
            'themes/default/images/icons_monochrome/buttons/new_quote.svg',
            'themes/default/images/icons_monochrome/buttons/new_reply.svg',
            'themes/default/images/icons_monochrome/buttons/new_reply_staff_only.svg',
            'themes/default/images/icons_monochrome/buttons/next.svg',
            'themes/default/images/icons_monochrome/buttons/next_none.svg',
            'themes/default/images/icons_monochrome/buttons/no.svg',
            'themes/default/images/icons_monochrome/buttons/notifications_disable.svg',
            'themes/default/images/icons_monochrome/buttons/notifications_enable.svg',
            'themes/default/images/icons_monochrome/buttons/pause.svg',
            'themes/default/images/icons_monochrome/buttons/points.svg',
            'themes/default/images/icons_monochrome/buttons/preview.svg',
            'themes/default/images/icons_monochrome/buttons/previous.svg',
            'themes/default/images/icons_monochrome/buttons/previous_none.svg',
            'themes/default/images/icons_monochrome/buttons/proceed.svg',
            'themes/default/images/icons_monochrome/buttons/proceed2.svg',
            'themes/default/images/icons_monochrome/buttons/redirect.svg',
            'themes/default/images/icons_monochrome/buttons/report.svg',
            'themes/default/images/icons_monochrome/buttons/save.svg',
            'themes/default/images/icons_monochrome/buttons/search.svg',
            'themes/default/images/icons_monochrome/buttons/send.svg',
            'themes/default/images/icons_monochrome/buttons/settings.svg',
            'themes/default/images/icons_monochrome/buttons/shrink_size.svg',
            'themes/default/images/icons_monochrome/buttons/simple.svg',
            'themes/default/images/icons_monochrome/buttons/skip.svg',
            'themes/default/images/icons_monochrome/buttons/slideshow.svg',
            'themes/default/images/icons_monochrome/buttons/sort.svg',
            'themes/default/images/icons_monochrome/buttons/sound_effects.svg',
            'themes/default/images/icons_monochrome/buttons/threaded.svg',
            'themes/default/images/icons_monochrome/buttons/thumbnail.svg',
            'themes/default/images/icons_monochrome/buttons/undo.svg',
            'themes/default/images/icons_monochrome/buttons/upload.svg',
            'themes/default/images/icons_monochrome/buttons/whisper.svg',
            'themes/default/images/icons_monochrome/buttons/yes.svg',
            'themes/default/images/icons_monochrome/calendar/activity.svg',
            'themes/default/images/icons_monochrome/calendar/anniversary.svg',
            'themes/default/images/icons_monochrome/calendar/appointment.svg',
            'themes/default/images/icons_monochrome/calendar/birthday.svg',
            'themes/default/images/icons_monochrome/calendar/commitment.svg',
            'themes/default/images/icons_monochrome/calendar/duty.svg',
            'themes/default/images/icons_monochrome/calendar/festival.svg',
            'themes/default/images/icons_monochrome/calendar/general.svg',
            'themes/default/images/icons_monochrome/calendar/index.html',
            'themes/default/images/icons_monochrome/calendar/public_holiday.svg',
            'themes/default/images/icons_monochrome/calendar/rss.svg',
            'themes/default/images/icons_monochrome/calendar/system_command.svg',
            'themes/default/images/icons_monochrome/calendar/vacation.svg',
            'themes/default/images/icons_monochrome/carousel/button_left.svg',
            'themes/default/images/icons_monochrome/carousel/button_left_hover.svg',
            'themes/default/images/icons_monochrome/carousel/button_right.svg',
            'themes/default/images/icons_monochrome/carousel/button_right_hover.svg',
            'themes/default/images/icons_monochrome/carousel/index.html',
            'themes/default/images/icons_monochrome/checklist/checklist_done.svg',
            'themes/default/images/icons_monochrome/checklist/checklist_na.svg',
            'themes/default/images/icons_monochrome/checklist/checklist_todo.svg',
            'themes/default/images/icons_monochrome/checklist/index.html',
            'themes/default/images/icons_monochrome/checklist/toggle.svg',
            'themes/default/images/icons_monochrome/checklist/toggle2.svg',
            'themes/default/images/icons_monochrome/cns_general/index.html',
            'themes/default/images/icons_monochrome/cns_general/is_off.svg',
            'themes/default/images/icons_monochrome/cns_general/is_on.svg',
            'themes/default/images/icons_monochrome/cns_general/new_posts.svg',
            'themes/default/images/icons_monochrome/cns_general/new_posts_redirect.svg',
            'themes/default/images/icons_monochrome/cns_general/no_new_posts.svg',
            'themes/default/images/icons_monochrome/cns_general/no_new_posts_redirect.svg',
            'themes/default/images/icons_monochrome/cns_general/redirect.svg',
            'themes/default/images/icons_monochrome/cns_topic_modifiers/announcement.svg',
            'themes/default/images/icons_monochrome/cns_topic_modifiers/closed.svg',
            'themes/default/images/icons_monochrome/cns_topic_modifiers/hot.svg',
            'themes/default/images/icons_monochrome/cns_topic_modifiers/index.html',
            'themes/default/images/icons_monochrome/cns_topic_modifiers/involved.svg',
            'themes/default/images/icons_monochrome/cns_topic_modifiers/not_validated.svg',
            'themes/default/images/icons_monochrome/cns_topic_modifiers/pinned.svg',
            'themes/default/images/icons_monochrome/cns_topic_modifiers/poll.svg',
            'themes/default/images/icons_monochrome/cns_topic_modifiers/unread.svg',
            'themes/default/images/icons_monochrome/comcode_editor/apply_changes.svg',
            'themes/default/images/icons_monochrome/comcode_editor/b.svg',
            'themes/default/images/icons_monochrome/comcode_editor/block.svg',
            'themes/default/images/icons_monochrome/comcode_editor/box.svg',
            'themes/default/images/icons_monochrome/comcode_editor/code.svg',
            'themes/default/images/icons_monochrome/comcode_editor/comcode.svg',
            'themes/default/images/icons_monochrome/comcode_editor/email.svg',
            'themes/default/images/icons_monochrome/comcode_editor/hide.svg',
            'themes/default/images/icons_monochrome/comcode_editor/html.svg',
            'themes/default/images/icons_monochrome/comcode_editor/i.svg',
            'themes/default/images/icons_monochrome/comcode_editor/img.svg',
            'themes/default/images/icons_monochrome/comcode_editor/index.html',
            'themes/default/images/icons_monochrome/comcode_editor/list.svg',
            'themes/default/images/icons_monochrome/comcode_editor/page.svg',
            'themes/default/images/icons_monochrome/comcode_editor/quote.svg',
            'themes/default/images/icons_monochrome/comcode_editor/s.svg',
            'themes/default/images/icons_monochrome/comcode_editor/thumb.svg',
            'themes/default/images/icons_monochrome/comcode_editor/u.svg',
            'themes/default/images/icons_monochrome/comcode_editor/url.svg',
            'themes/default/images/icons_monochrome/contact_methods/address.svg',
            'themes/default/images/icons_monochrome/contact_methods/email.svg',
            'themes/default/images/icons_monochrome/contact_methods/index.html',
            'themes/default/images/icons_monochrome/contact_methods/telephone.svg',
            'themes/default/images/icons_monochrome/content_types/audio.svg',
            'themes/default/images/icons_monochrome/content_types/image.svg',
            'themes/default/images/icons_monochrome/content_types/index.html',
            'themes/default/images/icons_monochrome/content_types/member.svg',
            'themes/default/images/icons_monochrome/content_types/multimedia.svg',
            'themes/default/images/icons_monochrome/content_types/page.svg',
            'themes/default/images/icons_monochrome/content_types/post.svg',
            'themes/default/images/icons_monochrome/content_types/topic.svg',
            'themes/default/images/icons_monochrome/content_types/video.svg',
            'themes/default/images/icons_monochrome/editor/comcode.svg',
            'themes/default/images/icons_monochrome/editor/index.html',
            'themes/default/images/icons_monochrome/editor/insert_emoticons.svg',
            'themes/default/images/icons_monochrome/editor/wysiwyg_off.svg',
            'themes/default/images/icons_monochrome/editor/wysiwyg_on.svg',
            'themes/default/images/icons_monochrome/features.svg',
            'themes/default/images/icons_monochrome/feedback/comment.svg',
            'themes/default/images/icons_monochrome/feedback/comments_topic.svg',
            'themes/default/images/icons_monochrome/feedback/dislike.svg',
            'themes/default/images/icons_monochrome/feedback/dislike2.svg',
            'themes/default/images/icons_monochrome/feedback/index.html',
            'themes/default/images/icons_monochrome/feedback/like.svg',
            'themes/default/images/icons_monochrome/feedback/like2.svg',
            'themes/default/images/icons_monochrome/feedback/rate.svg',
            'themes/default/images/icons_monochrome/feedback/rating.svg',
            'themes/default/images/icons_monochrome/file_types/email_link.svg',
            'themes/default/images/icons_monochrome/file_types/external_link.svg',
            'themes/default/images/icons_monochrome/file_types/index.html',
            'themes/default/images/icons_monochrome/file_types/page_archive.svg',
            'themes/default/images/icons_monochrome/file_types/page_css.svg',
            'themes/default/images/icons_monochrome/file_types/page_doc.svg',
            'themes/default/images/icons_monochrome/file_types/page_feed.svg',
            'themes/default/images/icons_monochrome/file_types/page_js.svg',
            'themes/default/images/icons_monochrome/file_types/page_media.svg',
            'themes/default/images/icons_monochrome/file_types/page_odp.svg',
            'themes/default/images/icons_monochrome/file_types/page_ods.svg',
            'themes/default/images/icons_monochrome/file_types/page_odt.svg',
            'themes/default/images/icons_monochrome/file_types/page_pdf.svg',
            'themes/default/images/icons_monochrome/file_types/page_ppt.svg',
            'themes/default/images/icons_monochrome/file_types/page_torrent.svg',
            'themes/default/images/icons_monochrome/file_types/page_tpl.svg',
            'themes/default/images/icons_monochrome/file_types/page_txt.svg',
            'themes/default/images/icons_monochrome/file_types/page_xls.svg',
            'themes/default/images/icons_monochrome/file_types/page_xml.svg',
            'themes/default/images/icons_monochrome/help.svg',
            'themes/default/images/icons_monochrome/helper_panel/hide.svg',
            'themes/default/images/icons_monochrome/helper_panel/index.html',
            'themes/default/images/icons_monochrome/helper_panel/show.svg',
            'themes/default/images/icons_monochrome/index.html',
            'themes/default/images/icons_monochrome/links/amazon.svg',
            'themes/default/images/icons_monochrome/links/apple.svg',
            'themes/default/images/icons_monochrome/links/baidu_tieba.svg',
            'themes/default/images/icons_monochrome/links/bandcamp.svg',
            'themes/default/images/icons_monochrome/links/bitcoin.svg',
            'themes/default/images/icons_monochrome/links/contact_member.svg',
            'themes/default/images/icons_monochrome/links/dailymotion.svg',
            'themes/default/images/icons_monochrome/links/diaspora.svg',
            'themes/default/images/icons_monochrome/links/discord.svg',
            'themes/default/images/icons_monochrome/links/download_as_archive.svg',
            'themes/default/images/icons_monochrome/links/dropbox.svg',
            'themes/default/images/icons_monochrome/links/dtube.svg',
            'themes/default/images/icons_monochrome/links/facebook.svg',
            'themes/default/images/icons_monochrome/links/favorites.svg',
            'themes/default/images/icons_monochrome/links/flattr.svg',
            'themes/default/images/icons_monochrome/links/github.svg',
            'themes/default/images/icons_monochrome/links/gitlab.svg',
            'themes/default/images/icons_monochrome/links/google.svg',
            'themes/default/images/icons_monochrome/links/hacker_news.svg',
            'themes/default/images/icons_monochrome/links/index.html',
            'themes/default/images/icons_monochrome/links/instagram.svg',
            'themes/default/images/icons_monochrome/links/jabber.svg',
            'themes/default/images/icons_monochrome/links/line.svg',
            'themes/default/images/icons_monochrome/links/linkedin.svg',
            'themes/default/images/icons_monochrome/links/mastodon.svg',
            'themes/default/images/icons_monochrome/links/microsoft.svg',
            'themes/default/images/icons_monochrome/links/minds.svg',
            'themes/default/images/icons_monochrome/links/patreon.svg',
            'themes/default/images/icons_monochrome/links/paypal.svg',
            'themes/default/images/icons_monochrome/links/pinterest.svg',
            'themes/default/images/icons_monochrome/links/playstation_network.svg',
            'themes/default/images/icons_monochrome/links/print.svg',
            'themes/default/images/icons_monochrome/links/quora.svg',
            'themes/default/images/icons_monochrome/links/qzone.svg',
            'themes/default/images/icons_monochrome/links/reddit.svg',
            'themes/default/images/icons_monochrome/links/rss.svg',
            'themes/default/images/icons_monochrome/links/sina_weibo.svg',
            'themes/default/images/icons_monochrome/links/skype.svg',
            'themes/default/images/icons_monochrome/links/slashdot.svg',
            'themes/default/images/icons_monochrome/links/snapchat.svg',
            'themes/default/images/icons_monochrome/links/soundcloud.svg',
            'themes/default/images/icons_monochrome/links/spotify.svg',
            'themes/default/images/icons_monochrome/links/stack_overflow.svg',
            'themes/default/images/icons_monochrome/links/stackexchange.svg',
            'themes/default/images/icons_monochrome/links/steam.svg',
            'themes/default/images/icons_monochrome/links/steemit.svg',
            'themes/default/images/icons_monochrome/links/telegram.svg',
            'themes/default/images/icons_monochrome/links/tiktok.svg',
            'themes/default/images/icons_monochrome/links/tumblr.svg',
            'themes/default/images/icons_monochrome/links/twitch.svg',
            'themes/default/images/icons_monochrome/links/twitter.svg',
            'themes/default/images/icons_monochrome/links/utopian.svg',
            'themes/default/images/icons_monochrome/links/viber.svg',
            'themes/default/images/icons_monochrome/links/vimeo.svg',
            'themes/default/images/icons_monochrome/links/vkontakte.svg',
            'themes/default/images/icons_monochrome/links/warning_add.svg',
            'themes/default/images/icons_monochrome/links/wechat.svg',
            'themes/default/images/icons_monochrome/links/whatsapp.svg',
            'themes/default/images/icons_monochrome/links/xbox_live.svg',
            'themes/default/images/icons_monochrome/links/yahoo.svg',
            'themes/default/images/icons_monochrome/links/youtube.svg',
            'themes/default/images/icons_monochrome/media_set/index.html',
            'themes/default/images/icons_monochrome/media_set/lightbox_close.svg',
            'themes/default/images/icons_monochrome/media_set/next.svg',
            'themes/default/images/icons_monochrome/media_set/previous.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/adminzone.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/actionlog.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/content_reviews.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/ecommerce/cash_flow.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/ecommerce/create_invoice.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/ecommerce/ecommerce.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/ecommerce/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/ecommerce/invoices.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/ecommerce/profit_loss.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/ecommerce/sales.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/ecommerce/subscriptions.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/ecommerce/transactions_log.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/ecommerce/undispatched_orders.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/email_log.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/errorlog.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/not_validated.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/points_log.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/realtime_rain.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/security_log.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/statistics/demographics.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/statistics/geolocate.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/statistics/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/statistics/load_times.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/statistics/page_views.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/statistics/search.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/statistics/statistics.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/statistics/submits.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/statistics/top_referrers.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/statistics/users_online.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/audit/trackbacks.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/home.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/security.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/security/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/security/ip_ban.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/security/ldap.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/security/permissions/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/security/permissions/match_keys.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/security/permissions/permission_tree_editor.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/security/permissions/privileges.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/security/usergroups_temp.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/security/wordfilter.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/setup.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/setup/awards.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/setup/config/base_config.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/setup/config/config.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/setup/config/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/setup/custom_comcode.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/setup/ecommerce_products.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/setup/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/setup/notifications.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/setup/oauth.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/setup/setupwizard.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/setup/welcome_emails.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/setup/xml_fields.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/sponsors.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/structure.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/addons.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/aggregate_types.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/breadcrumbs.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/forum/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/forum/multi_moderations.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/forum/post_templates.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/menus.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/redirects.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/sitemap/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/sitemap/sitemap_editor.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/zones/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/zones/zone_editor.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/zones/zones.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/style.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/style/debrand.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/style/emoticons.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/style/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/style/language/criticise_language.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/style/language/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/style/language/language.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/style/language/language_content.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/style/quotes.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/style/themes/css.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/style/themes/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/style/themes/logowizard.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/style/themes/templates.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/style/themes/theme_images.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/style/themes/themes.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/style/themes/themewizard.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/broken_urls.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/bulk_content_actions/backups.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/bulk_content_actions/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/cleanup.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/code_editor.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/commandr.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/health_check.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/newsletter/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/newsletter/newsletter_email_bounce.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/newsletter/newsletter_from_changes.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/newsletter/subscribers.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/phpinfo.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/upgrade.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/users/custom_profile_fields.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/users/delete_lurkers.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/users/index.html',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/users/investigate_user.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/users/member_add.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/users/member_edit.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/tools/users/merge_members.svg',
            'themes/default/images/icons_monochrome/menu/cms/author_set_own_profile.svg',
            'themes/default/images/icons_monochrome/menu/cms/banners.svg',
            'themes/default/images/icons_monochrome/menu/cms/blog.svg',
            'themes/default/images/icons_monochrome/menu/cms/catalogues/add_one_catalogue.svg',
            'themes/default/images/icons_monochrome/menu/cms/catalogues/edit_one_catalogue.svg',
            'themes/default/images/icons_monochrome/menu/cms/catalogues/edit_this_catalogue.svg',
            'themes/default/images/icons_monochrome/menu/cms/catalogues/index.html',
            'themes/default/images/icons_monochrome/menu/cms/clubs.svg',
            'themes/default/images/icons_monochrome/menu/cms/cms.svg',
            'themes/default/images/icons_monochrome/menu/cms/comcode_page_edit.svg',
            'themes/default/images/icons_monochrome/menu/cms/downloads/add_one_licence.svg',
            'themes/default/images/icons_monochrome/menu/cms/downloads/edit_one_licence.svg',
            'themes/default/images/icons_monochrome/menu/cms/downloads/index.html',
            'themes/default/images/icons_monochrome/menu/cms/filedump.svg',
            'themes/default/images/icons_monochrome/menu/cms/galleries/add_one_image.svg',
            'themes/default/images/icons_monochrome/menu/cms/galleries/add_one_multimedia.svg',
            'themes/default/images/icons_monochrome/menu/cms/galleries/add_one_video.svg',
            'themes/default/images/icons_monochrome/menu/cms/galleries/edit_one_image.svg',
            'themes/default/images/icons_monochrome/menu/cms/galleries/edit_one_multimedia.svg',
            'themes/default/images/icons_monochrome/menu/cms/galleries/edit_one_video.svg',
            'themes/default/images/icons_monochrome/menu/cms/galleries/index.html',
            'themes/default/images/icons_monochrome/menu/cms/index.html',
            'themes/default/images/icons_monochrome/menu/cms/quiz/find_winners.svg',
            'themes/default/images/icons_monochrome/menu/cms/quiz/index.html',
            'themes/default/images/icons_monochrome/menu/cms/quiz/quiz_results.svg',
            'themes/default/images/icons_monochrome/menu/home.svg',
            'themes/default/images/icons_monochrome/menu/index.html',
            'themes/default/images/icons_monochrome/menu/menu/home.svg',
            'themes/default/images/icons_monochrome/menu/menu/index.html',
            'themes/default/images/icons_monochrome/menu/pages.svg',
            'themes/default/images/icons_monochrome/menu/pages/about_us.svg',
            'themes/default/images/icons_monochrome/menu/pages/advertise.svg',
            'themes/default/images/icons_monochrome/menu/pages/donate.svg',
            'themes/default/images/icons_monochrome/menu/pages/guestbook.svg',
            'themes/default/images/icons_monochrome/menu/pages/home.svg',
            'themes/default/images/icons_monochrome/menu/pages/index.html',
            'themes/default/images/icons_monochrome/menu/pages/keymap.svg',
            'themes/default/images/icons_monochrome/menu/pages/privacy_policy.svg',
            'themes/default/images/icons_monochrome/menu/pages/rules.svg',
            'themes/default/images/icons_monochrome/menu/rich_content.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/atoz.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/authors.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/calendar.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/catalogues/catalogues.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/catalogues/contacts.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/catalogues/faqs.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/catalogues/index.html',
            'themes/default/images/icons_monochrome/menu/rich_content/catalogues/links.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/catalogues/products.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/catalogues/projects.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/downloads.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/ecommerce/index.html',
            'themes/default/images/icons_monochrome/menu/rich_content/ecommerce/orders.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/ecommerce/purchase.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/ecommerce/shopping_cart.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/galleries.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/index.html',
            'themes/default/images/icons_monochrome/menu/rich_content/news.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/quiz.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/wiki.svg',
            'themes/default/images/icons_monochrome/menu/rich_content/wiki/index.html',
            'themes/default/images/icons_monochrome/menu/rich_content/wiki/random_page.svg',
            'themes/default/images/icons_monochrome/menu/site_meta.svg',
            'themes/default/images/icons_monochrome/menu/site_meta/contact_us.svg',
            'themes/default/images/icons_monochrome/menu/site_meta/index.html',
            'themes/default/images/icons_monochrome/menu/site_meta/newsletters.svg',
            'themes/default/images/icons_monochrome/menu/site_meta/recommend.svg',
            'themes/default/images/icons_monochrome/menu/site_meta/tickets.svg',
            'themes/default/images/icons_monochrome/menu/site_meta/user_actions/concede.svg',
            'themes/default/images/icons_monochrome/menu/site_meta/user_actions/index.html',
            'themes/default/images/icons_monochrome/menu/site_meta/user_actions/invisible.svg',
            'themes/default/images/icons_monochrome/menu/site_meta/user_actions/join.svg',
            'themes/default/images/icons_monochrome/menu/site_meta/user_actions/login.svg',
            'themes/default/images/icons_monochrome/menu/site_meta/user_actions/logout.svg',
            'themes/default/images/icons_monochrome/menu/site_meta/user_actions/lost_password.svg',
            'themes/default/images/icons_monochrome/menu/social.svg',
            'themes/default/images/icons_monochrome/menu/social/chat/chat.svg',
            'themes/default/images/icons_monochrome/menu/social/chat/chatroom_add.svg',
            'themes/default/images/icons_monochrome/menu/social/chat/index.html',
            'themes/default/images/icons_monochrome/menu/social/chat/member_blocking.svg',
            'themes/default/images/icons_monochrome/menu/social/chat/sound.svg',
            'themes/default/images/icons_monochrome/menu/social/forum/forums.svg',
            'themes/default/images/icons_monochrome/menu/social/forum/index.html',
            'themes/default/images/icons_monochrome/menu/social/forum/inline_personal_posts.svg',
            'themes/default/images/icons_monochrome/menu/social/forum/vforums/index.html',
            'themes/default/images/icons_monochrome/menu/social/forum/vforums/involved_topics.svg',
            'themes/default/images/icons_monochrome/menu/social/forum/vforums/posts_since_last_visit.svg',
            'themes/default/images/icons_monochrome/menu/social/forum/vforums/recently_read_topics.svg',
            'themes/default/images/icons_monochrome/menu/social/forum/vforums/unanswered_topics.svg',
            'themes/default/images/icons_monochrome/menu/social/forum/vforums/unread_topics.svg',
            'themes/default/images/icons_monochrome/menu/social/friends.svg',
            'themes/default/images/icons_monochrome/menu/social/groups.svg',
            'themes/default/images/icons_monochrome/menu/social/index.html',
            'themes/default/images/icons_monochrome/menu/social/leader_board.svg',
            'themes/default/images/icons_monochrome/menu/social/members.svg',
            'themes/default/images/icons_monochrome/menu/social/points.svg',
            'themes/default/images/icons_monochrome/menu/social/polls.svg',
            'themes/default/images/icons_monochrome/menu/social/profile.svg',
            'themes/default/images/icons_monochrome/menu/social/users_online.svg',
            'themes/default/images/icons_monochrome/menu/social/warnings.svg',
            'themes/default/images/icons_monochrome/menu/welcome.svg',
            'themes/default/images/icons_monochrome/menus/index.html',
            'themes/default/images/icons_monochrome/menus/menu.svg',
            'themes/default/images/icons_monochrome/menus/menu_bullet.svg',
            'themes/default/images/icons_monochrome/menus/menu_bullet_current.svg',
            'themes/default/images/icons_monochrome/menus/menu_bullet_expand.svg',
            'themes/default/images/icons_monochrome/menus/menu_bullet_expand_hover.svg',
            'themes/default/images/icons_monochrome/menus/menu_bullet_hover.svg',
            'themes/default/images/icons_monochrome/menus/mobile_menu.svg',
            'themes/default/images/icons_monochrome/news/art.svg',
            'themes/default/images/icons_monochrome/news/business.svg',
            'themes/default/images/icons_monochrome/news/community.svg',
            'themes/default/images/icons_monochrome/news/difficulties.svg',
            'themes/default/images/icons_monochrome/news/entertainment.svg',
            'themes/default/images/icons_monochrome/news/general.svg',
            'themes/default/images/icons_monochrome/news/index.html',
            'themes/default/images/icons_monochrome/news/technology.svg',
            'themes/default/images/icons_monochrome/no_image.svg',
            'themes/default/images/icons_monochrome/realtime_rain/email.svg',
            'themes/default/images/icons_monochrome/realtime_rain/index.html',
            'themes/default/images/icons_monochrome/realtime_rain/news.svg',
            'themes/default/images/icons_monochrome/realtime_rain/next_but.svg',
            'themes/default/images/icons_monochrome/realtime_rain/phone.svg',
            'themes/default/images/icons_monochrome/realtime_rain/previous_but.svg',
            'themes/default/images/icons_monochrome/realtime_rain/searchengine.svg',
            'themes/default/images/icons_monochrome/results/index.html',
            'themes/default/images/icons_monochrome/results/sortablefield_asc.svg',
            'themes/default/images/icons_monochrome/results/sortablefield_desc.svg',
            'themes/default/images/icons_monochrome/sortable_tables/filter.svg',
            'themes/default/images/icons_monochrome/sortable_tables/index.html',
            'themes/default/images/icons_monochrome/sortable_tables/sortable.svg',
            'themes/default/images/icons_monochrome/spare/1.svg',
            'themes/default/images/icons_monochrome/spare/2.svg',
            'themes/default/images/icons_monochrome/spare/3.svg',
            'themes/default/images/icons_monochrome/spare/4.svg',
            'themes/default/images/icons_monochrome/spare/5.svg',
            'themes/default/images/icons_monochrome/spare/6.svg',
            'themes/default/images/icons_monochrome/spare/7.svg',
            'themes/default/images/icons_monochrome/spare/8.svg',
            'themes/default/images/icons_monochrome/spare/activity.svg',
            'themes/default/images/icons_monochrome/spare/administration.svg',
            'themes/default/images/icons_monochrome/spare/advice_and_guidance.svg',
            'themes/default/images/icons_monochrome/spare/analytics.svg',
            'themes/default/images/icons_monochrome/spare/book.svg',
            'themes/default/images/icons_monochrome/spare/business_development.svg',
            'themes/default/images/icons_monochrome/spare/classifieds.svg',
            'themes/default/images/icons_monochrome/spare/collaboration.svg',
            'themes/default/images/icons_monochrome/spare/compare.svg',
            'themes/default/images/icons_monochrome/spare/computer.svg',
            'themes/default/images/icons_monochrome/spare/content.svg',
            'themes/default/images/icons_monochrome/spare/contributing.svg',
            'themes/default/images/icons_monochrome/spare/credit.svg',
            'themes/default/images/icons_monochrome/spare/css.svg',
            'themes/default/images/icons_monochrome/spare/development.svg',
            'themes/default/images/icons_monochrome/spare/disaster.svg',
            'themes/default/images/icons_monochrome/spare/feedback_features.svg',
            'themes/default/images/icons_monochrome/spare/fun_and_games.svg',
            'themes/default/images/icons_monochrome/spare/gifts.svg',
            'themes/default/images/icons_monochrome/spare/heartbreak.svg',
            'themes/default/images/icons_monochrome/spare/idea.svg',
            'themes/default/images/icons_monochrome/spare/index.html',
            'themes/default/images/icons_monochrome/spare/installation.svg',
            'themes/default/images/icons_monochrome/spare/internationalisation.svg',
            'themes/default/images/icons_monochrome/spare/internet_technology.svg',
            'themes/default/images/icons_monochrome/spare/introduction.svg',
            'themes/default/images/icons_monochrome/spare/javascript.svg',
            'themes/default/images/icons_monochrome/spare/maintenance.svg',
            'themes/default/images/icons_monochrome/spare/mobile.svg',
            'themes/default/images/icons_monochrome/spare/open_source.svg',
            'themes/default/images/icons_monochrome/spare/opinion.svg',
            'themes/default/images/icons_monochrome/spare/performance.svg',
            'themes/default/images/icons_monochrome/spare/php.svg',
            'themes/default/images/icons_monochrome/spare/popular.svg',
            'themes/default/images/icons_monochrome/spare/power_tools.svg',
            'themes/default/images/icons_monochrome/spare/promote.svg',
            'themes/default/images/icons_monochrome/spare/recent.svg',
            'themes/default/images/icons_monochrome/spare/referrals.svg',
            'themes/default/images/icons_monochrome/spare/report_usability.svg',
            'themes/default/images/icons_monochrome/spare/roles/agency.svg',
            'themes/default/images/icons_monochrome/spare/roles/business_person.svg',
            'themes/default/images/icons_monochrome/spare/roles/consultant.svg',
            'themes/default/images/icons_monochrome/spare/roles/content_writer.svg',
            'themes/default/images/icons_monochrome/spare/roles/designer.svg',
            'themes/default/images/icons_monochrome/spare/roles/developer.svg',
            'themes/default/images/icons_monochrome/spare/roles/friend.svg',
            'themes/default/images/icons_monochrome/spare/roles/index.html',
            'themes/default/images/icons_monochrome/spare/roles/project_manager.svg',
            'themes/default/images/icons_monochrome/spare/roles/sales_person.svg',
            'themes/default/images/icons_monochrome/spare/roles/tester.svg',
            'themes/default/images/icons_monochrome/spare/roles/trainer.svg',
            'themes/default/images/icons_monochrome/spare/roles/translator.svg',
            'themes/default/images/icons_monochrome/spare/roles/webmaster.svg',
            'themes/default/images/icons_monochrome/spare/seo.svg',
            'themes/default/images/icons_monochrome/spare/social.svg',
            'themes/default/images/icons_monochrome/spare/sponsored.svg',
            'themes/default/images/icons_monochrome/spare/third_party_integration.svg',
            'themes/default/images/icons_monochrome/spare/video2.svg',
            'themes/default/images/icons_monochrome/spare/web_standards_and_accessibility.svg',
            'themes/default/images/icons_monochrome/spare/webhosting.svg',
            'themes/default/images/icons_monochrome/spare/workflows.svg',
            'themes/default/images/icons_monochrome/spare/world.svg',
            'themes/default/images/icons_monochrome/status/index.html',
            'themes/default/images/icons_monochrome/status/inform.svg',
            'themes/default/images/icons_monochrome/status/notice.svg',
            'themes/default/images/icons_monochrome/status/warn.svg',
            'themes/default/images/icons_monochrome/tabs/index.html',
            'themes/default/images/icons_monochrome/tabs/member_account/edit/avatar.svg',
            'themes/default/images/icons_monochrome/tabs/member_account/edit/data.svg',
            'themes/default/images/icons_monochrome/tabs/member_account/edit/delete.svg',
            'themes/default/images/icons_monochrome/tabs/member_account/edit/index.html',
            'themes/default/images/icons_monochrome/tabs/member_account/edit/photo.svg',
            'themes/default/images/icons_monochrome/tabs/member_account/edit/profile.svg',
            'themes/default/images/icons_monochrome/tabs/member_account/edit/settings.svg',
            'themes/default/images/icons_monochrome/tabs/member_account/edit/signature.svg',
            'themes/default/images/icons_monochrome/tabs/member_account/edit/title.svg',
            'themes/default/images/icons_monochrome/tabs/member_account/index.html',
            'themes/default/images/icons_monochrome/tiers/bronze.svg',
            'themes/default/images/icons_monochrome/tiers/gold.svg',
            'themes/default/images/icons_monochrome/tiers/index.html',
            'themes/default/images/icons_monochrome/tiers/platinum.svg',
            'themes/default/images/icons_monochrome/tiers/silver.svg',
            'themes/default/images/icons_monochrome/tool_buttons/commandr_off.svg',
            'themes/default/images/icons_monochrome/tool_buttons/commandr_on.svg',
            'themes/default/images/icons_monochrome/tool_buttons/inbox.svg',
            'themes/default/images/icons_monochrome/tool_buttons/inbox2.svg',
            'themes/default/images/icons_monochrome/tool_buttons/index.html',
            'themes/default/images/icons_monochrome/tool_buttons/notifications.svg',
            'themes/default/images/icons_monochrome/tool_buttons/notifications2.svg',
            'themes/default/images/icons_monochrome/tool_buttons/realtime_rain_off.svg',
            'themes/default/images/icons_monochrome/tool_buttons/realtime_rain_on.svg',
            'themes/default/images/icons_monochrome/tool_buttons/sitemap.svg',
            'themes/default/images/icons_monochrome/tool_buttons/software_chat.svg',
            'themes/default/images/icons_monochrome/tool_buttons/top.svg',
            'themes/default/images/icons_monochrome/tool_buttons/version_desktop.svg',
            'themes/default/images/icons_monochrome/tool_buttons/version_mobile.svg',
            'themes/default/images/icons_monochrome/trays/contract.svg',
            'themes/default/images/icons_monochrome/trays/expand.svg',
            'themes/default/images/icons_monochrome/trays/expcon.svg',
            'themes/default/images/icons_monochrome/trays/index.html',
            'themes/default/images/icons_monochrome/tree_field/category.svg',
            'themes/default/images/icons_monochrome/tree_field/collapse.svg',
            'themes/default/images/icons_monochrome/tree_field/entry.svg',
            'themes/default/images/icons_monochrome/tree_field/expand.svg',
            'themes/default/images/icons_monochrome/tree_field/index.html',
            'themes/default/images/icons_monochrome/wiki/index.html',
            'themes/default/images/icons_monochrome/wiki/link.svg',
            'themes/default/images/icons_monochrome/wiki/link_hover.svg',
            'themes/default/images/icons_monochrome_sprite.svg',
            'themes/default/images/icons_sprite.svg',
        ];
    }
}
