<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core_menus
 */

/**
 * Hook class.
 */
class Hook_addon_registry_core_menus
{
    /**
     * Get a list of file permissions to set.
     *
     * @param  boolean $runtime Whether to include wildcards represented runtime-created chmoddable files
     * @return array File permissions to set
     */
    public function get_chmod_array(bool $runtime = false) : array
    {
        return [];
    }

    /**
     * Get the version of Composr this addon is for (used in generating the TAR filename).
     *
     * @return float Version number
     */
    public function get_version() : float
    {
        return cms_version_number();
    }

    /**
     * Get the minimum required version of the website software needed to use this addon.
     *
     * @return float Minimum required website software version
     */
    public function get_min_cms_version() : float
    {
        return 11.0;
    }

    /**
     * Get the maximum compatible version of the website software to use this addon.
     *
     * @return ?float Maximum compatible website software version (null: no maximum version currently)
     */
    public function get_max_cms_version() : ?float
    {
        return null;
    }

    /**
     * Get the addon category.
     *
     * @return string The category
     */
    public function get_category() : string
    {
        return 'Architecture';
    }

    /**
     * Get the description of the addon.
     *
     * @return string Description of the addon
     */
    public function get_description() : string
    {
        return 'Edit menus.';
    }

    /**
     * Get a list of tutorials that apply to this addon.
     *
     * @return array List of tutorials
     */
    public function get_applicable_tutorials() : array
    {
        return [
            'tut_menus',
        ];
    }

    /**
     * Get a mapping of dependency types.
     *
     * @return array A structure specifying dependency information
     */
    public function get_dependencies() : array
    {
        return [
            'requires' => [],
            'recommends' => [],
            'conflicts_with' => [],
        ];
    }

    /**
     * Explicitly say which icon should be used.
     *
     * @return URLPATH Icon
     */
    public function get_default_icon() : string
    {
        return 'themes/default/images/icons/menu/adminzone/structure/menus.svg';
    }

    /**
     * Get a list of files that belong to this addon.
     *
     * @return array List of files
     */
    public function get_file_list() : array
    {
        return [
            'adminzone/menu_management.php',
            'adminzone/pages/modules/admin_menus.php',
            'data/page_link_chooser.php',
            'lang/EN/menus.ini',
            'sources/blocks/menu.php',
            'sources/hooks/systems/addon_registry/core_menus.php',
            'sources/hooks/systems/commandr_fs/menus.php',
            'sources/hooks/systems/preview/menu.php',
            'sources/hooks/systems/resource_meta_aware/menu.php',
            'sources/hooks/systems/resource_meta_aware/menu_item.php',
            'sources/hooks/systems/snippets/management_menu.php',
            'sources/menus.php',
            'sources/menus2.php',
            'sources/menus_comcode.php',
            'themes/admin/css/menu__dropdown.css',
            'themes/admin/templates/MENU_BRANCH_dropdown.tpl',
            'themes/admin/templates/MENU_dropdown.tpl',
            'themes/admin/templates/MENU_mobile.tpl',
            'themes/default/css/menu__dropdown.css',
            'themes/default/css/menu__embossed.css',
            'themes/default/css/menu__mobile.css',
            'themes/default/css/menu__popup.css',
            'themes/default/css/menu__select.css',
            'themes/default/css/menu__sitemap.css',
            'themes/default/css/menu__tree.css',
            'themes/default/css/menu_editor.css',
            'themes/default/images/icons/menu/adminzone/structure/menus.svg',
            'themes/default/images/icons/menus/index.html',
            'themes/default/images/icons/menus/menu.svg',
            'themes/default/images/icons/menus/menu_bullet.svg',
            'themes/default/images/icons/menus/menu_bullet_current.svg',
            'themes/default/images/icons/menus/menu_bullet_expand.svg',
            'themes/default/images/icons/menus/menu_bullet_expand_hover.svg',
            'themes/default/images/icons/menus/menu_bullet_hover.svg',
            'themes/default/images/icons/menus/mobile_menu.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/structure/menus.svg',
            'themes/default/images/icons_monochrome/menus/index.html',
            'themes/default/images/icons_monochrome/menus/menu.svg',
            'themes/default/images/icons_monochrome/menus/menu_bullet.svg',
            'themes/default/images/icons_monochrome/menus/menu_bullet_current.svg',
            'themes/default/images/icons_monochrome/menus/menu_bullet_expand.svg',
            'themes/default/images/icons_monochrome/menus/menu_bullet_expand_hover.svg',
            'themes/default/images/icons_monochrome/menus/menu_bullet_hover.svg',
            'themes/default/images/icons_monochrome/menus/mobile_menu.svg',
            'themes/default/javascript/core_menus.js',
            'themes/default/templates/BLOCK_MENU.tpl',
            'themes/default/templates/MENU_BRANCH_dropdown.tpl',
            'themes/default/templates/MENU_BRANCH_embossed.tpl',
            'themes/default/templates/MENU_BRANCH_mobile.tpl',
            'themes/default/templates/MENU_BRANCH_popup.tpl',
            'themes/default/templates/MENU_BRANCH_select.tpl',
            'themes/default/templates/MENU_BRANCH_sitemap.tpl',
            'themes/default/templates/MENU_BRANCH_tree.tpl',
            'themes/default/templates/MENU_EDITOR_BRANCH.tpl',
            'themes/default/templates/MENU_EDITOR_BRANCH_WRAP.tpl',
            'themes/default/templates/MENU_EDITOR_SCREEN.tpl',
            'themes/default/templates/MENU_LINK_PROPERTIES.tpl',
            'themes/default/templates/MENU_SPACER_dropdown.tpl',
            'themes/default/templates/MENU_SPACER_embossed.tpl',
            'themes/default/templates/MENU_SPACER_mobile.tpl',
            'themes/default/templates/MENU_SPACER_popup.tpl',
            'themes/default/templates/MENU_SPACER_select.tpl',
            'themes/default/templates/MENU_SPACER_sitemap.tpl',
            'themes/default/templates/MENU_SPACER_tree.tpl',
            'themes/default/templates/MENU_STAFF_LINK.tpl',
            'themes/default/templates/MENU_dropdown.tpl',
            'themes/default/templates/MENU_embossed.tpl',
            'themes/default/templates/MENU_mobile.tpl',
            'themes/default/templates/MENU_popup.tpl',
            'themes/default/templates/MENU_select.tpl',
            'themes/default/templates/MENU_sitemap.tpl',
            'themes/default/templates/MENU_tree.tpl',
            'themes/default/templates/PAGE_LINK_CHOOSER.tpl',
        ];
    }

    /**
     * Get mapping between template names and the method of this class that can render a preview of them.
     *
     * @return array The mapping
     */
    public function tpl_previews() : array
    {
        return [
            'templates/MENU_EDITOR_BRANCH.tpl' => 'administrative__menu_editor_screen',
            'templates/MENU_EDITOR_BRANCH_WRAP.tpl' => 'administrative__menu_editor_screen',
            'templates/MENU_EDITOR_SCREEN.tpl' => 'administrative__menu_editor_screen',
            'templates/PAGE_LINK_CHOOSER.tpl' => 'page_link_chooser',
            'templates/BLOCK_MENU.tpl' => 'block_menu__tree',
            'templates/MENU_STAFF_LINK.tpl' => 'block_menu__tree',
            'templates/ICON.tpl' => 'block_menu__tree',

            'templates/MENU_SPACER_tree.tpl' => 'block_menu__tree',
            'templates/MENU_BRANCH_tree.tpl' => 'block_menu__tree',
            'templates/MENU_tree.tpl' => 'block_menu__tree',

            'templates/MENU_SPACER_mobile.tpl' => 'block_menu__mobile',
            'templates/MENU_BRANCH_mobile.tpl' => 'block_menu__mobile',
            'templates/MENU_mobile.tpl' => 'block_menu__mobile',

            'templates/MENU_SPACER_dropdown.tpl' => 'block_menu__dropdown',
            'templates/MENU_BRANCH_dropdown.tpl' => 'block_menu__dropdown',
            'templates/MENU_dropdown.tpl' => 'block_menu__dropdown',

            'templates/MENU_SPACER_embossed.tpl' => 'block_menu__embossed',
            'templates/MENU_BRANCH_embossed.tpl' => 'block_menu__embossed',
            'templates/MENU_embossed.tpl' => 'block_menu__embossed',

            'templates/MENU_SPACER_popup.tpl' => 'block_menu__popup',
            'templates/MENU_BRANCH_popup.tpl' => 'block_menu__popup',
            'templates/MENU_popup.tpl' => 'block_menu__popup',

            'templates/MENU_SPACER_select.tpl' => 'block_menu__select',
            'templates/MENU_BRANCH_select.tpl' => 'block_menu__select',
            'templates/MENU_select.tpl' => 'block_menu__select',

            'templates/MENU_SPACER_sitemap.tpl' => 'block_menu__sitemap',
            'templates/MENU_BRANCH_sitemap.tpl' => 'block_menu__sitemap',
            'templates/MENU_sitemap.tpl' => 'block_menu__sitemap',

            'templates/MENU_LINK_PROPERTIES.tpl' => 'block_menu__sitemap',
        ];
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__menu_editor_screen() : object
    {
        $branch = do_lorem_template('MENU_EDITOR_BRANCH', ['CLICKABLE_SECTIONS' => true, 'I' => placeholder_numeric_id(), 'CHILD_BRANCHES' => '']);

        $child_branch_template = do_lorem_template('MENU_EDITOR_BRANCH_WRAP', [
            'DISPLAY' => 'display: block',
            'CLICKABLE_SECTIONS' => true,
            'ORDER' => 'replace_me_with_order',
            'PARENT' => 'replace_me_with_parent',
            'BRANCH_TYPE' => '0',
            'NEW_WINDOW' => '0',
            'CHECK_PERMS' => '0',
            'INCLUDE_SITEMAP' => '0',
            'CAPTION_LONG' => '',
            'CAPTION' => '',
            'URL' => '',
            'PAGE_ONLY' => '',
            'THEME_IMG_CODE' => '',
            'I' => placeholder_numeric_id(),
            'BRANCH' => $branch,
        ]);

        $root_branch = do_lorem_template('MENU_EDITOR_BRANCH', ['CLICKABLE_SECTIONS' => true, 'CHILD_BRANCHES' => '', 'I' => '']);

        return lorem_globalise(do_lorem_template('MENU_EDITOR_SCREEN', [
            'ALL_MENUS' => placeholder_array(),
            'MENU_NAME' => lorem_word(),
            'DELETE_URL' => placeholder_url(),
            'PING_URL' => placeholder_url(),
            'WARNING_DETAILS' => '',
            'FIELDS_TEMPLATE' => placeholder_fields(),
            'HIGHEST_ORDER' => lorem_phrase(),
            'URL' => placeholder_url(),
            'CHILD_BRANCH_TEMPLATE' => $child_branch_template,
            'ROOT_BRANCH' => $root_branch,
            'TITLE' => lorem_screen_title(),
            'TOTAL_ITEMS' => placeholder_number(),
            'MENU_TYPE' => 'dropdown',
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__page_link_chooser() : object
    {
        require_javascript('tree_list');
        return lorem_globalise(do_lorem_template('PAGE_LINK_CHOOSER', [
            'NAME' => lorem_word(),
            'VALUE' => lorem_word(),
            'GET_TITLE_TOO' => false,
            'AS_FIELD' => null,
            'PAGE_TYPE' => null,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_menu__mobile() : object
    {
        $child = new Tempcode();
        $content = new Tempcode();
        foreach (placeholder_array(3) as $v) {
            $child->attach(do_lorem_template('MENU_BRANCH_mobile', [
                'CAPTION' => lorem_word(),
                'IMG' => '',
                'URL' => placeholder_url(),
                'PAGE_LINK' => placeholder_link(),
                'ACCESSKEY' => '',
                'NEW_WINDOW' => false,
                'TOOLTIP' => lorem_phrase(),
                'CHILDREN' => '',
                'NUM_CHILDREN' => '0',
                'DISPLAY' => 'block',
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => false,
                'THE_LEVEL' => '2',
                'POSITION' => '1',
                'FIRST' => false,
                'LAST' => false,
                'SIBLINGS' => '3',
                'CURRENT' => false,
                'CURRENT_ZONE' => false,
            ]));
        }
        foreach (placeholder_array(3) as $v) {
            $content->attach(do_lorem_template('MENU_BRANCH_mobile', [
                'CAPTION' => lorem_word(),
                'IMG' => '',
                'URL' => placeholder_url(),
                'PAGE_LINK' => placeholder_link(),
                'ACCESSKEY' => '',
                'NEW_WINDOW' => false,
                'TOOLTIP' => lorem_phrase(),
                'CHILDREN' => $child,
                'NUM_CHILDREN' => '1',
                'DISPLAY' => 'block',
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => true,
                'THE_LEVEL' => '0',
                'POSITION' => '2',
                'FIRST' => false,
                'LAST' => false,
                'SIBLINGS' => '3',
                'CURRENT' => false,
                'CURRENT_ZONE' => false,
            ]));

            $content->attach(do_lorem_template('MENU_SPACER_mobile', [
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => true,
                'THE_LEVEL' => '0',
            ]));
        }
        $menu = do_lorem_template('MENU_mobile', [
            'CONTENT' => $content,
            'MENU' => lorem_word_2(),
            'NUM_BRANCHES' => strval(3),
        ]);

        $menu->attach(do_lorem_template('MENU_STAFF_LINK', ['TYPE' => 'mobile', 'EDIT_URL' => placeholder_url(), 'NAME' => lorem_phrase()]));

        return lorem_globalise(do_lorem_template('BLOCK_MENU', [
            'BLOCK_ID' => lorem_word(),
            'CONTENT' => $menu,
            'PARAM' => lorem_phrase(),
            'TRAY_STATUS' => lorem_phrase(),
            'TITLE' => lorem_phrase(),
            'TYPE' => 'mobile',
            'JAVASCRIPT_HIGHLIGHTING' => false,
        ]), null, '', false);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_menu__tree() : object
    {
        $child = new Tempcode();
        $content = new Tempcode();
        foreach (placeholder_array(3) as $v) {
            $child->attach(do_lorem_template('MENU_BRANCH_tree', [
                'CAPTION' => lorem_word(),
                'IMG' => '',
                'URL' => placeholder_url(),
                'PAGE_LINK' => placeholder_link(),
                'ACCESSKEY' => '',
                'NEW_WINDOW' => false,
                'TOOLTIP' => lorem_phrase(),
                'CHILDREN' => '',
                'NUM_CHILDREN' => '0',
                'DISPLAY' => 'block',
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => false,
                'THE_LEVEL' => '2',
                'POSITION' => '1',
                'FIRST' => false,
                'LAST' => false,
                'SIBLINGS' => '3',
                'CURRENT' => false,
                'CURRENT_ZONE' => false,
            ]));
        }
        foreach (placeholder_array(3) as $v) {
            $content->attach(do_lorem_template('MENU_BRANCH_tree', [
                'CAPTION' => lorem_word(),
                'IMG' => '',
                'URL' => placeholder_url(),
                'PAGE_LINK' => placeholder_link(),
                'ACCESSKEY' => '',
                'NEW_WINDOW' => false,
                'TOOLTIP' => lorem_phrase(),
                'CHILDREN' => $child,
                'NUM_CHILDREN' => '1',
                'DISPLAY' => 'block',
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => true,
                'THE_LEVEL' => '0',
                'POSITION' => '2',
                'FIRST' => false,
                'LAST' => false,
                'SIBLINGS' => '3',
                'CURRENT' => false,
                'CURRENT_ZONE' => false,
            ]));

            $content->attach(do_lorem_template('MENU_SPACER_tree', [
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => true,
                'THE_LEVEL' => '0',
            ]));
        }
        $menu = do_lorem_template('MENU_tree', [
            'CONTENT' => $content,
            'MENU' => lorem_word_2(),
            'NUM_BRANCHES' => strval(3),
        ]);

        $menu->attach(do_lorem_template('MENU_STAFF_LINK', ['TYPE' => 'tree', 'EDIT_URL' => placeholder_url(), 'NAME' => lorem_phrase()]));

        return lorem_globalise(do_lorem_template('BLOCK_MENU', [
            'BLOCK_ID' => lorem_word(),
            'CONTENT' => $menu,
            'PARAM' => lorem_phrase(),
            'TRAY_STATUS' => lorem_phrase(),
            'TITLE' => lorem_phrase(),
            'TYPE' => 'tree',
            'JAVASCRIPT_HIGHLIGHTING' => false,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_menu__dropdown() : object
    {
        $child = new Tempcode();
        $content = new Tempcode();
        foreach (placeholder_array(3) as $k => $v) {
            $child->attach(do_lorem_template('MENU_BRANCH_dropdown', [
                'CAPTION' => lorem_word(),
                'IMG' => '',
                'URL' => placeholder_url(),
                'PAGE_LINK' => placeholder_link(),
                'ACCESSKEY' => '',
                'NEW_WINDOW' => false,
                'TOOLTIP' => lorem_phrase(),
                'CHILDREN' => '',
                'NUM_CHILDREN' => '0',
                'DISPLAY' => 'block',
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => false,
                'THE_LEVEL' => '2',
                'POSITION' => '1',
                'FIRST' => false,
                'LAST' => false,
                'SIBLINGS' => '3',
                'CURRENT' => false,
                'CURRENT_ZONE' => false,
            ]));

            $child->attach(do_lorem_template('MENU_SPACER_dropdown', [
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => true,
                'THE_LEVEL' => '0',
            ]));
        }
        foreach (placeholder_array(3) as $k => $v) {
            $content->attach(do_lorem_template('MENU_BRANCH_dropdown', [
                'CAPTION' => lorem_word(),
                'IMG' => '',
                'URL' => placeholder_url(),
                'PAGE_LINK' => placeholder_link(),
                'ACCESSKEY' => '',
                'NEW_WINDOW' => false,
                'TOOLTIP' => lorem_phrase(),
                'CHILDREN' => $child,
                'NUM_CHILDREN' => '1',
                'DISPLAY' => 'block',
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => true,
                'THE_LEVEL' => '0',
                'POSITION' => '2',
                'FIRST' => false,
                'LAST' => false,
                'SIBLINGS' => '3',
                'CURRENT' => false,
                'CURRENT_ZONE' => false,
            ]));
        }
        $menu = do_lorem_template('MENU_dropdown', [
            'CONTENT' => $content,
            'MENU' => lorem_word_2(),
            'NUM_BRANCHES' => strval(3),
        ]);

        $menu->attach(do_lorem_template('MENU_STAFF_LINK', ['TYPE' => 'dropdown', 'EDIT_URL' => placeholder_url(), 'NAME' => lorem_phrase()]));

        return lorem_globalise($menu, null, '', false);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_menu__embossed() : object
    {
        $child = new Tempcode();
        $content = new Tempcode();
        foreach (placeholder_array(3) as $k => $v) {
            $child->attach(do_lorem_template('MENU_BRANCH_embossed', [
                'CAPTION' => lorem_word(),
                'IMG' => '',
                'URL' => placeholder_url(),
                'PAGE_LINK' => placeholder_link(),
                'ACCESSKEY' => '',
                'NEW_WINDOW' => false,
                'TOOLTIP' => lorem_phrase(),
                'CHILDREN' => '',
                'NUM_CHILDREN' => '0',
                'DISPLAY' => 'block',
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => false,
                'THE_LEVEL' => '2',
                'POSITION' => '1',
                'FIRST' => false,
                'LAST' => false,
                'SIBLINGS' => '3',
                'CURRENT' => false,
                'CURRENT_ZONE' => false,
            ]));
        }
        foreach (placeholder_array(3) as $k => $v) {
            $content->attach(do_lorem_template('MENU_BRANCH_embossed', [
                'CAPTION' => lorem_word(),
                'IMG' => '',
                'URL' => placeholder_url(),
                'PAGE_LINK' => placeholder_link(),
                'ACCESSKEY' => '',
                'NEW_WINDOW' => false,
                'TOOLTIP' => lorem_phrase(),
                'CHILDREN' => $child,
                'NUM_CHILDREN' => '1',
                'DISPLAY' => 'block',
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => true,
                'THE_LEVEL' => '0',
                'POSITION' => '2',
                'FIRST' => false,
                'LAST' => false,
                'SIBLINGS' => '3',
                'CURRENT' => false,
                'CURRENT_ZONE' => false,
            ]));

            $content->attach(do_lorem_template('MENU_SPACER_embossed', [
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => true,
                'THE_LEVEL' => '0',
            ]));
        }
        $menu = do_lorem_template('MENU_embossed', [
            'CONTENT' => $content,
            'MENU' => lorem_word_2(),
            'NUM_BRANCHES' => strval(3),
        ]);

        $menu->attach(do_lorem_template('MENU_STAFF_LINK', ['TYPE' => 'embossed', 'EDIT_URL' => placeholder_url(), 'NAME' => lorem_phrase()]));

        return lorem_globalise(do_lorem_template('BLOCK_MENU', [
            'BLOCK_ID' => lorem_word(),
            'CONTENT' => $menu,
            'PARAM' => lorem_phrase(),
            'TRAY_STATUS' => lorem_phrase(),
            'TITLE' => lorem_phrase(),
            'TYPE' => 'embossed',
            'JAVASCRIPT_HIGHLIGHTING' => false,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_menu__popup() : object
    {
        $child = new Tempcode();
        $content = new Tempcode();
        foreach (placeholder_array(3) as $k => $v) {
            $child->attach(do_lorem_template('MENU_BRANCH_popup', [
                'CAPTION' => lorem_word(),
                'IMG' => '',
                'URL' => placeholder_url(),
                'PAGE_LINK' => placeholder_link(),
                'ACCESSKEY' => '',
                'NEW_WINDOW' => false,
                'TOOLTIP' => lorem_phrase(),
                'CHILDREN' => '',
                'NUM_CHILDREN' => '0',
                'DISPLAY' => 'block',
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => false,
                'THE_LEVEL' => '2',
                'POSITION' => '1',
                'FIRST' => false,
                'LAST' => false,
                'SIBLINGS' => '3',
                'CURRENT' => false,
                'CURRENT_ZONE' => false,
            ]));
        }
        foreach (placeholder_array(3) as $k => $v) {
            $content->attach(do_lorem_template('MENU_BRANCH_popup', [
                'CAPTION' => lorem_word(),
                'IMG' => '',
                'URL' => placeholder_url(),
                'PAGE_LINK' => placeholder_link(),
                'ACCESSKEY' => '',
                'NEW_WINDOW' => false,
                'TOOLTIP' => lorem_phrase(),
                'CHILDREN' => $child,
                'NUM_CHILDREN' => '1',
                'DISPLAY' => 'block',
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => true,
                'THE_LEVEL' => '0',
                'POSITION' => '2',
                'FIRST' => false,
                'LAST' => false,
                'SIBLINGS' => '3',
                'CURRENT' => false,
                'CURRENT_ZONE' => false,
            ]));

            $content->attach(do_lorem_template('MENU_SPACER_popup', [
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => true,
                'THE_LEVEL' => '0',
            ]));
        }
        $menu = do_lorem_template('MENU_popup', [
            'CONTENT' => $content,
            'MENU' => lorem_word_2(),
            'NUM_BRANCHES' => strval(3),
        ]);

        $menu->attach(do_lorem_template('MENU_STAFF_LINK', ['TYPE' => 'popup', 'EDIT_URL' => placeholder_url(), 'NAME' => lorem_phrase()]));

        return lorem_globalise(do_lorem_template('BLOCK_MENU', [
            'BLOCK_ID' => lorem_word(),
            'CONTENT' => $menu,
            'PARAM' => lorem_phrase(),
            'TRAY_STATUS' => lorem_phrase(),
            'TITLE' => lorem_phrase(),
            'TYPE' => 'popup',
            'JAVASCRIPT_HIGHLIGHTING' => false,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_menu__select() : object
    {
        $child = new Tempcode();
        $content = new Tempcode();
        foreach (placeholder_array(3) as $k => $v) {
            $child->attach(do_lorem_template('MENU_BRANCH_select', [
                'CAPTION' => lorem_word(),
                'IMG' => '',
                'URL' => placeholder_url(),
                'PAGE_LINK' => placeholder_link(),
                'ACCESSKEY' => '',
                'NEW_WINDOW' => false,
                'TOOLTIP' => lorem_phrase(),
                'CHILDREN' => '',
                'NUM_CHILDREN' => '0',
                'DISPLAY' => 'block',
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => false,
                'THE_LEVEL' => '2',
                'POSITION' => '1',
                'FIRST' => false,
                'LAST' => false,
                'SIBLINGS' => '3',
                'CURRENT' => false,
                'CURRENT_ZONE' => false,
            ]));
        }
        foreach (placeholder_array(3) as $k => $v) {
            $content->attach(do_lorem_template('MENU_BRANCH_select', [
                'CAPTION' => lorem_word(),
                'IMG' => '',
                'URL' => placeholder_url(),
                'PAGE_LINK' => placeholder_link(),
                'ACCESSKEY' => '',
                'NEW_WINDOW' => false,
                'TOOLTIP' => lorem_phrase(),
                'CHILDREN' => $child,
                'NUM_CHILDREN' => '1',
                'DISPLAY' => 'block',
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => true,
                'THE_LEVEL' => '0',
                'POSITION' => '2',
                'FIRST' => false,
                'LAST' => false,
                'SIBLINGS' => '3',
                'CURRENT' => false,
                'CURRENT_ZONE' => false,
            ]));

            $content->attach(do_lorem_template('MENU_SPACER_select', [
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => true,
                'THE_LEVEL' => '0',
            ]));
        }
        $menu = do_lorem_template('MENU_select', [
            'CONTENT' => $content,
            'MENU' => lorem_word_2(),
            'NUM_BRANCHES' => strval(3),
        ]);

        $menu->attach(do_lorem_template('MENU_STAFF_LINK', ['TYPE' => 'select', 'EDIT_URL' => placeholder_url(), 'NAME' => lorem_phrase()]));

        return lorem_globalise(do_lorem_template('BLOCK_MENU', [
            'BLOCK_ID' => lorem_word(),
            'CONTENT' => $menu,
            'PARAM' => lorem_phrase(),
            'TRAY_STATUS' => lorem_phrase(),
            'TITLE' => lorem_phrase(),
            'TYPE' => 'select',
            'JAVASCRIPT_HIGHLIGHTING' => false,
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_menu__sitemap() : object
    {
        $child = new Tempcode();
        $content = new Tempcode();
        foreach (placeholder_array(3) as $k => $v) {
            $child->attach(do_lorem_template('MENU_BRANCH_sitemap', [
                'CAPTION' => lorem_word(),
                'IMG' => '',
                'URL' => placeholder_url(),
                'PAGE_LINK' => placeholder_link(),
                'ACCESSKEY' => '',
                'NEW_WINDOW' => false,
                'TOOLTIP' => lorem_phrase(),
                'CHILDREN' => '',
                'NUM_CHILDREN' => '0',
                'DISPLAY' => 'block',
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => false,
                'THE_LEVEL' => '2',
                'POSITION' => strval($k),
                'FIRST' => $k === 0,
                'LAST' => $k === 2,
                'SIBLINGS' => '3',
                'CURRENT' => false,
                'CURRENT_ZONE' => false,
            ]));
        }
        foreach (placeholder_array(3) as $k => $v) {
            $content->attach(do_lorem_template('MENU_BRANCH_sitemap', [
                'CAPTION' => lorem_word(),
                'IMG' => '',
                'URL' => placeholder_url(),
                'PAGE_LINK' => placeholder_link(),
                'ACCESSKEY' => '',
                'NEW_WINDOW' => false,
                'TOOLTIP' => lorem_phrase(),
                'CHILDREN' => $child,
                'NUM_CHILDREN' => '1',
                'DISPLAY' => 'block',
                'MENU' => lorem_word_2(),
                'TOP_LEVEL' => true,
                'THE_LEVEL' => '0',
                'POSITION' => strval($k),
                'FIRST' => $k === 0,
                'LAST' => $k === 2,
                'SIBLINGS' => '3',
                'CURRENT' => false,
                'CURRENT_ZONE' => false,
            ]));
        }
        $content->attach(do_template('MENU_SPACER_sitemap'));
        $menu = do_lorem_template('MENU_sitemap', [
            'CONTENT' => $content,
            'MENU' => lorem_word_2(),
            'NUM_BRANCHES' => strval(3),
        ]);

        $menu->attach(do_lorem_template('MENU_STAFF_LINK', ['TYPE' => 'sitemap', 'EDIT_URL' => placeholder_url(), 'NAME' => lorem_phrase()]));

        return lorem_globalise($menu, null, '', true);
    }
}
