<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    recommend
 */

/**
 * Hook class.
 */
class Hook_addon_registry_recommend
{
    /**
     * Get a list of file permissions to set.
     *
     * @param  boolean $runtime Whether to include wildcards represented runtime-created chmoddable files
     * @return array File permissions to set
     */
    public function get_chmod_array(bool $runtime = false) : array
    {
        return [];
    }

    /**
     * Get the version of Composr this addon is for (used in generating the TAR filename).
     *
     * @return float Version number
     */
    public function get_version() : float
    {
        return cms_version_number();
    }

    /**
     * Get the minimum required version of the website software needed to use this addon.
     *
     * @return float Minimum required website software version
     */
    public function get_min_cms_version() : float
    {
        return 11.0;
    }

    /**
     * Get the maximum compatible version of the website software to use this addon.
     *
     * @return ?float Maximum compatible website software version (null: no maximum version currently)
     */
    public function get_max_cms_version() : ?float
    {
        return null;
    }

    /**
     * Get the addon category.
     *
     * @return string The category
     */
    public function get_category() : string
    {
        return 'Community';
    }

    /**
     * Get the description of the addon.
     *
     * @return string Description of the addon
     */
    public function get_description() : string
    {
        return 'Allow members to easily recommend the website to others.';
    }

    /**
     * Get a list of tutorials that apply to this addon.
     *
     * @return array List of tutorials
     */
    public function get_applicable_tutorials() : array
    {
        return [
            'tut_members',
        ];
    }

    /**
     * Get a mapping of dependency types.
     *
     * @return array A structure specifying dependency information
     */
    public function get_dependencies() : array
    {
        return [
            'requires' => [],
            'recommends' => [],
            'conflicts_with' => [],
        ];
    }

    /**
     * Explicitly say which icon should be used.
     *
     * @return URLPATH Icon
     */
    public function get_default_icon() : string
    {
        return 'themes/default/images/icons/menu/site_meta/recommend.svg';
    }

    /**
     * Get a list of files that belong to this addon.
     *
     * @return array List of files
     */
    public function get_file_list() : array
    {
        return [
            'lang/EN/recommend.ini',
            'pages/comcode/EN/recommend_help.txt',
            'pages/modules/recommend.php',
            'sources/blocks/main_screen_actions.php',
            'sources/hooks/systems/actionlog/recommend.php',
            'sources/hooks/systems/addon_registry/recommend.php',
            'sources/hooks/systems/config/enable_spreadsheet_recommend.php',
            'sources/hooks/systems/config/points_RECOMMEND_SITE.php',
            'sources/hooks/systems/page_groupings/recommend.php',
            'sources/hooks/systems/privacy/recommend.php',
            'sources/hooks/systems/realtime_rain/recommend.php',
            'sources/recommend.php',
            'themes/default/css/recommend.css',
            'themes/default/css/screen_actions.css',
            'themes/default/images/icons/menu/site_meta/recommend.svg',
            'themes/default/images/icons_monochrome/menu/site_meta/recommend.svg',
            'themes/default/templates/BLOCK_MAIN_SCREEN_ACTIONS.tpl',
        ];
    }

    /**
     * Get mapping between template names and the method of this class that can render a preview of them.
     *
     * @return array The mapping
     */
    public function tpl_previews() : array
    {
        return [
            'templates/BLOCK_MAIN_SCREEN_ACTIONS.tpl' => 'block_main_screen_actions',
        ];
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_main_screen_actions() : object
    {
        return lorem_globalise(do_lorem_template('BLOCK_MAIN_SCREEN_ACTIONS', [
            'BLOCK_ID' => lorem_word(),
            'PRINT_URL' => placeholder_url(),
            'RECOMMEND_URL' => placeholder_url(),
            'URL_ENCODED_CANONICAL_URL' => placeholder_url(),
            'TITLE' => lorem_phrase(),
        ]), null, '', true);
    }
}
