<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    themewizard
 */

/**
 * Hook class.
 */
class Hook_addon_registry_themewizard
{
    /**
     * Get a list of file permissions to set.
     *
     * @param  boolean $runtime Whether to include wildcards represented runtime-created chmoddable files
     * @return array File permissions to set
     */
    public function get_chmod_array(bool $runtime = false) : array
    {
        return [];
    }

    /**
     * Get the version of Composr this addon is for (used in generating the TAR filename).
     *
     * @return float Version number
     */
    public function get_version() : float
    {
        return cms_version_number();
    }

    /**
     * Get the minimum required version of the website software needed to use this addon.
     *
     * @return float Minimum required website software version
     */
    public function get_min_cms_version() : float
    {
        return 11.0;
    }

    /**
     * Get the maximum compatible version of the website software to use this addon.
     *
     * @return ?float Maximum compatible website software version (null: no maximum version currently)
     */
    public function get_max_cms_version() : ?float
    {
        return null;
    }

    /**
     * Get the addon category.
     *
     * @return string The category
     */
    public function get_category() : string
    {
        return 'Graphical';
    }

    /**
     * Get the description of the addon.
     *
     * @return string Description of the addon
     */
    public function get_description() : string
    {
        return 'Automatically generate your own colour schemes using the default theme as a base. Uses the sophisticated chromagraphic equations built into Composr.';
    }

    /**
     * Get a list of tutorials that apply to this addon.
     *
     * @return array List of tutorials
     */
    public function get_applicable_tutorials() : array
    {
        return [
            'tut_themes',
            'tut_designer_themes',
        ];
    }

    /**
     * Get a mapping of dependency types.
     *
     * @return array A structure specifying dependency information
     */
    public function get_dependencies() : array
    {
        return [
            'requires' => [],
            'recommends' => [],
            'conflicts_with' => [],
        ];
    }

    /**
     * Explicitly say which icon should be used.
     *
     * @return URLPATH Icon
     */
    public function get_default_icon() : string
    {
        return 'themes/default/images/icons/menu/adminzone/style/themes/themewizard.svg';
    }

    /**
     * Get a list of files that belong to this addon.
     *
     * @return array List of files
     */
    public function get_file_list() : array
    {
        return [
            'adminzone/logowizard.php',
            'adminzone/pages/modules/admin_themewizard.php',
            'adminzone/themewizard.php',
            'sources/hooks/modules/admin_themewizard/.htaccess',
            'sources/hooks/modules/admin_themewizard/index.html',
            'sources/hooks/systems/addon_registry/themewizard.php',
            'sources/hooks/systems/cleanup/themewizard_files.php',
            'sources/hooks/systems/commandr_commands/themewizard_compute_equation.php',
            'sources/hooks/systems/commandr_commands/themewizard_find_color.php',
            'sources/hooks/systems/page_groupings/themewizard.php',
            'sources/hooks/systems/preview/logo.php',
            'sources/hooks/systems/preview/themewizard.php',
            'sources/hooks/systems/preview/themewizard_image.php',
            'sources/hooks/systems/snippets/themewizard_equation.php',
            'sources/themewizard.php',
            'sources_custom/hooks/modules/admin_themewizard/.htaccess',
            'sources_custom/hooks/modules/admin_themewizard/index.html',
            'themes/default/images/icons/menu/adminzone/style/themes/logowizard.svg',
            'themes/default/images/icons/menu/adminzone/style/themes/themewizard.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/style/themes/logowizard.svg',
            'themes/default/images/icons_monochrome/menu/adminzone/style/themes/themewizard.svg',
            'themes/default/images/logo/default_backgrounds/banner1.png',
            'themes/default/images/logo/default_backgrounds/banner10.png',
            'themes/default/images/logo/default_backgrounds/banner2.png',
            'themes/default/images/logo/default_backgrounds/banner3A.png',
            'themes/default/images/logo/default_backgrounds/banner3B.png',
            'themes/default/images/logo/default_backgrounds/banner3C.png',
            'themes/default/images/logo/default_backgrounds/banner4.png',
            'themes/default/images/logo/default_backgrounds/banner5.png',
            'themes/default/images/logo/default_backgrounds/banner6.png',
            'themes/default/images/logo/default_backgrounds/banner7A.png',
            'themes/default/images/logo/default_backgrounds/banner7B.png',
            'themes/default/images/logo/default_backgrounds/banner8A.png',
            'themes/default/images/logo/default_backgrounds/banner8B.png',
            'themes/default/images/logo/default_backgrounds/banner9.png',
            'themes/default/images/logo/default_backgrounds/index.html',
            'themes/default/images/logo/default_logos/index.html',
            'themes/default/images/logo/default_logos/logo1.png',
            'themes/default/images/logo/default_logos/logo10.png',
            'themes/default/images/logo/default_logos/logo11.png',
            'themes/default/images/logo/default_logos/logo12.png',
            'themes/default/images/logo/default_logos/logo2.png',
            'themes/default/images/logo/default_logos/logo3.png',
            'themes/default/images/logo/default_logos/logo4.png',
            'themes/default/images/logo/default_logos/logo5.png',
            'themes/default/images/logo/default_logos/logo6.png',
            'themes/default/images/logo/default_logos/logo7.png',
            'themes/default/images/logo/default_logos/logo8.png',
            'themes/default/images/logo/default_logos/logo9.png',
            'themes/default/images/logo/default_logos_monochrome/index.html',
            'themes/default/images/logo/default_logos_monochrome/logo1.png',
            'themes/default/images/logo/default_logos_monochrome/logo10.png',
            'themes/default/images/logo/default_logos_monochrome/logo11.png',
            'themes/default/images/logo/default_logos_monochrome/logo12.png',
            'themes/default/images/logo/default_logos_monochrome/logo2.png',
            'themes/default/images/logo/default_logos_monochrome/logo3.png',
            'themes/default/images/logo/default_logos_monochrome/logo4.png',
            'themes/default/images/logo/default_logos_monochrome/logo5.png',
            'themes/default/images/logo/default_logos_monochrome/logo6.png',
            'themes/default/images/logo/default_logos_monochrome/logo7.png',
            'themes/default/images/logo/default_logos_monochrome/logo8.png',
            'themes/default/images/logo/default_logos_monochrome/logo9.png',
            'themes/default/images/logo/index.html',
            'themes/default/javascript/themewizard.js',
            'themes/default/templates/LOGOWIZARD_2.tpl',
            'themes/default/templates/THEMEWIZARD_PREVIEW.tpl',
        ];
    }

    /**
     * Get mapping between template names and the method of this class that can render a preview of them.
     *
     * @return array The mapping
     */
    public function tpl_previews() : array
    {
        return [
            'templates/THEMEWIZARD_PREVIEW.tpl' => 'administrative__themewizard_preview_screen',
            'templates/LOGOWIZARD_2.tpl' => 'administrative__logowizard_2',
        ];
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__themewizard_preview_screen() : object
    {
        require_lang('themes');

        return lorem_globalise(do_lorem_template('THEMEWIZARD_PREVIEW', [
            'SOURCE_THEME' => 'default',
            'ALGORITHM' => 'equations',
            'RED' => placeholder_codename(),
            'GREEN' => placeholder_codename(),
            'BLUE' => placeholder_codename(),
            'SEED' => lorem_word(),
            'DARK' => true,
            'DOMINANT' => lorem_word(),
            'LD' => lorem_phrase(),
        ]), null, '', true);
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__administrative__logowizard_2() : object
    {
        require_lang('themes');

        require_code('fonts');

        $preview = do_lorem_template('LOGOWIZARD_2', [
            'NAME' => lorem_phrase(),
            'FONT' => find_default_font(),
            'COLOUR' => '#FFFFFF',
            'LOGO_TYPE' => 'small',
            'LOGO_OUTPUT_THEME_IMAGE' => lorem_word(),
            'LOGO_THEME_IMAGE' => 'logo/default_logos/1',
            'BACKGROUND_THEME_IMAGE' => 'logo/default_backgrounds/1',
            'THEME' => lorem_phrase(),
        ]);

        return lorem_globalise(do_lorem_template('CONFIRM_SCREEN', [
            'URL' => placeholder_url(),
            'BACK_URL' => placeholder_url(),
            'PREVIEW' => $preview,
            'FIELDS' => '',
            'TITLE' => lorem_screen_title(),
        ]), null, '', true);
    }
}
