<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    users_online_block
 */

/**
 * Hook class.
 */
class Hook_addon_registry_users_online_block
{
    /**
     * Get a list of file permissions to set.
     *
     * @param  boolean $runtime Whether to include wildcards represented runtime-created chmoddable files
     * @return array File permissions to set
     */
    public function get_chmod_array(bool $runtime = false) : array
    {
        return [];
    }

    /**
     * Get the version of Composr this addon is for (used in generating the TAR filename).
     *
     * @return float Version number
     */
    public function get_version() : float
    {
        return cms_version_number();
    }

    /**
     * Get the minimum required version of the website software needed to use this addon.
     *
     * @return float Minimum required website software version
     */
    public function get_min_cms_version() : float
    {
        return 11.0;
    }

    /**
     * Get the maximum compatible version of the website software to use this addon.
     *
     * @return ?float Maximum compatible website software version (null: no maximum version currently)
     */
    public function get_max_cms_version() : ?float
    {
        return null;
    }

    /**
     * Get the addon category.
     *
     * @return string The category
     */
    public function get_category() : string
    {
        return 'Information Display';
    }

    /**
     * Get the description of the addon.
     *
     * @return string Description of the addon
     */
    public function get_description() : string
    {
        return 'A block to show which users who are currently visiting the website, and birthdays.';
    }

    /**
     * Get a list of tutorials that apply to this addon.
     *
     * @return array List of tutorials
     */
    public function get_applicable_tutorials() : array
    {
        return [
            'tut_members',
        ];
    }

    /**
     * Get a mapping of dependency types.
     *
     * @return array A structure specifying dependency information
     */
    public function get_dependencies() : array
    {
        return [
            'requires' => [],
            'recommends' => [],
            'conflicts_with' => [],
        ];
    }

    /**
     * Explicitly say which icon should be used.
     *
     * @return URLPATH Icon
     */
    public function get_default_icon() : string
    {
        return 'themes/default/images/icons/menu/social/users_online.svg';
    }

    /**
     * Get a list of files that belong to this addon.
     *
     * @return array List of files
     */
    public function get_file_list() : array
    {
        return [
            'sources/blocks/side_users_online.php',
            'sources/hooks/systems/addon_registry/users_online_block.php',
            'sources/hooks/systems/config/usersonline_show_birthdays.php',
            'sources/hooks/systems/config/usersonline_show_newest_member.php',
            'themes/default/templates/BLOCK_SIDE_USERS_ONLINE.tpl',
        ];
    }

    /**
     * Get mapping between template names and the method of this class that can render a preview of them.
     *
     * @return array The mapping
     */
    public function tpl_previews() : array
    {
        return [
            'templates/BLOCK_SIDE_USERS_ONLINE.tpl' => 'block_side_users_online',
        ];
    }

    /**
     * Get a preview(s) of a (group of) template(s), as a full standalone piece of HTML in Tempcode format.
     * Uses sources/lorem.php functions to place appropriate stock-text. Should not hard-code things, as the code is intended to be declarative.
     * Assumptions: You can assume all Lang/CSS/JavaScript files in this addon have been pre-required.
     *
     * @return Tempcode Preview
     */
    public function tpl_preview__block_side_users_online() : object
    {
        require_lang('cns');

        $online = [];
        foreach (placeholder_array() as $k => $v) {
            $online[] = [
                'URL' => placeholder_url(),
                'USERNAME' => lorem_phrase(),
                'COLOUR' => lorem_word(),
                'MEMBER_ID' => placeholder_numeric_id(),
                'AVATAR_URL' => placeholder_image_url(),
            ];
        }

        $newest = new Tempcode();

        $birthdays = [];
        foreach (placeholder_array() as $k => $v) {
            $birthdays[] = [
                'AGE' => placeholder_number(),
                'PROFILE_URL' => placeholder_url(),
                'USERNAME' => lorem_word(),
                'BIRTHDAY_URL' => placeholder_url(),
            ];
        }

        return lorem_globalise(do_lorem_template('BLOCK_SIDE_USERS_ONLINE', [
            'BLOCK_ID' => lorem_word(),
            'ONLINE' => $online,
            'GUESTS' => placeholder_number(),
            'MEMBERS' => placeholder_number(),
            '_GUESTS' => lorem_phrase(),
            '_MEMBERS' => lorem_phrase(),
            'BIRTHDAYS' => $birthdays,
            'NEWEST' => $newest,
        ]), null, '', true);
    }
}
