<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    news
 */

/**
 * Hook class.
 */
class Hook_attachments_news
{
    /**
     * Run function for attachment hooks. They see if permission to an attachment of an ID relating to this content is present for a member.
     *
     * @param  ID_TEXT $id The ID
     * @param  object $db The database connector to check on
     * @param  MEMBER $member_id The member to check for
     * @return boolean Whether there is permission
     */
    public function run(string $id, object $db, int $member_id) : bool
    {
        if (!addon_installed('news')) {
            return false;
        }

        if ($db->is_forum_db()) {
            return false;
        }

        if (addon_installed('content_privacy')) {
            require_code('content_privacy');
            if (!has_privacy_access('news', $id)) {
                return false;
            }
        }

        $cat_id = $GLOBALS['SITE_DB']->query_select_value_if_there('news', 'news_category', ['id' => intval($id)]);
        if ($cat_id === null) {
            return false;
        }
        return has_category_access($member_id, 'news', strval($cat_id));
    }
}
