<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    banners
 */

/**
 * Hook class.
 */
class Hook_block_ui_renderers_banners
{
    /**
     * See if a particular block parameter's UI input can be handled as a hidden field.
     *
     * @param  ID_TEXT $block The block
     * @param  ID_TEXT $parameter The parameter of the block
     * @param  boolean $has_default Whether there is a default value for the field, due to this being an edit
     * @param  string $default Default value for field
     * @return ?Tempcode Rendered field (null: not handled)
     */
    public function render_block_ui_parameter_hidden(string $block, string $parameter, bool $has_default, string $default) : ?object
    {
        if (!addon_installed('banners')) {
            return null;
        }

        return null;
    }

    /**
     * See if a particular block parameter's UI input can be rendered by this.
     *
     * @param  ID_TEXT $block The block
     * @param  ID_TEXT $parameter The parameter of the block
     * @param  boolean $has_default Whether there is a default value for the field, due to this being an edit
     * @param  string $default Default value for field
     * @param  string $description Field description
     * @return ?Tempcode Rendered field (null: not handled)
     */
    public function render_block_ui_parameter(string $block, string $parameter, bool $has_default, string $default, string $description) : ?object
    {
        if (!addon_installed('banners')) {
            return null;
        }

        if (($parameter == 'param') && (in_array($block, ['main_banner_wave', 'main_top_sites']))) { // banner type list
            require_code('banners2');
            $list = create_selection_list_banner_types($default);
            return form_input_list(titleify($parameter), escape_html($description), $parameter, $list, null, false, false);
        }

        if (($parameter == 'name') && (in_array($block, ['main_banner_wave']))) { // banner list
            require_code('banners2');
            $list = new Tempcode();
            $list->attach(form_input_list_entry('', false));
            $list->attach(create_selection_list_banners($default));
            return form_input_list(titleify($parameter), escape_html($description), $parameter, $list, null, false, false);
        }

        if (($parameter == 'region') && (in_array($block, ['main_banner_wave']))) { // region list
            require_code('locations');
            $continents_and_countries = find_continents_and_countries();

            $list_groups = new Tempcode();
            $list_groups->attach(form_input_list_entry('', false));
            foreach ($continents_and_countries as $continent => $countries) {
                $list = new Tempcode();
                foreach ($countries as $country_code => $country_name) {
                    $list->attach(form_input_list_entry($country_code, $country_code == $default, $country_name));
                }
                $list_groups->attach(form_input_list_group($continent, $list));
            }

            return form_input_list(titleify($parameter), escape_html($description), $parameter, $list_groups, null, false, false);
        }

        return null;
    }
}
