<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    tickets
 */

/**
 * Hook class.
 */
class Hook_change_detection_tickets
{
    /**
     * Run function for change_detection hooks. They see if their own something has changed in comparison to sample data.
     *
     * @param  string $data The sample data, serialised and then MD5'd
     * @return boolean Whether the something has changed
     */
    public function run(string $data) : bool
    {
        if (!addon_installed('tickets')) {
            return false;
        }

        if (get_param_string('type', 'browse') == 'browse') {
            require_lang('tickets');
            require_code('tickets');
            require_code('tickets2');
            $ticket_type_id = get_param_integer('ticket_type_id', null);
            $tickets = get_tickets(['ticket_type_id' => $ticket_type_id]);
            return md5(serialize($tickets)) != $data;
        }

        $ticket_id = get_param_string('id', null);
        if ($ticket_id === null) {
            return false;
        }

        require_lang('tickets');
        require_code('tickets');
        require_code('tickets2');

        $ticket_posts = get_ticket_posts($ticket_id);

        return md5(serialize(is_array($ticket_posts) ? count($ticket_posts) : 0)) != $data;
    }
}
