<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core_cleanup_tools
 */

/**
 * Hook class.
 */
class Hook_cleanup_template_usage
{
    /**
     * Find details about this cleanup hook.
     *
     * @return ?array Map of cleanup hook info (null: hook is disabled)
     */
    public function info() : ?array
    {
        $info = [];
        $info['title'] = do_lang_tempcode('TEMPLATE_USAGE');
        $info['description'] = do_lang_tempcode('DESCRIPTION_TEMPLATE_USAGE');
        $info['type'] = 'other';

        return $info;
    }

    /**
     * Run the cleanup hook action.
     *
     * @return Tempcode Results
     */
    public function run() : object
    {
        $GLOBALS['SITE_DB']->query_delete('theme_screen_tree');
        $GLOBALS['SITE_DB']->query_delete('theme_template_relations');

        require_code('files');
        require_code('themes2');

        $themes = find_all_themes();
        foreach ($themes as $theme) {
            $meta_dir = 'themes/' . $theme . '/_meta_tree';
            if (is_dir($meta_dir)) {
                deldir_contents($meta_dir);
            }
        }

        return new Tempcode();
    }
}
