<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    themewizard
 */

/**
 * Hook class.
 */
class Hook_cleanup_themewizard_files
{
    /**
     * Find details about this cleanup hook.
     *
     * @return ?array Map of cleanup hook info (null: hook is disabled)
     */
    public function info() : ?array
    {
        if (!addon_installed('themewizard')) {
            return null;
        }

        $info = [];
        $info['title'] = do_lang_tempcode('themes:THEMEWIZARD_FILES');
        $info['description'] = do_lang_tempcode('themes:DESCRIPTION_THEMEWIZARD_FILES');
        $info['type'] = 'other';

        return $info;
    }

    /**
     * Run the cleanup hook action.
     *
     * @return Tempcode Results
     */
    public function run() : object
    {
        require_code('themewizard');
        require_code('themes2');

        $files_added = [];

        $themes = find_all_themes();
        foreach (array_keys($themes) as $theme_name) {
            if (!in_array($theme_name, ['default', 'admin'])) {
                $algorithm = get_theme_option('themewizard_built_with_algorithm', '', $theme_name);
                if ($algorithm != '') {
                    // Will not overwrite anything
                    $source_theme = get_theme_option('themewizard_built_with_source_theme', null, $theme_name);
                    $seed = find_theme_seed($theme_name);
                    $dark = find_theme_dark($theme_name);
                    $_files_added = generate_themewizard_theme($theme_name, $source_theme, $algorithm, $seed, $dark, false, true);
                    $files_added = array_merge($files_added, $_files_added);
                }
            }
        }

        $out = new Tempcode();
        if (empty($files_added)) {
            $out->attach(do_lang_tempcode('upgrade:NO_ISSUES_FOUND'));
        } else {
            foreach ($files_added as $file) {
                $out->attach(div(do_lang_tempcode('ADDED_SIMPLE', escape_html($file))));
            }
        }

        return $out;
    }
}
