<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    commandr
 */

/**
 * Hook class.
 */
class Hook_commandr_command_ban_member
{
    /**
     * Run function for Commandr hooks.
     *
     * @param  array $options The options with which the command was called
     * @param  array $parameters The parameters with which the command was called
     * @param  object $commandr_fs A reference to the Commandr filesystem object
     * @return ~array Array of stdcommand, stdhtml, stdout, and stderr responses (false: error)
     */
    public function run(array $options, array $parameters, object &$commandr_fs)
    {
        if ((array_key_exists('h', $options)) || (array_key_exists('help', $options))) {
            return ['', do_command_help('ban_member', ['h', 'u'], [true]), '', ''];
        }

        if (get_forum_type() != 'cns') {
            return ['', '', '', do_lang('NO_CNS')];
        }

        if (!array_key_exists(0, $parameters)) {
            return ['', '', '', do_lang('MISSING_PARAM', '1', 'ban_member')];
        }

        require_code('cns_members_action');
        require_code('cns_members_action2');
        require_lang('cns');

        $member_id = $GLOBALS['FORUM_DRIVER']->get_member_from_username($parameters[0]);

        if (($member_id === null) || (is_guest($member_id))) {
            return ['', '', '', do_lang('_MEMBER_NO_EXIST', $parameters[0])];
        }

        if ((array_key_exists('u', $options)) || (array_key_exists('unban', $options))) {
            cns_unban_member($member_id);
        } else {
            cns_ban_member($member_id);
        }
        return ['', '', do_lang('SUCCESS'), ''];
    }
}
