<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    commandr
 */

// Opposite would be executing SQL with a '@' prefix.

/**
 * Hook class.
 */
class Hook_commandr_command_sql_dump
{
    /**
     * Run function for Commandr hooks.
     *
     * @param  array $options The options with which the command was called
     * @param  array $parameters The parameters with which the command was called
     * @param  object $commandr_fs A reference to the Commandr filesystem object
     * @return array Array of stdcommand, stdhtml, stdout, and stderr responses
     */
    public function run(array $options, array $parameters, object &$commandr_fs) : array
    {
        if ((array_key_exists('h', $options)) || (array_key_exists('help', $options))) {
            return ['', do_command_help('sql_dump', ['h'], [true, true]), '', ''];
        }

        $intended_db_type = empty($parameters[0]) ? get_db_type() : $parameters[0];

        if (count($parameters) > 2) {
            $only = [];
            for ($i = 2; $i < count($parameters); $i++) {
                $only[] = $parameters[$i];
            }
        } else {
            $only = null;
        }

        // Where to save dump
        if (isset($parameters[1])) {
            $out_filename = $parameters[1];
        } else {
            $out_filename = 'dump_' . uniqid('', true) . '.sql';
        }
        $out_file_path = get_custom_file_base() . '/exports/backups/' . $out_filename;

        // Generate dump
        require_code('database_relations');
        require_code('files');
        $out_file = cms_fopen_text_write($out_file_path);
        get_sql_dump($out_file, true, false, [], $only, null, $intended_db_type);
        fclose($out_file);
        sync_file($out_file_path);
        fix_permissions($out_file_path);

        $out = do_lang('SQL_DUMP_SAVED_TO', escape_html('exports/backups/' . $out_filename), escape_html(get_custom_base_url() . '/exports/backups/' . rawurlencode($out_filename)));

        return ['', $out, '', ''];
    }
}
