<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    commandr
 */

/**
 * Hook class.
 */
class Hook_commandr_command_users_online
{
    /**
     * Run function for Commandr hooks.
     *
     * @param  array $options The options with which the command was called
     * @param  array $parameters The parameters with which the command was called
     * @param  object $commandr_fs A reference to the Commandr filesystem object
     * @return array Array of stdcommand, stdhtml, stdout, and stderr responses
     */
    public function run(array $options, array $parameters, object &$commandr_fs) : array
    {
        if ((array_key_exists('h', $options)) || (array_key_exists('help', $options))) {
            return ['', do_command_help('users_online', ['h'], []), '', ''];
        }

        $count = 0;
        require_code('users2');
        $members = get_users_online(true, null, $count);
        if ($members === null) {
            return ['', '', do_lang('TOO_MANY_USERS_ONLINE'), ''];
        }
        $out = new Tempcode();
        $guests = 0;

        $valid_members = [];
        foreach ($members as $member) {
            if ((is_guest($member['member_id'])) || ($member['cache_username'] === null)) {
                $guests++;
            } else {
                $valid_members[$member['cache_username']] = $member['member_id'];
            }
        }

        return ['', do_template('COMMANDR_USERS_ONLINE', [
            '_GUID' => 'fcf779ef175895d425b706e40fb3252a',
            'MEMBERS' => $valid_members,
            '_GUESTS' => strval($guests),
            'GUESTS' => integer_format($guests, 0),
        ]), '', ''];
    }
}
