<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    cns_forum
 */

/**
 * Hook class.
 */
class Hook_commandr_scheduled_publish_post
{
    /**
     * Get information about this hook.
     *
     * @return ?array Map of hook details (null: addon not available)
     */
    public function info() : ?array
    {
        if (!addon_installed('cns_forum')) {
            return null;
        }

        return [
            'required_parameters' => 12,
        ];
    }

    /**
     * Run Commandr hook.
     *
     * @param  array $options The options with which the command was called
     * @param  string $id Unspecified identifier for the resource behind this scheduled event
     * @param  array $parameters The json_decoded parameters passed with run_scheduled_action
     * @param  object $commandr_fs A reference to the Commandr filesystem object
     * @return array Array of stdcommand, stdhtml, stdout, and stderr responses
     */
    public function run(array $options, string $id, array $parameters, object &$commandr_fs) : array
    {
        $topic_id = intval($id);

        // Map out parameters to make them easier to understand since there are many of them
        //  This action is for a moderator reply, so there are a lot of parameters involved
        list($forum_id, $title, $post, $skip_sig, $first_post, $is_emphasised, $poster_name_if_guest, $intended_solely_for, $topic_title, $anonymous, $poster, $ip_address) = $parameters;

        $test = $GLOBALS['FORUM_DB']->query_select_value_if_there('f_topics', 'id', ['id' => $topic_id]);
        if ($test === null) {
            return ['', '', do_lang('MISSING_RESOURCE'), ''];
        }

        require_code('cns_posts_action2');
        require_code('cns_posts_action');

        $post_id = cns_make_post($topic_id, $title, $post, $skip_sig, $first_post, 1, $is_emphasised, $poster_name_if_guest, $ip_address, null, $poster, $intended_solely_for, null, null, false, true, null, true, $topic_title, null, $anonymous == 1);

        if (($forum_id !== null) && ($anonymous == 0) && ($intended_solely_for === null)) {
            require_code('users2');
            if ((has_actual_page_access(get_modal_user(), 'forumview')) && (has_category_access(get_modal_user(), 'forums', strval($forum_id)))) {
                require_code('syndication');
                syndicate_described_activity($first_post ? 'cns:ACTIVITY_ADD_TOPIC' : 'cns:ACTIVITY_ADD_POST_IN', $first_post ? $title : $topic_title, '', '', '_SEARCH:topicview:browse:' . strval($topic_id) . '#post_' . strval($post_id), '', '', 'cns_forum', 1, $poster);
            }
        }

        return ['', '', do_lang('SUCCESS'), ''];
    }
}
