<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    newsletter
 */

/**
 * Hook class.
 */
class Hook_commandr_scheduled_send_newsletter
{
    /**
     * Get information about this hook.
     *
     * @return ?array Map of hook details (null: addon not available)
     */
    public function info() : ?array
    {
        if (!addon_installed('newsletter')) {
            return null;
        }

        return [
            'required_parameters' => 4,
        ];
    }

    /**
     * Run Commandr hook.
     *
     * @param  array $options The options with which the command was called
     * @param  string $id Unspecified identifier for the resource behind this scheduled event
     * @param  array $parameters The json_decoded parameters passed with run_scheduled_action
     * @param  object $commandr_fs A reference to the Commandr filesystem object
     * @return array Array of stdcommand, stdhtml, stdout, and stderr responses
     */
    public function run(array $options, string $id, array $parameters, object &$commandr_fs) : array
    {
        require_code('newsletter');

        $ret = call_user_func_array('send_newsletter', $parameters);

        return ['', $ret, do_lang('SUCCESS'), ''];
    }
}
