<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    galleries
 */

/**
 * Hook class.
 */
class Hook_config_galleries_sort_order
{
    /**
     * Gets the details relating to the config option.
     *
     * @return ?array The details (null: disabled)
     */
    public function get_details() : ?array
    {
        return [
            'human_name' => 'GALLERY_DEFAULT_SORT_ORDER',
            'type' => 'list',
            'category' => 'GALLERY',
            'group' => 'BROWSING_GALLERIES',
            'explanation' => 'CONFIG_OPTION_galleries_sort_order',
            'shared_hosting_restricted' => '0',
            'list_options' => 'title ASC|average_rating DESC|compound_rating DESC|recent ASC|recent DESC',
            'required' => true,
            'public' => false,
            'addon' => 'galleries',
        ];
    }

    /**
     * Gets the default value for the config option.
     *
     * @return ?string The default value (null: option is disabled)
     */
    public function get_default() : ?string
    {
        if (!addon_installed('galleries')) {
            return null;
        }

        return 'recent ASC';
    }
}
