<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core_configuration
 */

/**
 * Hook class.
 */
class Hook_config_mail_server_type
{
    /**
     * Gets the details relating to the config option.
     *
     * @return ?array The details (null: disabled)
     */
    public function get_details() : ?array
    {
        return [
            'human_name' => 'SERVER_TYPE',
            'type' => 'list',
            'category' => 'SERVER',
            'group' => 'IMAP',
            'explanation' => 'CONFIG_OPTION_mail_server_type',
            'shared_hosting_restricted' => '0',
            'list_options' => 'imap|imaps|imaps_nocert|imapt|imapt_nocert|pop3|pop3s|pop3s_nocert|pop3t|pop3t_nocert',
            'order_in_category_group' => 1,
            'required' => true,
            'public' => false,
            'addon' => 'core_configuration',
        ];
    }

    /**
     * Gets the default value for the config option.
     *
     * @return ?string The default value (null: option is disabled)
     */
    public function get_default() : ?string
    {
        if (!function_exists('imap_open') && !addon_installed('imap')) {
            return null;
        }

        return 'imap';
    }
}
