<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core_configuration
 */

/**
 * Hook class.
 */
class Hook_config_maintenance_script_htaccess
{
    /**
     * Gets the details relating to the config option.
     *
     * @return ?array The details (null: disabled)
     */
    public function get_details() : ?array
    {
        return [
            'human_name' => 'MAINTENANCE_SCRIPT_ACCESS',
            'type' => 'tick',
            'category' => 'SECURITY',
            'group' => 'GENERAL',
            'explanation' => 'CONFIG_OPTION_maintenance_script_htaccess',
            'shared_hosting_restricted' => '0',
            'list_options' => '',
            'order_in_category_group' => 9,
            'required' => true,
            'public' => false,
            'addon' => 'core_configuration',

            'maintenance_code' => 'two_factor',
        ];
    }

    /**
     * Gets the default value for the config option.
     *
     * @return ?string The default value (null: option is disabled)
     */
    public function get_default() : ?string
    {
        require_code('two_factor');
        if (!maintenance_script_htaccess_option_available()) {
            return null;
        }

        return '0';
    }

    /**
     * Code to run after the option is saved, if the value was changed or we are not formally setting it.
     *
     * @param  string $new_value The new value
     */
    public function postsave_handler(string $new_value)
    {
        // Re-adjust the htaccess file
        require_code('two_factor');
        adjust_htaccess();
    }
}
