<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    news
 */

/**
 * Hook class.
 */
class Hook_config_ping_url
{
    /**
     * Gets the details relating to the config option.
     *
     * @return ?array The details (null: disabled)
     */
    public function get_details() : ?array
    {
        return [
            'human_name' => 'PING_URL',
            'type' => 'text',
            'category' => 'FEATURE',
            'group' => 'NEWS',
            'explanation' => 'CONFIG_OPTION_ping_url',
            'shared_hosting_restricted' => '0',
            'list_options' => '',
            'order_in_category_group' => 1,
            'required' => false,
            'public' => false,
            'addon' => 'news',
        ];
    }

    /**
     * Gets the default value for the config option.
     *
     * @return ?string The default value (null: option is disabled)
     */
    public function get_default() : ?string
    {
        if (!addon_installed('news')) {
            return null;
        }

        // http://blogsearch.google.com/ping?url={url} is the direct Google Blog search one
        // Note that we also ping the major search engines directly with the RSS feed, as a sitemap; those do not need specifying in the ping URLs
        return 'http://pingomatic.com/ping/?title={title}&blogurl={url}&rssurl={rss}';
    }
}
