<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    cns_forum
 */

/**
 * Hook class.
 */
class Hook_config_topic_polls_weighting_base
{
    /**
     * Gets the details relating to the config option.
     *
     * @return ?array The details (null: disabled)
     */
    public function get_details() : ?array
    {
        return [
            'human_name' => 'TOPIC_POLLS_WEIGHTING_BASE',
            'type' => 'float',
            'category' => 'FORUMS',
            'group' => 'POLL_POINT_WEIGHTING',
            'explanation' => 'CONFIG_OPTION_topic_polls_weighting_base',
            'shared_hosting_restricted' => '0',
            'list_options' => '',
            'order_in_category_group' => 1,
            'required' => true,
            'public' => false,
            'addon' => 'cns_forum',
        ];
    }

    /**
     * Gets the default value for the config option.
     *
     * @return ?string The default value (null: option is disabled)
     */
    public function get_default() : ?string
    {
        if (!addon_installed('cns_forum') || get_forum_type() != 'cns' || !addon_installed('points')) {
            return null;
        }

        return '3';
    }

    /**
     * Code to run after the option is saved, if the value was changed or we are not formally setting it.
     *
     * @param  string $new_value The new value
     */
    public function postsave_handler(string $new_value)
    {
        require_lang('cns');
        require_code('tasks');

        // Flush voting power cache
        call_user_func_array__long_task(do_lang('CACHE_TOPICS'), null, 'cns_topics_recache', [null, false, false, true], false, false, false);
    }
}
