<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core_configuration
 */

/**
 * Hook class.
 */
class Hook_config_url_scheme
{
    /**
     * Gets the details relating to the config option.
     *
     * @return ?array The details (null: disabled)
     */
    public function get_details() : ?array
    {
        return [
            'human_name' => 'URL_SCHEME',
            'type' => 'list',
            'category' => 'SITE',
            'group' => 'SEO_URLS',
            'explanation' => 'CONFIG_OPTION_url_scheme',
            'shared_hosting_restricted' => '0',
            'list_options' => 'RAW|PG|HTM|SIMPLE',
            'order_in_category_group' => 1,
            'required' => true,
            'public' => false,
            'addon' => 'core_configuration',
        ];
    }

    /**
     * Gets the default value for the config option.
     *
     * @return ?string The default value (null: option is disabled)
     */
    public function get_default() : ?string
    {
        if (GOOGLE_APPENGINE) {
            return 'HTM';
        }
        return 'RAW';
    }

    /**
     * Code to run before the option is saved.
     * If there is some kind of problem with the new value then we could attach an error message.
     *
     * @param  string $new_value The new value
     * @param  string $old_value The old value
     * @return boolean Whether to allow the save
     */
    public function presave_handler(string $new_value, string $old_value) : bool
    {
        // Make sure we haven't locked ourselves out due to absent URL Scheme support
        $http_result = cms_http_request(get_base_url() . '/pg/keymap', ['trigger_error' => false, 'no_redirect' => true]);
        if (($http_result->data != '') && ($http_result->message == '404')) {
            attach_message(do_lang_tempcode('BEFORE_MOD_REWRITE'), 'warn');
            return false;
        }

        return true;
    }
}
