<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core_configuration
 */

/**
 * Hook class.
 */
class Hook_config_valid_images
{
    /**
     * Gets the details relating to the config option.
     *
     * @return ?array The details (null: disabled)
     */
    public function get_details() : ?array
    {
        return [
            'human_name' => 'IMAGE_TYPES',
            'type' => 'line',
            'category' => 'SECURITY',
            'group' => 'UPLOADED_FILES',
            'explanation' => 'CONFIG_OPTION_valid_images',
            'shared_hosting_restricted' => '0',
            'list_options' => '',
            'required' => true,
            'public' => true,
            'addon' => 'core_configuration',
        ];
    }

    /**
     * Gets the default value for the config option.
     *
     * @return ?string The default value (null: option is disabled)
     */
    public function get_default() : ?string
    {
        $ret = 'jpg,jpe,jpeg,gif,png,ico,cur,svg'; // Web-safe images only
        if (function_exists('imagecreatefrombmp')) {
            $ret .= ',bmp';
        }
        return $ret;
        // webp is not really websafe.
        // This encodes what we may *upload*. See the is_image function for explicitly hard-coded checks of what constitutes valid images in different situations.
    }
}
