<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core_configuration
 */

/**
 * Hook class.
 */
class Hook_contentious_overrides_configured
{
    /**
     * Add to a template being compiled.
     *
     * @param  string $data Template data
     * @param  ID_TEXT $template_name The name of the template (blank: not from a file)
     * @param  ID_TEXT $theme The name of the theme
     * @param  ID_TEXT $lang The language it is for
     * @param  ?string $suffix File type suffix of template file (e.g. .tpl) (null: not from a file)
     * @set .tpl .js .xml .txt .css
     * @param  ?string $directory Subdirectory type to look in. Surrounded by '/', unlike with $directory parameters to most other functions (performance reasons) (null: not from a file)
     */
    public function compile_template(string &$data, string $template_name, string $theme, string $lang, ?string $suffix, ?string $directory)
    {
        if (!function_exists('get_option')) {
            return;
        }

        switch ($suffix) {
            case '.js':
                $_extra_templates = get_theme_option('globally_included_js_files');
                break;

            case '.css':
                $_extra_templates = get_theme_option('globally_included_css_files');
                break;

            default:
                return;
        }

        if (trim($_extra_templates) == '') {
            return;
        }

        $extra_templates = array_map('trim', explode(',', $_extra_templates));

        if ($template_name == 'global') { // Merge into global as required
            foreach ($extra_templates as $file) {
                if ($file == '') {
                    continue;
                }

                $found = find_template_place($file, $theme, $suffix, str_replace(['/', '\\', '_custom'], ['', '', ''], $directory));
                if ($found !== null) {
                    $full_path = get_custom_file_base() . '/themes/' . $found[0] . $found[1] . $file . $found[2];
                    $data .= cms_file_get_contents_safe($full_path);
                }
            }
        } elseif (in_array($template_name, $extra_templates)) {
            $data = ''; // Wipe it out, as it will be merged into global
        }
    }
}
