<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core
 */

/**
 * Hook class.
 */
class Hook_cron_missing_editfrom
{
    /**
     * Get info from this hook.
     *
     * @param  ?TIME $last_run Last time run (null: never)
     * @param  ?boolean $calculate_num_queued Calculate the number of items queued, if possible (null: the hook may decide / low priority)
     * @return ?array Return a map of info about the hook (null: disabled)
     */
    public function info(?int $last_run, ?bool $calculate_num_queued) : ?array
    {
        return [
            'label' => 'Create missing .editfrom files',
            'num_queued' => null,
            'minutes_between_runs' => 60 * 24,
        ];
    }

    /**
     * Run function for system scheduler hooks. Searches for things to do. ->info(..., true) must be called before this method.
     *
     * @param  ?TIME $last_run Last time run (null: never)
     */
    public function run(?int $last_run)
    {
        require_code('files2');
        $bitmask = IGNORE_CUSTOM_ZONES | IGNORE_CUSTOM_THEMES | IGNORE_CUSTOM_LANGS | IGNORE_FLOATING | IGNORE_UPLOADS;
        $bitmask_files = $bitmask | IGNORE_ACCESS_CONTROLLERS | IGNORE_NONBUNDLED;
        $directories = get_directory_contents(get_file_base(), '', $bitmask, true, false);
        foreach ($directories as $directory) {
            if (strpos($directory, '_custom') !== false) {
                $files = get_directory_contents(get_file_base() . '/' . $directory, $directory, $bitmask_files, true, true, ['php', 'tpl', 'css', 'js']);
                foreach ($files as $file) {
                    $override_path = get_file_base() . '/' . $file;
                    $editfrom_path = get_file_base() . '/' . $file . '.editfrom';
                    if (!is_file($editfrom_path)) {
                        $orig_path = get_file_base() . '/' . str_replace('_custom', '', $file);
                        if (is_file($orig_path)) {
                            $orig_path_size = filesize($orig_path);
                            $override_path_size = filesize($override_path);
                            if ($orig_path_size < $override_path_size * 1.2) { // Code changes removing only up to 20% of code or code added --> A full rather than partial override
                                copy($orig_path, $editfrom_path);
                                fix_permissions($editfrom_path);
                            }
                        }
                    }
                }
            }
        }
    }
}
