<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core
 */

/**
 * Hook class.
 */
class Hook_notification_error_occurred extends Hook_notification__Staff
{
    /**
     * Find whether a handled notification code supports categories.
     * (Content types, for example, will define notifications on specific categories, not just in general. The categories are interpreted by the hook and may be complex. E.g. it might be like a regexp match, or like FORUM:3 or TOPIC:100).
     *
     * @param  ID_TEXT $notification_code Notification code
     * @return boolean Whether it does
     */
    public function supports_categories(string $notification_code) : bool
    {
        return true;
    }

    /**
     * Standard function to create the standardised category tree.
     *
     * @param  ID_TEXT $notification_code Notification code
     * @param  ?ID_TEXT $id The ID of where we're looking under (null: N/A)
     * @return array Tree structure
     */
    public function create_category_tree(string $notification_code, ?string $id) : array
    {
        $page_links = [];
        $page_links[] = ['id' => 'error_occurred_api', 'title' => do_lang('NOTIFICATION_CATEGORY_TYPE_error_occurred_api')];
        $page_links[] = ['id' => 'error_occurred_cron', 'title' => do_lang('NOTIFICATION_CATEGORY_TYPE_error_occurred_cron')];
        $page_links[] = ['id' => 'error_occurred_missing_page', 'title' => do_lang('NOTIFICATION_CATEGORY_TYPE_error_occurred_missing_page')];
        $page_links[] = ['id' => 'error_occurred_missing_reference_important', 'title' => do_lang('NOTIFICATION_CATEGORY_TYPE_error_occurred_missing_reference_important')];
        $page_links[] = ['id' => 'error_occurred_missing_reference', 'title' => do_lang('NOTIFICATION_CATEGORY_TYPE_error_occurred_missing_reference')];
        $page_links[] = ['id' => 'error_occurred_missing_resource', 'title' => do_lang('NOTIFICATION_CATEGORY_TYPE_error_occurred_missing_resource')];
        $page_links[] = ['id' => 'error_occurred_rss', 'title' => do_lang('NOTIFICATION_CATEGORY_TYPE_error_occurred_rss')];
        $page_links[] = ['id' => 'error_occurred', 'title' => do_lang('GENERAL')];

        if (addon_installed('health_check')) {
            $page_links[] = ['id' => 'health_check_failed', 'title' => do_lang('health_check:HEALTH_CHECK_SUBJECT_fail')];
            $page_links[] = ['id' => 'health_check_passed', 'title' => do_lang('health_check:HEALTH_CHECK_SUBJECT_misc')];
        }

        return $page_links;
    }

    /**
     * Find the initial setting that members have for a notification code (only applies to the member_could_potentially_enable members).
     *
     * @param  ID_TEXT $notification_code Notification code
     * @param  ?SHORT_TEXT $category The category within the notification code (null: none)
     * @param  MEMBER $member_id The member the notification would be for
     * @return integer Initial setting
     */
    public function get_initial_setting(string $notification_code, ?string $category, int $member_id) : int
    {
        return A_NA;
    }

    /**
     * Get a list of all the notification codes this hook can handle.
     * (Addons can define hooks that handle whole sets of codes, so hooks are written so they can take wide authority).
     *
     * @return array List of codes (mapping between code names, and a pair: section and labelling for those codes)
     */
    public function list_handled_codes() : array
    {
        $list = [];
        $list['error_occurred'] = [do_lang('ERRORS'), do_lang('NOTIFICATION_TYPE_error_occurred')];
        return $list;
    }
}
