<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    news
 */

/**
 * Hook class.
 */
class Hook_page_groupings_news
{
    /**
     * Run function for do_next_menu hooks. They find links to put on standard navigation menus of the system.
     *
     * @param  ?MEMBER $member_id Member ID to run as (null: current member)
     * @param  boolean $extensive_docs Whether to use extensive documentation tooltips, rather than short summaries
     * @return array List of tuple of links (page grouping, icon, do-next-style linking data), label, help (optional) and/or nulls
     */
    public function run(?int $member_id = null, bool $extensive_docs = false) : array
    {
        if (!addon_installed('news')) {
            return [];
        }

        $cnt = intval($GLOBALS['SITE_DB']->query_select_value('news', 'COUNT(*)'));
        $cnt_blogs = $cnt - intval($GLOBALS['SITE_DB']->query_select_value('news n LEFT JOIN ' . get_table_prefix() . 'news_categories c ON c.id=n.news_category', 'COUNT(*)', ['nc_owner' => null]));

        return [
            has_privilege(get_member(), 'submit_highrange_content', 'cms_news') ? ['cms', 'menu/rich_content/news', ['cms_news', ['type' => 'browse'], get_module_zone('cms_news')], do_lang_tempcode('ITEMS_HERE', do_lang_tempcode('NEWS'), make_string_tempcode(escape_html(integer_format($cnt, 0)))), 'news:DOC_NEWS'] : null,
            (get_option('separate_blogs') == '0') ? null : (has_privilege(get_member(), 'submit_highrange_content', 'cms_blogs') ? ['cms', 'menu/cms/blog', ['cms_blogs', ['type' => 'browse'], get_module_zone('cms_blogs')], do_lang_tempcode('ITEMS_HERE', do_lang_tempcode('news:BLOGS'), make_string_tempcode(escape_html(integer_format($cnt_blogs, 0)))), 'news:DOC_BLOGS'] : null),
            ['rich_content', 'menu/rich_content/news', ['news', [], get_module_zone('news')], do_lang_tempcode('NEWS')],
        ];
    }
}
