<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    points
 */

/**
 * Hook class.
 */
class Hook_page_groupings_points
{
    /**
     * Run function for do_next_menu hooks. They find links to put on standard navigation menus of the system.
     *
     * @param  ?MEMBER $member_id Member ID to run as (null: current member)
     * @param  boolean $extensive_docs Whether to use extensive documentation tooltips, rather than short summaries
     * @return array List of tuple of links (page grouping, icon, do-next-style linking data), label, help (optional) and/or nulls
     */
    public function run(?int $member_id = null, bool $extensive_docs = false) : array
    {
        if (!addon_installed('points')) {
            return [];
        }

        return [
            ['audit', 'menu/adminzone/audit/points_log', ['admin_points', ['type' => 'browse'], get_module_zone('admin_points')], do_lang_tempcode('points:POINTS_LEDGER'), 'points:DOC_POINTS'],
            ['audit', 'menu/social/points', ['admin_points', ['type' => 'export_overview'], get_module_zone('admin_points')], do_lang_tempcode('points:EXPORT_POINTS_OVERVIEW'), 'points:DOC_EXPORT_POINTS_OVERVIEW'],
            (get_forum_type() == 'cns' || get_forum_type() == 'none') ? null : ['social', 'menu/social/points', ['points', [], get_module_zone('points')], do_lang_tempcode('points:VIEW_POINTS')],
        ];
    }
}
