<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    welcome_emails
 */

/**
 * Hook class.
 */
class Hook_preview_cns_welcome_email
{
    /**
     * Find whether this preview hook applies.
     *
     * @return array A pair: The preview, the updated post Comcode
     */
    public function applies() : array
    {
        $member_id = get_param_integer('id', get_member());

        $applies = (addon_installed('welcome_emails')) && (get_page_name() == 'admin_cns_welcome_emails');

        return [$applies, null];
    }

    /**
     * Run function for preview hooks.
     *
     * @return array A pair: The preview, the updated post Comcode
     */
    public function run() : array
    {
        $mail = $this->get_mail_row();

        require_code('cns_welcome_emails');
        list($subject, $message, $is_html, $name) = cns_prepare_welcome_email($mail);

        if (($is_html) && (addon_installed('newsletter')/*will actually always be true if $is_html*/)) {
            require_javascript('newsletter');

            $preview = do_template('NEWSLETTER_PREVIEW', ['_GUID' => '3790bb2b050e0c8c4339db54a063579a', 'HTML_PREVIEW' => $message]);
        } else {
            $preview = comcode_to_tempcode($message);
        }

        return [$preview, null];
    }

    /**
     * Get a simulated row for the welcome e-mail being previewed.
     *
     * @return array Row
     */
    protected function get_mail_row() : array
    {
        $name = post_param_string('welcome_email_name');
        $subject = post_param_string('subject');
        $text = post_param_string('text');
        $send_time = post_param_integer('send_time');
        $newsletter = post_param_integer('newsletter', null);
        $usergroup = post_param_integer('usergroup', null);
        $usergroup_type = post_param_string('usergroup_type', '');

        return [
            'w_name' => $name,
            'w_subject' => $subject,
            'w_text' => $text,
            'w_send_time' => $send_time,
            'w_newsletter' => $newsletter,
            'w_usergroup' => $usergroup,
            'w_usergroup_type' => $usergroup_type,
        ];
    }
}
