<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    newsletter
 */

/**
 * Hook class.
 */
class Hook_preview_newsletter_whatsnew
{
    /**
     * Find whether this preview hook applies.
     *
     * @return array Triplet: Whether it applies, the attachment ID type (may be null), whether the forum DB is used [optional]
     */
    public function applies() : array
    {
        $applies = (addon_installed('newsletter')) && (get_page_name() == 'admin_newsletter') && ((get_param_string('type', 'browse') == 'whatsnew') || (get_param_string('type', 'browse') == 'whatsnew_2'));
        return [$applies, null, false];
    }

    /**
     * Run function for preview hooks.
     *
     * @return array A pair: The preview, the updated post Comcode (may be null)
     */
    public function run() : array
    {
        require_code('newsletter');
        require_lang('newsletter');
        require_javascript('newsletter');

        $lang = user_lang__with__translation_override(true);

        if (get_param_string('type', 'browse') == 'whatsnew') {
            $cutoff_time = post_param_date('cutoff');
            $chosen_categories = newsletter_get_category_choices($cutoff_time, $lang);

            $output = with_whitespace($chosen_categories);
        } else {
            $cutoff_time = post_param_date('cutoff');
            $in_full = post_param_integer('in_full', 0);
            $chosen_categories = post_param_string('chosen_categories');
            $message = generate_whatsnew_comcode($chosen_categories, $in_full, $lang, $cutoff_time);

            list($preview) = newsletter_preview($message, do_lang('EXAMPLE'), $lang, true, do_lang('SAMPLE_FORENAME'), do_lang('SAMPLE_SURNAME'), do_lang('SAMPLE_NAME'), do_lang('SAMPLE_ADDRESS'));
            $output = do_template('NEWSLETTER_PREVIEW', ['_GUID' => 'd4abd6c367712a043ea2747453217fb8', 'HTML_PREVIEW' => $preview]);
        }

        return [$output, null, false];
    }
}
