<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    themewizard
 */

/**
 * Hook class.
 */
class Hook_preview_themewizard_image
{
    /**
     * Find whether this preview hook applies.
     *
     * @return array Triplet: Whether it applies, the attachment ID type (may be null), whether the forum DB is used [optional]
     */
    public function applies() : array
    {
        $applies = (addon_installed('themewizard')) && (get_page_name() == 'admin_themes') && (get_param_string('type', '') == 'edit_image');
        return [$applies, null, false];
    }

    /**
     * Run function for preview hooks.
     *
     * @return array A pair: The preview, the updated post Comcode (may be null)
     */
    public function run() : array
    {
        require_lang('themes');
        require_code('themewizard');
        require_code('themes3');

        $theme = post_param_string('theme');
        $id = post_param_string('id');

        $seed = post_param_string('seed');
        $dark = (post_param_integer('dark', 0) == 1);

        $image = generate_themewizard_image($seed, $dark, 'default', 'hsv', $id);
        if ($image === null) {
            warn_exit(do_lang_tempcode('INTERNAL_ERROR'));
        }

        $saveat = cms_tempnam();
        if (is_string($image)) {
            cms_file_put_contents_safe($saveat, $image);

            cms_ob_end_clean();

            $mime_type = 'image/svg+xml';
        } else {
            cms_imagesave($image, $saveat, 'png') or intelligent_write_error($saveat);
            imagedestroy($image);

            cms_ob_end_clean();

            $mime_type = 'image/png';
        }

        $preview = protect_from_escaping('<img src="data:' . $mime_type . ';base64,' . base64_encode(file_get_contents($saveat)) . '" />');

        @unlink($saveat);

        return [$preview, null];
    }
}
