<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    content_privacy
 */

/**
 * Hook class.
 */
class Hook_privacy_content_privacy extends Hook_privacy_base
{
    /**
     * Find privacy details.
     *
     * @return ?array A map of privacy details in a standardised format (null: disabled)
     */
    public function info() : ?array
    {
        if (!addon_installed('content_privacy')) {
            return null;
        }
        if (get_forum_type() != 'cns') {
            return null;
        }

        require_lang('content_privacy');

        return [
            'label' => 'content_privacy:PRIVACY_SETTINGS',

            'description' => 'content_privacy:DESCRIPTION_PRIVACY_PRIVACY_SETTINGS',

            'cookies' => [
            ],

            'positive' => [
                [
                    'heading' => do_lang('INFORMATION_STORAGE'),
                    'explanation' => do_lang_tempcode('PRIVACY_SETTINGS_EXPLANATION', escape_html(static_evaluate_tempcode(build_url(['page' => 'members', 'type' => 'view'], get_module_zone('members'), [], false, false, false, 'tab--edit--privacy')))),
                ],
            ],

            'general' => [
            ],

            'database_records' => [
                'content_privacy__members' => [
                    'timestamp_field' => null,
                    'retention_days' => null,
                    'retention_handle_method' => PRIVACY_METHOD__LEAVE,
                    'owner_id_field' => 'member_id',
                    'additional_member_id_fields' => [],
                    'ip_address_fields' => [],
                    'email_fields' => [],
                    'username_fields' => [],
                    'additional_anonymise_fields' => [],
                    'extra_where' => null,
                    'removal_default_handle_method' => PRIVACY_METHOD__DELETE,
                    'removal_default_handle_method_member_override' => null,
                    'allowed_handle_methods' => PRIVACY_METHOD__DELETE,
                ],
            ],
        ];
    }
}
