<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    filedump
 */

/**
 * Hook class.
 */
class Hook_privacy_filedump extends Hook_privacy_base
{
    /**
     * Find privacy details.
     *
     * @return ?array A map of privacy details in a standardised format (null: disabled)
     */
    public function info() : ?array
    {
        if (!addon_installed('filedump')) {
            return null;
        }

        return [
            'label' => 'filedump:FILEDUMP',

            'description' => 'filedump:DESCRIPTION_PRIVACY_FILEDUMP',

            'cookies' => [
            ],

            'positive' => [
            ],

            'general' => [
            ],

            'database_records' => [
                'filedump' => [
                    'timestamp_field' => null,
                    'retention_days' => null,
                    'retention_handle_method' => PRIVACY_METHOD__LEAVE,
                    'owner_id_field' => 'the_member',
                    'additional_member_id_fields' => [],
                    'ip_address_fields' => [],
                    'email_fields' => [],
                    'username_fields' => [],
                    'additional_anonymise_fields' => [],
                    'extra_where' => null,
                    'removal_default_handle_method' => PRIVACY_METHOD__ANONYMISE,
                    'removal_default_handle_method_member_override' => null,
                    'allowed_handle_methods' => PRIVACY_METHOD__ANONYMISE | PRIVACY_METHOD__DELETE,
                ],
            ],
        ];
    }

    /**
     * Delete a row.
     *
     * @param  ID_TEXT $table_name Table name
     * @param  array $table_details Details of the table from the info function
     * @param  array $row Row raw from the database
     */
    public function delete(string $table_name, array $table_details, array $row)
    {
        switch ($table_name) {
            case 'filedump':
                $rows = $GLOBALS['SITE_DB']->query_select('filedump', ['*'], ['id' => $row['id']], '', 1);
                if (array_key_exists(0, $rows)) {
                    $path = get_custom_file_base() . '/uploads/filedump' . $row['subpath'] . $row['name'];
                    @unlink($path);
                    sync_file($path);
                    $GLOBALS['SITE_DB']->query_delete('filedump', ['id' => $row['id']]);
                }
                break;

            default:
                parent::delete($table_name, $table_details, $row);
                break;
        }
    }
}
