<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core
 */

/**
 * Hook class.
 */
class Hook_spam_heuristics_pasting
{
    /**
     * Find the confidence score for a particular spam heuristic as applied to the current context.
     *
     * @param  string $post_data Posted data
     * @return integer Confidence score
     */
    public function assess_confidence(string $post_data) : int
    {
        $score = intval(get_option('spam_heuristic_confidence_pasting'));
        if ($score == 0) {
            return 0;
        }

        $post_data = post_param_string('post_data', null);
        if (!cms_empty_safe($post_data)) {
            $bits = explode(',', $post_data);
            if (in_array('paste', $bits)) {
                return $score;
            }
        }

        return 0;
    }
}
