<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core
 */

/**
 * Hook class.
 */
class Hook_symbol_CONTENT_COUNT
{
    /**
     * Run function for symbol hooks. Searches for tasks to perform.
     *
     * @param  array $param Symbol parameters
     * @return string Result
     */
    public function run(array $param) : string
    {
        if (empty($param[0])) {
            return '';
        }

        $content_type = $param[0];
        $select = array_key_exists(1, $param) ? $param[1] : '';
        $filter = array_key_exists(2, $param) ? $param[2] : '';

        require_code('content');
        $object = get_content_object($content_type);
        if ($object === null) {
            return do_lang('NO_SUCH_CONTENT_TYPE', escape_html($content_type));
        }
        $info = $object->info();

        $db = $info['db'];

        if ($select == '') {
            $extra_where_selectcode = '1=1';
        } else {
            require_code('content');
            $extra_where_selectcode = build_selectcode_select_for_content_type($select, $info);
        }

        require_code('filtercode');
        list($extra_join_filtercode, $extra_where_filtercode) = filtercode_to_sql($db, parse_filtercode($filter), $content_type);

        $count = $db->query_select_value($info['table'] . ' r' . implode('', $extra_join_filtercode), 'COUNT(*)', [], ' AND ' . $extra_where_selectcode . $extra_where_filtercode);

        $value = strval($count);

        return $value;
    }
}
