<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    galleries
 */

/**
 * Hook class.
 */
class Hook_symbol_GALLERY_VIDEO_FOR_URL
{
    /**
     * Run function for symbol hooks. Searches for tasks to perform.
     *
     * @param  array $param Symbol parameters
     * @return string Result
     */
    public function run(array $param) : string
    {
        if (!addon_installed('galleries')) {
            return '';
        }

        $value = '';

        if (!empty($param[0])) {
            $url = $param[0];
            if (strpos($url, ' ') !== false) {
                $url = rawurlencode(str_replace('%2F', '/', $url)); // In case was not properly encoded as URL
            }

            $test = $GLOBALS['SITE_DB']->query_select_value_if_there('videos', 'id', ['url' => $url]);
            if ($test !== null) {
                $value = strval($test);
            } else {
                require_code('galleries2');
                list($width, $height, $length, $title, $cat) = video_get_default_metadata($url);

                if (!empty($param[1])) {
                    $title = $param[1];
                }

                if (!empty($param[2])) {
                    $cat = $param[2];
                }

                if (($width !== null) && ($height !== null) && ($length !== null) && ($title != '') && ($cat != '')) {
                    require_code('galleries2');
                    require_lang('galleries');

                    $allow_rating = isset($param[3]) ? ((intval($param[3]) == 1) ? 1 : 0) : 1;
                    $allow_comments = isset($param[4]) ? ((intval($param[4]) == 1) ? 1 : 0) : 1;
                    $allow_trackbacks = isset($param[5]) ? ((intval($param[5]) == 1) ? 1 : 0) : 1;

                    $id = add_video($title, $cat, '', $url, '', 1, $allow_rating, $allow_comments, $allow_trackbacks, do_lang('VIDEO_WAS_AUTO_IMPORTED'), $length, $width, $height);
                }
            }
        }

        return $value;
    }
}
