<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core_privacy
 */

/**
 * Hook class.
 */
class Hook_symbol_PRIVACY_POLICY_DATE
{
    /**
     * Run function for symbol hooks. Searches for tasks to perform.
     *
     * @param  array $param Symbol parameters
     * @return string Result
     */
    public function run(array $param) : string
    {
        $privacy_block_time = get_value('privacy_policy_auto__time', null, true);
        if ($privacy_block_time === null) {
            do_block('main_privacy_policy_auto'); // Force generation
            $privacy_block_time = get_value('privacy_policy_auto__time', null, true);
        }

        $times = [];
        $times[] = intval($privacy_block_time);

        global $METADATA;
        $page = empty($param[0]) ? 'privacy' : $param[0];
        if (($page === get_page_name()) && (isset($METADATA['created_RAW']))) {
            $page_modified = isset($METADATA['modified']) ? intval($METADATA['modified_RAW']) : null;
            $page_created = isset($METADATA['created']) ? intval($METADATA['created_RAW']) : null;
        } else {
            $page_details = $GLOBALS['SITE_DB']->query_select('comcode_pages', ['p_add_date', 'p_edit_date'], ['the_zone' => '', 'the_page' => $page], '', 1);
            if (isset($page_details[0])) {
                $page_created = $page_details[0]['p_add_date'];
                $page_modified = $page_details[0]['p_edit_date'];
            } else {
                $page_created = null;
                $page_modified = null;
            }
        }
        $times[] = $page_created;
        $times[] = $page_modified;

        $latest_time = null;
        foreach ($times as $time) {
            if (($time !== null) && (($latest_time === null) || ($time > $latest_time))) {
                $latest_time = $time;
            }
        }

        if ($latest_time === null) {
            $latest_time = time();
        }

        $value = strval($latest_time);
        return $value;
    }
}
