<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core_language_editing
 */

/**
 * Hook class.
 */
class Hook_symbol_PROVIDE_WITH_TRANSLATION
{
    /**
     * Run function for symbol hooks. Searches for tasks to perform.
     *
     * @param  array $param Symbol parameters
     * @return string Result
     */
    public function run(array $param) : string
    {
        require_code('translation');

        $text = isset($param[0]) ? $param[0] : '';

        if (!defined('TRANS_TEXT_CONTEXT__HTML_BLOCK')) {
            return $text; // Somehow startup hook didn't run
        }

        if (!empty($param[1])) {
            $context = @constant('TRANS_TEXT_CONTEXT_' . $param[1]);
            if ($context === null) {
                $context = TRANS_TEXT_CONTEXT__HTML_BLOCK;
            }
        } else {
            $context = TRANS_TEXT_CONTEXT__HTML_BLOCK;
        }

        $from = empty($param[2]) ? null : $param[2];

        $errormsg = null;
        $text_translated = translate_text($text, $context, $from, user_lang(), null, $errormsg);

        if ($errormsg !== null) {
            require_code('failure');
            cms_error_log($errormsg, 'error_occurred_api');
        }

        if ($text_translated === null) {
            return $text;
        }

        switch ($context) {
            case TRANS_TEXT_CONTEXT__PLAIN:
                $text .= ' (' . $text_translated . ')';
                break;

            case TRANS_TEXT_CONTEXT__HTML_BLOCK:
                $text .= '<br /><div class="box box__translation"><div class="box_inner">' . $text_translated . '</div></div>'; // Comes with a "Powered by" message
                break;

            case TRANS_TEXT_CONTEXT__HTML_INLINE:
                $text .= ' (' . $text_translated . ')';
                break;
        }

        return $text;
    }
}
