<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    backup
 */

/**
 * Hook class.
 */
class Hook_task_make_backup
{
    /**
     * Run the task hook.
     *
     * @param  string $file The filename to backup to
     * @param  string $b_type The type of backup to do
     * @set full incremental
     * @param  integer $max_size The maximum size of a file to include in the backup
     * @return ?array A tuple of at least 2: Return mime-type, content (either Tempcode, or a string, or a filename and file-path pair to a temporary file), map of HTTP headers if transferring immediately, map of ini_set commands if transferring immediately (null: show standard success message)
     */
    public function run(string $file, string $b_type, int $max_size) : ?array
    {
        if (!addon_installed('backup')) {
            return null;
        }

        require_code('backup');
        $backup_result = make_backup($file, $b_type, $max_size, [$this, 'log']);

        return ['text/html', $backup_result];
    }

    /**
     * Do logging.
     *
     * @param  string $message Message to log
     */
    public function log(string $message)
    {
        static $i = 0;

        task_log($this, $message);

        $i++;
    }
}
