<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    news
 */

/**
 * Hook class.
 */
class Hook_task_rss_cloud_update
{
    /**
     * Run the task hook.
     *
     * @return ?array A tuple of at least 2: Return mime-type, content (either Tempcode, or a string, or a filename and file-path pair to a temporary file), map of HTTP headers if transferring immediately, map of ini_set commands if transferring immediately (null: show standard success message)
     */
    public function run() : ?array
    {
        if (!addon_installed('news')) {
            return null;
        }

        // Send out on RSS cloud
        if (php_function_allowed('fsockopen')) {
            $start = 0;
            do {
                $listeners = $GLOBALS['SITE_DB']->query_select('news_rss_cloud', ['*'], [], '', 100, $start);
                foreach ($listeners as $listener) {
                    $data = $listener['watching_channel'];
                    if ($listener['rem_protocol'] == 'xml-rpc') {
                        require_code('xmlrpc');
                        xml_rpc('http://' . $listener['rem_ip'] . ':' . strval($listener['rem_port']) . '/' . $listener['rem_path'], $listener['rem_procedure'], $data, true);
                    }
                    // Other protocols not supported
                }
                $start += 100;
            } while (array_key_exists(0, $listeners));
            if (!$GLOBALS['SITE_DB']->table_is_locked('news_rss_cloud')) {
                $GLOBALS['SITE_DB']->query('DELETE FROM ' . get_table_prefix() . 'news_rss_cloud WHERE register_time<' . strval(time() - 25 * 60 * 60), null, 0, true); // Errors suppressed in case DB write access broken
            }
        }

        return null;
    }
}
