<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core
 */

/**
 * Hook class.
 */
class Hook_task_sitemap
{
    /**
     * Run the task hook.
     *
     * @param  boolean $full_regenerate Whether to do a full sitemap rebuild
     * @return ?array A tuple of at least 2: Return mime-type, content (either Tempcode, or a string, or a filename and file-path pair to a temporary file), map of HTTP headers if transferring immediately, map of ini_set commands if transferring immediately (null: show standard success message)
     */
    public function run(bool $full_regenerate = false) : ?array
    {
        set_value('sitemap_building_in_progress', '1', true);

        require_code('sitemap_xml');

        if ($full_regenerate) {
            build_sitemap_cache_table();
        }

        sitemap_xml_build([$this, 'log']);

        set_value('sitemap_building_in_progress', '0', true);

        return null;
    }

    /**
     * Do logging.
     */
    public function log()
    {
        static $i = 0;

        task_log($this, 'Processing row into XML Sitemap', $i);

        $i++;
    }
}
