<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    polls
 */

/**
 * Add a new poll to the database, then return the ID of the new entry.
 *
 * @param  SHORT_TEXT $question The question
 * @param  SHORT_TEXT $a1 The first choice
 * @range  1 max
 * @param  SHORT_TEXT $a2 The second choice
 * @range  1 max
 * @param  SHORT_TEXT $a3 The third choice (blank means not a choice)
 * @param  SHORT_TEXT $a4 The fourth choice (blank means not a choice)
 * @param  SHORT_TEXT $a5 The fifth choice (blank means not a choice)
 * @param  SHORT_TEXT $a6 The sixth choice (blank means not a choice)
 * @param  SHORT_TEXT $a7 The seventh choice (blank means not a choice)
 * @param  SHORT_TEXT $a8 The eighth choice (blank means not a choice)
 * @param  SHORT_TEXT $a9 The ninth choice (blank means not a choice)
 * @param  SHORT_TEXT $a10 The tenth choice (blank means not a choice)
 * @param  ?integer $num_options The number of choices (null: calculate)
 * @range  2 5
 * @param  BINARY $current Whether the poll is the current poll
 * @param  BINARY $allow_rating Whether to allow rating of this poll
 * @param  SHORT_INTEGER $allow_comments Whether comments are allowed (0=no, 1=yes, 2=review style)
 * @param  BINARY $allow_trackbacks Whether to allow trackbacking on this poll
 * @param  LONG_TEXT $notes Notes about this poll
 * @param  ?TIME $time The time the poll was submitted (null: now)
 * @param  ?MEMBER $submitter The member who submitted (null: the current member)
 * @param  ?TIME $use_time The time the poll was put to use (null: not put to use yet)
 * @param  integer $v1 How many have voted for option 1
 * @range  0 max
 * @param  integer $v2 How many have voted for option 2
 * @range  0 max
 * @param  integer $v3 How many have voted for option 3
 * @range  0 max
 * @param  integer $v4 How many have voted for option 4
 * @range  0 max
 * @param  integer $v5 How many have voted for option 5
 * @range  0 max
 * @param  integer $v6 How many have voted for option 6
 * @range  0 max
 * @param  integer $v7 How many have voted for option 7
 * @range  0 max
 * @param  integer $v8 How many have voted for option 8
 * @range  0 max
 * @param  integer $v9 How many have voted for option 9
 * @range  0 max
 * @param  integer $v10 How many have voted for option 10
 * @range  0 max
 * @param  integer $views The number of views had
 * @param  ?TIME $edit_date The edit date (null: never)
 * @return AUTO_LINK The poll ID of our new poll
 */
function add_poll(string $question, string $a1, string $a2, string $a3 = '', string $a4 = '', string $a5 = '', string $a6 = '', string $a7 = '', string $a8 = '', string $a9 = '', string $a10 = '', ?int $num_options = null, int $current = 0, int $allow_rating = 1, int $allow_comments = 1, int $allow_trackbacks = 1, string $notes = '', ?int $time = null, ?int $submitter = null, ?int $use_time = null, int $v1 = 0, int $v2 = 0, int $v3 = 0, int $v4 = 0, int $v5 = 0, int $v6 = 0, int $v7 = 0, int $v8 = 0, int $v9 = 0, int $v10 = 0, int $views = 0, ?int $edit_date = null) : int
{
    require_code('global4');
    prevent_double_submit('ADD_POLL', null, $question);

    if ($num_options === null) {
        $num_options = 2;
        if ($a3 != '') {
            $num_options++;
        }
        if ($a4 != '') {
            $num_options++;
        }
        if ($a5 != '') {
            $num_options++;
        }
        if ($a6 != '') {
            $num_options++;
        }
        if ($a7 != '') {
            $num_options++;
        }
        if ($a8 != '') {
            $num_options++;
        }
        if ($a9 != '') {
            $num_options++;
        }
        if ($a10 != '') {
            $num_options++;
        }
    }

    if ($current == 1) {
        persistent_cache_delete('POLL');
        $GLOBALS['SITE_DB']->query_update('poll', ['is_current' => 0], ['is_current' => 1], '', 1);
    }

    if ($time === null) {
        $time = time();
    }
    if ($submitter === null) {
        $submitter = get_member();
    }

    $map = [
        'edit_date' => $edit_date,
        'poll_views' => $views,
        'add_time' => $time,
        'allow_trackbacks' => $allow_trackbacks,
        'allow_rating' => $allow_rating,
        'allow_comments' => $allow_comments,
        'notes' => $notes,
        'submitter' => $submitter,
        'date_and_time' => $use_time,
        'votes1' => $v1,
        'votes2' => $v2,
        'votes3' => $v3,
        'votes4' => $v4,
        'votes5' => $v5,
        'votes6' => $v6,
        'votes7' => $v7,
        'votes8' => $v8,
        'votes9' => $v9,
        'votes10' => $v10,
        'num_options' => $num_options,
        'is_current' => $current,
    ];
    $map += insert_lang_comcode('question', $question, 1);
    $map += insert_lang_comcode('option1', $a1, 1);
    $map += insert_lang_comcode('option2', $a2, 1);
    $map += insert_lang_comcode('option3', $a3, 1);
    $map += insert_lang_comcode('option4', $a4, 1);
    $map += insert_lang_comcode('option5', $a5, 1);
    $map += insert_lang_comcode('option6', $a6, 1);
    $map += insert_lang_comcode('option7', $a7, 1);
    $map += insert_lang_comcode('option8', $a8, 1);
    $map += insert_lang_comcode('option9', $a9, 1);
    $map += insert_lang_comcode('option10', $a10, 1);
    $id = $GLOBALS['SITE_DB']->query_insert('poll', $map, true);

    log_it('ADD_POLL', strval($id), $question);

    require_code('member_mentions');
    dispatch_member_mention_notifications('poll', strval($id), $submitter);

    if ((addon_installed('commandr')) && (!running_script('install')) && (!get_mass_import_mode())) {
        require_code('resource_fs');
        generate_resource_fs_moniker('poll', strval($id), null, null, true);
    }

    if ($current == 1) {
        require_code('sitemap_xml');
        notify_sitemap_node_add('_SEARCH:polls:view:' . strval($id));
    }

    return $id;
}

/**
 * Edit a poll.
 *
 * @param  AUTO_LINK $id The ID of the poll to edit
 * @param  SHORT_TEXT $question The question
 * @param  SHORT_TEXT $a1 The first choice
 * @range  1 max
 * @param  SHORT_TEXT $a2 The second choice
 * @range  1 max
 * @param  SHORT_TEXT $a3 The third choice (blank means not a choice)
 * @param  SHORT_TEXT $a4 The fourth choice (blank means not a choice)
 * @param  SHORT_TEXT $a5 The fifth choice (blank means not a choice)
 * @param  SHORT_TEXT $a6 The sixth choice (blank means not a choice)
 * @param  SHORT_TEXT $a7 The seventh choice (blank means not a choice)
 * @param  SHORT_TEXT $a8 The eighth choice (blank means not a choice)
 * @param  SHORT_TEXT $a9 The ninth choice (blank means not a choice)
 * @param  SHORT_TEXT $a10 The tenth choice (blank means not a choice)
 * @param  integer $num_options The number of choices
 * @param  BINARY $allow_rating Whether to allow rating of this poll
 * @param  SHORT_INTEGER $allow_comments Whether comments are allowed (0=no, 1=yes, 2=review style)
 * @param  BINARY $allow_trackbacks Whether to allow trackbacking on this poll
 * @param  LONG_TEXT $notes Notes about this poll
 * @param  ?TIME $edit_time Edit time (null: either means current time, or if $null_is_literal, means reset to to null)
 * @param  ?TIME $add_time Add time (null: do not change)
 * @param  ?integer $views Number of views (null: do not change)
 * @param  ?MEMBER $submitter Submitter (null: do not change)
 * @param  boolean $null_is_literal Determines whether some nulls passed mean 'use a default' or literally mean 'set to null'
 */
function edit_poll(int $id, string $question, string $a1, string $a2, string $a3, string $a4, string $a5, string $a6, string $a7, string $a8, string $a9, string $a10, int $num_options, int $allow_rating, int $allow_comments, int $allow_trackbacks, string $notes, ?int $edit_time = null, ?int $add_time = null, ?int $views = null, ?int $submitter = null, bool $null_is_literal = false)
{
    if ($edit_time === null) {
        $edit_time = $null_is_literal ? null : time();
    }

    $rows = $GLOBALS['SITE_DB']->query_select('poll', ['*'], ['id' => $id], '', 1);
    if (!array_key_exists(0, $rows)) {
        warn_exit(do_lang_tempcode('MISSING_RESOURCE', 'poll'));
    }

    log_it('EDIT_POLL', strval($id), $question);

    if ((addon_installed('commandr')) && (!running_script('install')) && (!get_mass_import_mode())) {
        require_code('resource_fs');
        generate_resource_fs_moniker('poll', strval($id));
    }

    persistent_cache_delete('POLL');

    $_question = $rows[0]['question'];
    $_a1 = $rows[0]['option1'];
    $_a2 = $rows[0]['option2'];
    $_a3 = $rows[0]['option3'];
    $_a4 = $rows[0]['option4'];
    $_a5 = $rows[0]['option5'];
    $_a6 = $rows[0]['option6'];
    $_a7 = $rows[0]['option7'];
    $_a8 = $rows[0]['option8'];
    $_a9 = $rows[0]['option9'];
    $_a10 = $rows[0]['option10'];

    $update_map = [
        'allow_rating' => $allow_rating,
        'allow_comments' => $allow_comments,
        'allow_trackbacks' => $allow_trackbacks,
        'notes' => $notes,
        'num_options' => $num_options,
    ];
    $update_map += lang_remap_comcode('question', $_question, $question);
    $update_map += lang_remap_comcode('option1', $_a1, $a1);
    $update_map += lang_remap_comcode('option2', $_a2, $a2);
    $update_map += lang_remap_comcode('option3', $_a3, $a3);
    $update_map += lang_remap_comcode('option4', $_a4, $a4);
    $update_map += lang_remap_comcode('option5', $_a5, $a5);
    $update_map += lang_remap_comcode('option6', $_a6, $a6);
    $update_map += lang_remap_comcode('option7', $_a7, $a7);
    $update_map += lang_remap_comcode('option8', $_a8, $a8);
    $update_map += lang_remap_comcode('option9', $_a9, $a9);
    $update_map += lang_remap_comcode('option10', $_a10, $a10);

    $update_map['edit_date'] = $edit_time;
    if ($add_time !== null) {
        $update_map['add_time'] = $add_time;
    }
    if ($views !== null) {
        $update_map['poll_views'] = $views;
    }
    if ($submitter !== null) {
        $update_map['submitter'] = $submitter;
    }

    $GLOBALS['SITE_DB']->query_update('poll', $update_map, ['id' => $id], '', 1);
    persistent_cache_delete('POLL');
    delete_cache_entry('main_poll');

    require_code('urls2');
    suggest_new_idmoniker_for('polls', 'view', strval($id), '', $question);

    require_code('feedback');
    update_spacer_post(
        $allow_comments != 0,
        'polls',
        strval($id),
        build_url(['page' => 'polls', 'type' => 'view', 'id' => $id], get_module_zone('polls'), [], false, false, true),
        $question,
        find_overridden_comment_forum('polls')
    );

    require_code('sitemap_xml');
    if ($rows[0]['is_current'] == 1) {
        notify_sitemap_node_edit('_SEARCH:polls:view:' . strval($id));
    } else {
        notify_sitemap_node_delete('_SEARCH:polls:view:' . strval($id));
    }
}

/**
 * Delete a poll.
 *
 * @param  AUTO_LINK $id The ID of the poll to delete
 */
function delete_poll(int $id)
{
    $rows = $GLOBALS['SITE_DB']->query_select('poll', ['*'], ['id' => $id], '', 1);
    if (!array_key_exists(0, $rows)) {
        warn_exit(do_lang_tempcode('MISSING_RESOURCE', 'poll'));
    }

    persistent_cache_delete('POLL');

    if (addon_installed('catalogues')) {
        update_catalogue_content_ref('poll', strval($id), '');
    }

    $question = get_translated_text($rows[0]['question']);

    delete_lang($rows[0]['question']);
    for ($i = 1; $i <= 10; $i++) {
        delete_lang($rows[0]['option' . strval($i)]);
    }

    $GLOBALS['SITE_DB']->query_delete('rating', ['rating_for_type' => 'polls', 'rating_for_id' => strval($id)]);
    $GLOBALS['SITE_DB']->query_delete('trackbacks', ['trackback_for_type' => 'polls', 'trackback_for_id' => strval($id)]);
    require_code('notifications');
    delete_all_notifications_on('comment_posted', 'polls_' . strval($id));

    $GLOBALS['SITE_DB']->query_delete('poll', ['id' => $id], '', 1);

    $GLOBALS['SITE_DB']->query_update('url_id_monikers', ['m_deprecated' => 1], ['m_resource_page' => 'polls', 'm_resource_type' => 'view', 'm_resource_id' => strval($id)]);

    log_it('DELETE_POLL', strval($id), $question);

    if ((addon_installed('commandr')) && (!running_script('install')) && (!get_mass_import_mode())) {
        require_code('resource_fs');
        expunge_resource_fs_moniker('poll', strval($id));
    }

    require_code('sitemap_xml');
    notify_sitemap_node_delete('_SEARCH:polls:view:' . strval($id));
}

/**
 * Set the poll.
 *
 * @param  AUTO_LINK $id The poll ID to set
 */
function set_poll(int $id)
{
    $rows = $GLOBALS['SITE_DB']->query_select('poll', ['question', 'submitter'], ['id' => $id]);
    $question = $rows[0]['question'];
    $submitter = $rows[0]['submitter'];

    $already_logged = already_in_log('CHOOSE_POLL', strval($id));

    log_it('CHOOSE_POLL', strval($id), get_translated_text($question));

    require_code('users2');
    if (has_actual_page_access(get_modal_user(), 'polls')) {
        require_code('syndication');
        syndicate_described_activity('polls:ACTIVITY_CHOOSE_POLL', get_translated_text($question), '', '', '_SEARCH:polls:view:' . strval($id), '', '', 'polls', 1, null, true);
    }

    if ((!is_guest($submitter)) && (addon_installed('points')) && (!$already_logged)) {
        require_code('points2');
        $points_chosen = intval(get_option('points_CHOOSE_POLL'));
        if ($points_chosen != 0) {
            require_code('content');
            list($title) = content_get_details('poll', strval($id));

            points_credit_member($submitter, do_lang('ACTIVITY_CHOOSE_POLL', $title), $points_chosen, 0, true, 0, 'poll', 'choose', strval($id));
        }
    } else {
        $points_chosen = 0;
    }

    $GLOBALS['SITE_DB']->query_update('poll', ['is_current' => 0], ['is_current' => 1]);
    $GLOBALS['SITE_DB']->query_update('poll', ['is_current' => 1, 'date_and_time' => time()], ['id' => $id], '', 1);

    delete_cache_entry('main_poll');
    persistent_cache_delete('POLL');

    require_lang('polls');
    require_code('notifications');
    $subject = do_lang('POLL_CHOSEN_NOTIFICATION_MAIL_SUBJECT', get_site_name(), get_translated_text($question));
    $poll_url = build_url(['page' => 'polls', 'type' => 'view', 'id' => $id], get_module_zone('polls'), [], false, false, true);
    $mail = do_notification_lang('POLL_CHOSEN_NOTIFICATION_MAIL', comcode_escape(get_site_name()), comcode_escape(get_translated_text($question)), $poll_url->evaluate());
    dispatch_notification('poll_chosen', null, $subject, $mail);

    require_code('sitemap_xml');
    notify_sitemap_node_edit('_SEARCH:polls:view:' . strval($id));
}

/**
 * Unset the poll.
 *
 * @param  AUTO_LINK $id The poll ID to unset
 */
function unset_poll(int $id)
{
    $GLOBALS['SITE_DB']->query_update('poll', ['is_current' => 0, 'date_and_time' => time()], ['id' => $id], '', 1);

    require_code('sitemap_xml');
    notify_sitemap_node_edit('_SEARCH:polls:view:' . strval($id));
}
