<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core_abstract_interfaces
 */

/*
Columned table = Simple low-assumption table with data organised into columns
*/

/**
 * Get the Tempcode for a table header row.
 *
 * @param  array $values The array of field titles that define the entries in the table
 * @return Tempcode The generated header
 */
function columned_table_header_row(array $values) : object
{
    $cells = new Tempcode();
    foreach ($values as $value) {
        $cells->attach(do_template('COLUMNED_TABLE_HEADER_ROW_CELL', ['_GUID' => '5002f54ccddf7259f3460d8c0759fd1a', 'VALUE' => $value]));
    }

    return do_template('COLUMNED_TABLE_HEADER_ROW', ['_GUID' => '2f4095b8d30f50f34fdd6acf8dd566b1', 'CELLS' => $cells]);
}

/**
 * Get the Tempcode for a table row.
 *
 * @param  array $values The array of values that make up this row (each is a plain-text string or HTML Tempcode)
 * @param  boolean $auto_escape Whether to automatically escape each plain-text entry so that it cannot contain HTML (ignored for Tempcode values)
 * @return Tempcode The generated row
 */
function columned_table_row(array $values, bool $auto_escape) : object
{
    $cells = new Tempcode();
    foreach ($values as $value) {
        if (($auto_escape) && (!is_object($value))) {
            $value = escape_html(is_object($value) ? $value->evaluate() : $value);
        }

        $cells->attach(do_template('COLUMNED_TABLE_ROW_CELL', ['_GUID' => '700a982eb2262149295816ddee91b0e7', 'VALUE' => $value]));
    }

    return do_template('COLUMNED_TABLE_ROW', ['_GUID' => 'a4efacc07ecb165e37c355559f476ae9', 'CELLS' => $cells]);
}
