<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core_abstract_interfaces
 */

/*
Map table = Table where each row represents a named field, and each record gets its own table
*/

/**
 * Get the Tempcode for a map screen. (a map shows a single entry, with the field name for each field to the left of the value).
 *
 * @param  Tempcode $title The title of the map screen; should be out of get_screen_title
 * @param  array $fields An array of mappings between title and value (each mapping being a field)
 * @param  boolean $auto_escape Whether to automatically escape each plain-text entry so that it cannot contain HTML (ignored for Tempcode values)
 * @param  ?Tempcode $text Text to show (null: none)
 * @param  ?Tempcode $buttons Buttons to show (null: none)
 * @param  boolean $responsive Use a responsive layout for the table (too much to fit in 2 columns on a small screen)
 * @return Tempcode The generated map screen
 */
function map_table_screen(object $title, array $fields, bool $auto_escape, ?object $text = null, ?object $buttons = null, bool $responsive = false) : object
{
    $_fields = new Tempcode();
    foreach ($fields as $key => $val) {
        $_fields->attach(map_table_field(do_lang_tempcode($key), $val, $auto_escape));
    }

    return do_template('MAP_TABLE_SCREEN', [
        '_GUID' => 'c8c6cbc8e7b5a47a3078fd69feb057a0',
        'TITLE' => $title,
        'TEXT' => $text,
        'FIELDS' => $_fields,
        'BUTTONS' => $buttons,
        'RESPONSIVE' => $responsive,
    ]);
}

/**
 * Get the Tempcode for a map field.
 *
 * @param  mixed $name The field title, provided in plain-text format or as HTML via do_lang_tempcode/protect_from_escaping (string or Tempcode)
 * @param  mixed $value The field value, format depends on $auto_escape (string or Tempcode)
 * @param  boolean $auto_escape Whether to automatically escape each plain-text entry so that it cannot contain HTML (ignored for Tempcode values)
 * @param  string $abbr Field abbreviation (blank: none)
 * @return Tempcode The generated map field
 */
function map_table_field($name, $value, bool $auto_escape, string $abbr = '') : object // Not for use with the above, which takes the fields as a raw map
{
    if (($auto_escape) && (!is_object($value))) {
        $value = escape_html($value);
    }
    return do_template('MAP_TABLE_FIELD', ['_GUID' => '7cd6e583cac2dacc99e3185419d67930', 'ABBR' => $abbr, 'NAME' => $name, 'VALUE' => $value]);
}
