<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.


 NOTE TO PROGRAMMERS:
   Do not edit this file. If you need to make changes, save your changed file to the appropriate *_custom folder
   **** If you ignore this advice, then your website upgrades (e.g. for bug fixes) will likely kill your changes ****

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    core
 */

/*
This script defines the rewrite rules from Composr's end.

Also see build_rewrite_rules.php for web-server script file generation [creates files like recommended.htaccess] (and to a lesser extent, urls.php and urls2.php).
build_rewrite_rules.php is in Git / the composr_release_build addon.
*/

/**
 * Find the list of URL remappings.
 *
 * @param  ID_TEXT $url_scheme The URL scheme to use
 * @return array The list of URL remappings
 */
function get_remappings(string $url_scheme) : array
{
    // The target mapping... upper case means variable substitution, lower case means constant-string
    // The source mapping... null means 'anything' (we'll use it in a variable substitution), else we require a certain value
    // These have to be in longest to shortest number of bindings order, to reduce the potential for &'d attributes

    $rules = [];
    switch ($url_scheme) {
        case 'PG':
            if (addon_installed('wiki')) {
                $rules[] = [['page' => 'wiki', 'type' => 'browse', 'id' => null], 'pg/s/ID', false];
            }
            $rules[] = [['page' => null, 'type' => null, 'id' => null], 'pg/PAGE/TYPE/ID', false];
            $rules[] = [['page' => null, 'id' => null], 'pg/PAGE/browse/ID', false];
            $rules[] = [['page' => null, 'type' => 'browse'], 'pg/PAGE', false];
            $rules[] = [['page' => null, 'type' => null], 'pg/PAGE/TYPE', false];
            if (get_option('url_scheme_omit_default_zone_pages') == '1') {
                $rules[] = [['page' => false/*will map to get_zone_default_page*/], '', true];
                $rules[] = [['page' => ''], '', true];
            }
            $rules[] = [['page' => ''], 'pg/DEFAULT_PAGE', false];
            $rules[] = [['page' => null], 'pg/PAGE', false];
            $rules[] = [[], 'pg', true];
            break;

        case 'HTM':
            if (addon_installed('wiki')) {
                $rules[] = [['page' => 'wiki', 'type' => 'browse', 'id' => null], 's/ID.htm', false];
            }
            $rules[] = [['page' => null, 'type' => null, 'id' => null], 'PAGE/TYPE/ID.htm', false];
            $rules[] = [['page' => null, 'id' => null], 'PAGE/browse/ID.htm', false];
            $rules[] = [['page' => null, 'type' => 'browse'], 'PAGE.htm', false];
            $rules[] = [['page' => null, 'type' => null], 'PAGE/TYPE.htm', false];
            if (get_option('url_scheme_omit_default_zone_pages') == '1') {
                $rules[] = [['page' => false/*will map to get_zone_default_page*/], '', true];
                $rules[] = [['page' => ''], '', true];
            }
            $rules[] = [['page' => ''], 'DEFAULT_PAGE.htm', false];
            $rules[] = [['page' => null], 'PAGE.htm', false];
            $rules[] = [[], '', false];
            break;

        case 'SIMPLE':
            if (addon_installed('wiki')) {
                $rules[] = [['page' => 'wiki', 'type' => 'browse', 'id' => null], 's/ID', false];
            }
            $rules[] = [['page' => null, 'type' => null, 'id' => null], 'PAGE/TYPE/ID', false];
            $rules[] = [['page' => null, 'id' => null], 'PAGE/browse/ID', false];
            $rules[] = [['page' => null, 'type' => 'browse'], 'PAGE', false];
            $rules[] = [['page' => null, 'type' => null], 'PAGE/TYPE', false];
            if (get_option('url_scheme_omit_default_zone_pages') == '1') {
                $rules[] = [['page' => false/*will map to get_zone_default_page*/], '', true];
                $rules[] = [['page' => ''], '', true];
            }
            $rules[] = [['page' => ''], 'DEFAULT_PAGE', false];
            $rules[] = [['page' => null], 'PAGE', false];
            $rules[] = [[], '', false];
            break;
    }

    return $rules;
}
